@@ -7,6 +7,9 @@ set -e
 
 PROJECT_DIR=$(basename ${PWD})
 
+# Use deps from vendor dir.
+export GOFLAGS="-mod=vendor"
+
 GIT_TAG=${SOURCE_GIT_TAG:-$(git describe --always --tags HEAD)}
 LD_FLAGS="-w -X github.com/openshift/console/pkg/version.Version=${GIT_TAG}"
 
