@@ -3,10 +3,10 @@ import { Provider } from 'react-redux';
 import { Link, Router } from 'react-router-dom';
 import { mount, shallow } from 'enzyme';
 
+import { FLAGS } from '@console/shared';
 import { setFlag } from '@console/internal/actions/features';
 import * as UIActions from '@console/internal/actions/ui';
 import { history } from '@console/internal/components/utils/router';
-import { FLAGS } from '@console/internal/const';
 import {
   PrometheusGraph,
   PrometheusGraphLink,
@@ -41,13 +41,16 @@ describe('<PrometheusGraphLink />', () => {
     // Need full mount with redux store since this is a redux-connected component
     const getWrapper = (query: string) => {
       const wrapper = mount(
-        <Router history={history}>
-          <Provider store={store}>
-            <PrometheusGraphLink query={query}>
-              <p className="test-class" />
-            </PrometheusGraphLink>
-          </Provider>
-        </Router>,
+        <PrometheusGraphLink query={query}>
+          <p className="test-class" />
+        </PrometheusGraphLink>,
+        {
+          wrappingComponent: ({ children }) => (
+            <Router history={history}>
+              <Provider store={store}>{children}</Provider>
+            </Router>
+          ),
+        },
       );
       expect(wrapper.find('p.test-class').exists()).toBe(true);
       return wrapper;
@@ -61,14 +64,14 @@ describe('<PrometheusGraphLink />', () => {
     expect(wrapper.find(Link).exists()).toBe(false);
     wrapper = getWrapper('test');
     expect(wrapper.find(Link).exists()).toBe(true);
-    expect(wrapper.find(Link).props().to).toEqual('/metrics?query0=test');
+    expect(wrapper.find(Link).props().to).toEqual('/dev-monitoring/ns/default/metrics?query0=test');
 
     store.dispatch(UIActions.setActivePerspective('admin'));
     wrapper = getWrapper('');
     expect(wrapper.find(Link).exists()).toBe(false);
     wrapper = getWrapper('test');
     expect(wrapper.find(Link).exists()).toBe(true);
-    expect(wrapper.find(Link).props().to).toEqual('/metrics?query0=test');
+    expect(wrapper.find(Link).props().to).toEqual('/dev-monitoring/ns/default/metrics?query0=test');
 
     store.dispatch(setFlag(FLAGS.CAN_GET_NS, true));
     store.dispatch(UIActions.setActivePerspective('dev'));
@@ -76,7 +79,7 @@ describe('<PrometheusGraphLink />', () => {
     expect(wrapper.find(Link).exists()).toBe(false);
     wrapper = getWrapper('test');
     expect(wrapper.find(Link).exists()).toBe(true);
-    expect(wrapper.find(Link).props().to).toEqual('/metrics?query0=test');
+    expect(wrapper.find(Link).props().to).toEqual('/dev-monitoring/ns/default/metrics?query0=test');
 
     store.dispatch(UIActions.setActivePerspective('admin'));
     wrapper = getWrapper('');
@@ -88,10 +91,10 @@ describe('<PrometheusGraphLink />', () => {
 });
 
 describe('getPrometheusExpressionBrowserURL()', () => {
-  const urls = {
-    'prometheus-k8s': 'https://mock.prometheus.url',
-  };
-  const url = getPrometheusExpressionBrowserURL(urls, ['test-query-1', 'test-query-2']);
+  const url = getPrometheusExpressionBrowserURL('https://mock.prometheus.url', [
+    'test-query-1',
+    'test-query-2',
+  ]);
   expect(url).toBe(
     'https://mock.prometheus.url/graph?g0.range_input=1h&g0.expr=test-query-1&g0.tab=0&g1.range_input=1h&g1.expr=test-query-2&g1.tab=0',
   );
