@@ -1,4 +1,4 @@
-import { Config, browser, logging, $ } from 'protractor';
+import { browser, $ } from 'protractor';
 import { execSync } from 'child_process';
 import { promise as webdriverpromise } from 'selenium-webdriver';
 import * as HtmlScreenshotReporter from 'protractor-jasmine2-screenshot-reporter';
@@ -36,7 +36,7 @@ const junitReporter = new JUnitXmlReporter({
   savePath: `./${screenshotsDir}`,
   consolidateAll: true,
 });
-const browserLogs: logging.Entry[] = [];
+const browserLogs = [];
 
 const suite = (tests: string[]): string[] =>
   (!_.isNil(process.env.BRIDGE_KUBEADMIN_PASSWORD) ? ['tests/login.scenario.ts'] : []).concat([
@@ -58,6 +58,7 @@ const testSuites = {
     'tests/modal-annotations.scenario.ts',
     'tests/environment.scenario.ts',
   ]),
+  event: suite(['tests/event.scenario.ts']),
   crudBasic: suite(['tests/crud.scenario.ts']),
   monitoring: suite(['tests/monitoring.scenario.ts']),
   newApp: suite(['tests/overview/overview.scenario.ts', 'tests/deploy-image.scenario.ts']),
@@ -77,18 +78,23 @@ const testSuites = {
   ]),
   overview: suite(['tests/overview/overview.scenario.ts']),
   crdExtensions: suite(['tests/crd-extensions.scenario.ts']),
+  oauth: suite(['tests/oauth.scenario.ts']),
   e2e: suite([
     'tests/crud.scenario.ts',
+    'tests/filter.scenario.ts',
     'tests/secrets.scenario.ts',
     'tests/storage.scenario.ts',
-    'tests/filter.scenario.ts',
     'tests/modal-annotations.scenario.ts',
     'tests/environment.scenario.ts',
     'tests/overview/overview.scenario.ts',
     'tests/deploy-image.scenario.ts',
     'tests/performance.scenario.ts',
     'tests/monitoring.scenario.ts',
+    'tests/alertmanager.scenario.ts',
     'tests/crd-extensions.scenario.ts',
+    'tests/oauth.scenario.ts',
+    'tests/devconsole/pipeline.scenario.ts',
+    'tests/event.scenario.ts',
   ]),
   release: suite([
     'tests/crud.scenario.ts',
@@ -100,6 +106,7 @@ const testSuites = {
     'tests/performance.scenario.ts',
     'tests/monitoring.scenario.ts',
     'tests/crd-extensions.scenario.ts',
+    'tests/event.scenario.ts',
   ]),
   all: suite([
     'tests/crud.scenario.ts',
@@ -113,15 +120,20 @@ const testSuites = {
     'tests/deploy-image.scenario.ts',
     'tests/developer-catalog.scenario.ts',
     'tests/monitoring.scenario.ts',
+    'tests/alertmanager.scenario.ts',
     'tests/devconsole/dev-perspective.scenario.ts',
     'tests/devconsole/git-import-flow.scenario.ts',
+    'tests/devconsole/pipeline.scenario.ts',
     'tests/crd-extensions.scenario.ts',
+    'tests/oauth.scenario.ts',
+    'tests/event.scenario.ts',
   ]),
   clusterSettings: suite(['tests/cluster-settings.scenario.ts']),
+  alertmanager: suite(['tests/alertmanager.scenario.ts']),
   login: ['tests/login.scenario.ts'],
 };
 
-export const config: Config = {
+export const config = {
   framework: 'jasmine',
   directConnect: true,
   skipSourceMapSupport: true,
@@ -210,10 +222,12 @@ export const config: Config = {
 };
 
 export const checkLogs = async () =>
-  (await browser
-    .manage()
-    .logs()
-    .get('browser')).map((log) => {
+  (
+    await browser
+      .manage()
+      .logs()
+      .get('browser')
+  ).map((log) => {
     browserLogs.push(log);
     return log;
   });
