@@ -1,5 +1,5 @@
 import * as _ from 'lodash';
-import { HealthState } from '@console/shared/src/components/dashboard/health-card/states';
+import { HealthState } from '@console/shared/src/components/dashboard/status-card/states';
 import { PrometheusHealthHandler } from '@console/plugin-sdk';
 import { getResiliencyProgress } from '../../../../utils';
 
@@ -14,7 +14,7 @@ const CephHealthStatus = [
     state: HealthState.ERROR,
   },
   {
-    state: HealthState.UNKNOWN,
+    state: HealthState.NOT_AVAILABLE,
   },
 ];
 
@@ -33,7 +33,7 @@ export const getCephHealthState: PrometheusHealthHandler = (responses = [], erro
 export const getDataResiliencyState: PrometheusHealthHandler = (responses = [], errors = []) => {
   const progress: number = getResiliencyProgress(responses[0]);
   if (errors[0]) {
-    return { state: HealthState.UNKNOWN };
+    return { state: HealthState.NOT_AVAILABLE };
   }
   if (!responses[0]) {
     return { state: HealthState.LOADING };
