@@ -15,7 +15,7 @@ import {
   getNodeCPUCapacity,
   getNodeAllocatableMemory,
 } from '@console/shared';
-import { Alert, ActionGroup, Button } from '@patternfly/react-core';
+import { ActionGroup, Button } from '@patternfly/react-core';
 import { tableFilters } from '@console/internal/components/factory/table-filters';
 import { ButtonBar } from '@console/internal/components/utils/button-bar';
 import { history } from '@console/internal/components/utils/router';
@@ -181,7 +181,6 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({
   const [error, setError] = React.useState('');
   const [inProgress, setProgress] = React.useState(false);
   const [selectedNodesCnt, setSelectedNodesCnt] = React.useState(0);
-  const [nodesWarningMsg, setNodesWarningMsg] = React.useState('');
   const [storageClass, setStorageClass] = React.useState(null);
 
   // pre-selection of nodes
@@ -192,40 +191,10 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({
     setNodes(preSelectedNodes);
   }
 
-  const hasMinimumCPU = (node: formattedNodeType): boolean => {
-    return convertToBaseValue(node.cpuCapacity) >= 16;
-  };
-
-  const hasMinimumMemory = (node: formattedNodeType): boolean => {
-    return convertToBaseValue(node.allocatableMemory) >= convertToBaseValue('64 Gi');
-  };
-
-  const validateNodes = React.useCallback((selectedNodes: formattedNodeType[]): void => {
-    let invalidNodesCount = 0;
-    let nodeName = '';
-    selectedNodes.forEach((node: formattedNodeType) => {
-      if (!hasMinimumCPU(node) || !hasMinimumMemory(node)) {
-        invalidNodesCount += 1;
-        nodeName = node.id;
-      }
-    });
-
-    if (invalidNodesCount > 0) {
-      const msg =
-        invalidNodesCount > 1
-          ? `${invalidNodesCount} of the selected nodes do not meet minimum requirements of 16 cores and 64 GiB Memory`
-          : `Node ${nodeName} does not meet minimum requirements of 16 cores and 64 GiB memory.`;
-      setNodesWarningMsg(msg);
-    } else {
-      setNodesWarningMsg('');
-    }
-  }, []);
-
   React.useEffect(() => {
     const selectedNodes = _.filter(unfilteredNodes, 'selected');
     setSelectedNodesCnt(selectedNodes.length);
-    validateNodes(selectedNodes);
-  }, [nodes, unfilteredNodes, validateNodes]);
+  }, [nodes, unfilteredNodes]);
 
   React.useEffect(() => {
     if (isFiltered || nodes.length !== data.length) {
@@ -356,14 +325,6 @@ const CustomNodeTable: React.FC<CustomNodeTableProps> = ({
       <p className="control-label help-block" id="nodes-selected">
         {selectedNodesCnt} node(s) selected
       </p>
-      {nodesWarningMsg.length > 0 && (
-        <Alert
-          className="co-alert ceph-ocs-install__alert"
-          variant="warning"
-          title={nodesWarningMsg}
-          isInline
-        />
-      )}
       <div className="ceph-ocs-install__ocs-service-capacity--dropdown">
         <OCSStorageClassDropdown onChange={setStorageClass} />
       </div>
