@@ -8,6 +8,11 @@ export const ocsTaint: Taint = {
 };
 Object.freeze(ocsTaint);
 
+export const storageClassTooltip =
+  'The Storage Class will be used to request storage from the underlying infrastructure to create the backing persistent volumes that will be used to provide the OpenShift Container Storage (OCS) service.';
+export const labelTooltip =
+  'The backing storage requested will be higher as it will factor in the requested capacity, replica factor, and fault tolerant costs associated with the requested capacity.';
+
 export const ocsRequestData: K8sResourceKind = {
   apiVersion: 'ocs.openshift.io/v1',
   kind: 'StorageCluster',
@@ -32,7 +37,7 @@ export const ocsRequestData: K8sResourceKind = {
             volumeMode: 'Block',
             resources: {
               requests: {
-                storage: '2Ti',
+                storage: '',
               },
             },
           },
