@@ -21,12 +21,13 @@ import {
   DashboardsOverviewUtilizationItem,
   DashboardsOverviewResourceActivity,
   DashboardsOverviewPrometheusActivity,
+  HorizontalNavTab,
 } from '@console/plugin-sdk';
 // TODO(vojtech): internal code needed by plugins should be moved to console-shared package
 import { PodModel, RouteModel, NodeModel } from '@console/internal/models';
-import { FLAGS } from '@console/internal/const';
+import { FLAGS } from '@console/shared';
 import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
-import { OverviewQuery } from '@console/internal/components/dashboard/dashboards-page/overview-dashboard/queries';
+import { OverviewQuery } from '@console/internal/components/dashboard/dashboards-page/cluster-dashboard/queries';
 import { FooBarModel } from './models';
 import { yamlTemplates } from './yaml-templates';
 import TestIcon from './components/test-icon';
@@ -52,7 +53,8 @@ type ConsumedExtensions =
   | DashboardsInventoryItemGroup
   | DashboardsOverviewUtilizationItem
   | DashboardsOverviewResourceActivity
-  | DashboardsOverviewPrometheusActivity;
+  | DashboardsOverviewPrometheusActivity
+  | HorizontalNavTab;
 
 const plugin: Plugin<ConsumedExtensions> = [
   {
@@ -75,9 +77,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Test Href Link',
         href: '/test',
-        required: 'TEST_MODEL_FLAG',
       },
     },
+    flags: {
+      required: ['TEST_MODEL_FLAG'],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -86,9 +90,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Test ResourceNS Link',
         resource: 'pods',
-        required: 'TEST_MODEL_FLAG',
       },
     },
+    flags: {
+      required: ['TEST_MODEL_FLAG'],
+    },
   },
   {
     type: 'NavItem/ResourceCluster',
@@ -97,9 +103,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Test ResourceCluster Link',
         resource: 'projects',
-        required: [FLAGS.OPENSHIFT, 'TEST_MODEL_FLAG'],
       },
     },
+    flags: {
+      required: [FLAGS.OPENSHIFT, 'TEST_MODEL_FLAG'],
+    },
   },
   {
     type: 'Page/Resource/List',
@@ -215,11 +223,6 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Dashboards/Overview/Inventory/Item',
     properties: {
-      resource: {
-        isList: true,
-        kind: RouteModel.kind,
-        prop: 'routes',
-      },
       model: RouteModel,
       mapper: getRouteStatusGroups,
       expandedComponent: () =>
@@ -276,6 +279,20 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: 'TEST_MODEL_FLAG',
     },
   },
+  {
+    type: 'HorizontalNavTab',
+    properties: {
+      model: PodModel,
+      page: {
+        href: 'example',
+        name: 'Example',
+      },
+      loader: () =>
+        import('./components/test-pages' /* webpackChunkName: "demo" */).then(
+          (m) => m.DummyHorizontalNavTab,
+        ),
+    },
+  },
 ];
 
 export default plugin;
