@@ -1,18 +1,23 @@
-import { HealthState } from '@console/shared/src/components/dashboard/health-card/states';
+import { HealthState } from '@console/shared/src/components/dashboard/status-card/states';
 import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
-import { FirehoseResource, FirehoseResult } from '@console/internal/components/utils';
-import { K8sKind, K8sResourceKind } from '@console/internal/module/k8s';
+import {
+  FirehoseResource,
+  FirehoseResult,
+  FirehoseResourcesResult,
+} from '@console/internal/components/utils';
+import { K8sKind, K8sResourceKind, K8sResourceCommon } from '@console/internal/module/k8s';
 import {
   StatusGroupMapper,
   ExpandedComponentProps,
 } from '@console/shared/src/components/dashboard/inventory-card/InventoryItem';
 import { PrometheusResponse } from '@console/internal/components/graphs';
-import { Extension } from './extension';
-import { LazyLoader } from './types';
+import { Extension, LazyLoader } from './base';
 
 export interface DashboardsExtensionProperties {
-  /** Name of feature flag for this item. */
+  /** Feature flags which are required for this extension to be effective. */
   required?: string | string[];
+  /** Feature flags which are disallowed for this extension to be effective. */
+  disallowed?: string | string[];
 }
 
 namespace ExtensionProperties {
@@ -77,6 +82,27 @@ namespace ExtensionProperties {
     popupTitle?: string;
   }
 
+  export interface DashboardsOverviewHealthOperator<R extends K8sResourceCommon>
+    extends DashboardsOverviewHealthSubsystem {
+    /** Title of operators section in popup */
+    title: string;
+
+    /** Resources which will be fetched and passed to healthHandler */
+    resources: FirehoseResource[];
+
+    /** Resolve status for operators */
+    getOperatorsWithStatuses: GetOperatorsWithStatuses<R>;
+
+    /** Loader for popup row component */
+    operatorRowLoader: LazyLoader<OperatorRowProps<R>>;
+
+    /**
+     * Link to all resources page.
+     * If not provided then a list page of first resource from resources prop is used.
+     */
+    viewAllLink?: string;
+  }
+
   export interface DashboardsTab extends DashboardsExtensionProperties {
     /** The tab's ID which will be used as part of href within dashboards page */
     id: string;
@@ -100,21 +126,18 @@ namespace ExtensionProperties {
   }
 
   export interface DashboardsOverviewInventoryItem extends DashboardsExtensionProperties {
-    /** Resource which will be fetched and grouped by `mapper` function. */
-    resource: FirehoseResource;
+    /** The model for `resource` which will be fetched. The model is used for getting model's label or abbr. */
+    model: K8sKind;
+
+    /** Function which will map various statuses to groups. */
+    mapper?: StatusGroupMapper;
 
     /** Additional resources which will be fetched and passed to `mapper` function. */
     additionalResources?: FirehoseResource[];
 
-    /** The model for `resource` which will be fetched. The model is used for getting model's label or abbr. */
-    model: K8sKind;
-
     /** Defines whether model's label or abbr should be used when rendering the item. Defaults to false (label). */
     useAbbr?: boolean;
 
-    /** Function which will map various statuses to groups. */
-    mapper: StatusGroupMapper;
-
     /** Loader for the component which will be used when item is expanded. */
     expandedComponent?: LazyLoader<ExpandedComponentProps>;
   }
@@ -140,7 +163,7 @@ namespace ExtensionProperties {
 
   export interface DashboardsOverviewResourceActivity extends DashboardsExtensionProperties {
     /** Resource to watch */
-    k8sResource: FirehoseResource;
+    k8sResource: FirehoseResource & { isList: true };
 
     /**
      * Function which will determine if given resource represents the action.
@@ -149,7 +172,7 @@ namespace ExtensionProperties {
     isActivity?: (resource: K8sResourceKind) => boolean;
 
     /** Timestamp for given action, which will be used for ordering */
-    getTimestamp: (resource: K8sResourceKind) => Date;
+    getTimestamp?: (resource: K8sResourceKind) => Date;
 
     /** Loader for corresponding action component */
     loader: LazyLoader<K8sActivityProps>;
@@ -200,14 +223,26 @@ export const isDashboardsOverviewHealthPrometheusSubsystem = (
 ): e is DashboardsOverviewHealthPrometheusSubsystem =>
   e.type === 'Dashboards/Overview/Health/Prometheus';
 
+export interface DashboardsOverviewHealthOperator<R extends K8sResourceCommon = K8sResourceCommon>
+  extends Extension<ExtensionProperties.DashboardsOverviewHealthOperator<R>> {
+  type: 'Dashboards/Overview/Health/Operator';
+}
+
+export const isDashboardsOverviewHealthOperator = (
+  e: Extension,
+): e is DashboardsOverviewHealthOperator => e.type === 'Dashboards/Overview/Health/Operator';
+
 export type DashboardsOverviewHealthSubsystem =
   | DashboardsOverviewHealthURLSubsystem
-  | DashboardsOverviewHealthPrometheusSubsystem;
+  | DashboardsOverviewHealthPrometheusSubsystem
+  | DashboardsOverviewHealthOperator;
 
 export const isDashboardsOverviewHealthSubsystem = (
   e: Extension,
 ): e is DashboardsOverviewHealthSubsystem =>
-  isDashboardsOverviewHealthURLSubsystem(e) || isDashboardsOverviewHealthPrometheusSubsystem(e);
+  isDashboardsOverviewHealthURLSubsystem(e) ||
+  isDashboardsOverviewHealthPrometheusSubsystem(e) ||
+  isDashboardsOverviewHealthOperator(e);
 
 export interface DashboardsTab extends Extension<ExtensionProperties.DashboardsTab> {
   type: 'Dashboards/Tab';
@@ -274,6 +309,16 @@ export interface ProjectDashboardInventoryItem
 export const isProjectDashboardInventoryItem = (e: Extension): e is ProjectDashboardInventoryItem =>
   e.type === 'Project/Dashboard/Inventory/Item';
 
+export interface DashboardsOverviewInventoryItemReplacement
+  extends Extension<ExtensionProperties.DashboardsOverviewInventoryItem> {
+  type: 'Dashboards/Overview/Inventory/Item/Replacement';
+}
+
+export const isDashboardsOverviewInventoryItemReplacement = (
+  e: Extension,
+): e is DashboardsOverviewInventoryItemReplacement =>
+  e.type === 'Dashboards/Overview/Inventory/Item/Replacement';
+
 export type DashboardCardSpan = 4 | 6 | 12;
 
 export type K8sActivityProps = {
@@ -300,3 +345,34 @@ export type PrometheusHealthHandler = (
   errors: any[],
   additionalResource?: FirehoseResult<K8sResourceKind | K8sResourceKind[]>,
 ) => SubsystemHealth;
+
+export type OperatorHealthHandler = (resources: FirehoseResourcesResult) => OperatorHealth;
+
+export type OperatorHealth = {
+  health: HealthState;
+  count?: number;
+};
+
+export type GetOperatorsWithStatuses<R extends K8sResourceCommon = K8sResourceCommon> = (
+  resources: FirehoseResourcesResult,
+) => OperatorStatusWithResources<R>[];
+
+export type OperatorStatusWithResources<R extends K8sResourceCommon = K8sResourceCommon> = {
+  operators: R[];
+  status: OperatorStatusPriority;
+};
+
+export type GetOperatorStatusPriority<R extends K8sResourceCommon = K8sResourceCommon> = (
+  operator: R,
+) => OperatorStatusPriority;
+
+export type OperatorStatusPriority = {
+  title: string;
+  priority: number;
+  icon: React.ReactNode;
+  health: HealthState;
+};
+
+export type OperatorRowProps<R extends K8sResourceCommon = K8sResourceCommon> = {
+  operatorStatus: OperatorStatusWithResources<R>;
+};
