@@ -3,7 +3,7 @@ import { Helmet } from 'react-helmet';
 import { match as RMatch } from 'react-router';
 import { BuildConfigsPage } from '@console/internal/components/build-config';
 import { withStartGuide } from '../../../../public/components/start-guide';
-import DefaultPage from './DefaultPage';
+import ProjectListPage from './projects/ProjectListPage';
 
 export interface BuildConfigPageProps {
   match: RMatch<{
@@ -15,18 +15,18 @@ export interface BuildConfigPageProps {
 const BuildConfigPage: React.FC<BuildConfigPageProps> = ({ noProjectsAvailable, ...props }) => {
   const namespace = props.match.params.ns;
   return (
-    <React.Fragment>
+    <>
       <Helmet>
         <title>Builds</title>
       </Helmet>
       {namespace ? (
         <BuildConfigsPage {...props} mock={noProjectsAvailable} />
       ) : (
-        <DefaultPage title="Build Configs">
+        <ProjectListPage title="Build Configs">
           Select a project to view the list of build configs
-        </DefaultPage>
+        </ProjectListPage>
       )}
-    </React.Fragment>
+    </>
   );
 };
 
