@@ -2,7 +2,7 @@ import * as React from 'react';
 import { Firehose } from '@console/internal/components/utils';
 import { referenceForModel } from '@console/internal/module/k8s';
 import { ServiceModel } from '@console/knative-plugin';
-import ResourceDropdown from './ResourceDropdown';
+import { ResourceDropdown } from '@console/shared';
 
 interface ApplicationDropdownProps {
   id?: string;
@@ -63,6 +63,12 @@ const ApplicationDropdown: React.FC<ApplicationDropdownProps> = ({ namespace, ..
       prop: 'knativeService',
       optional: true,
     },
+    {
+      isList: true,
+      kind: 'Secret',
+      namespace,
+      prop: 'secrets',
+    },
   ];
   return (
     <Firehose resources={resources}>
