@@ -2,14 +2,17 @@ import * as React from 'react';
 import { RouteComponentProps } from 'react-router-dom';
 import { Helmet } from 'react-helmet';
 import { PageHeading, Firehose } from '@console/internal/components/utils';
-import { ImageStreamModel } from '@console/internal/models';
+import { QUERY_PROPERTIES } from '../../const';
+import QueryFocusApplication from '../QueryFocusApplication';
 import NamespacedPage, { NamespacedPageVariants } from '../NamespacedPage';
 import DeployImage from './DeployImage';
 
 export type DeployImagePageProps = RouteComponentProps<{ ns?: string }>;
 
-const DeployImagePage: React.FunctionComponent<DeployImagePageProps> = ({ match }) => {
+const DeployImagePage: React.FunctionComponent<DeployImagePageProps> = ({ match, location }) => {
   const namespace = match.params.ns;
+  const params = new URLSearchParams(location.search);
+
   return (
     <NamespacedPage disabled variant={NamespacedPageVariants.light}>
       <Helmet>
@@ -17,18 +20,17 @@ const DeployImagePage: React.FunctionComponent<DeployImagePageProps> = ({ match
       </Helmet>
       <PageHeading title="Deploy Image" />
       <div className="co-m-pane__body">
-        <Firehose
-          resources={[
-            { kind: 'Project', prop: 'projects', isList: true },
-            {
-              kind: ImageStreamModel.kind,
-              prop: 'imageStreams',
-              isList: true,
-            },
-          ]}
-        >
-          <DeployImage namespace={namespace} />
-        </Firehose>
+        <QueryFocusApplication>
+          {(desiredApplication) => (
+            <Firehose resources={[{ kind: 'Project', prop: 'projects', isList: true }]}>
+              <DeployImage
+                forApplication={desiredApplication}
+                namespace={namespace}
+                contextualSource={params.get(QUERY_PROPERTIES.CONTEXT_SOURCE)}
+              />
+            </Firehose>
+          )}
+        </QueryFocusApplication>
       </div>
     </NamespacedPage>
   );
