@@ -1,3 +1,4 @@
+import { ValidatedOptions } from '@patternfly/react-core';
 import { GitImportFormData, Resources } from '../import-types';
 
 export const mockFormData: GitImportFormData = {
@@ -19,7 +20,7 @@ export const mockFormData: GitImportFormData = {
     dir: '',
     showGitType: false,
     secret: '',
-    isUrlValidated: false,
+    urlValidation: ValidatedOptions.default,
     isUrlValidating: false,
   },
   docker: {
@@ -79,16 +80,20 @@ export const mockFormData: GitImportFormData = {
   },
   limits: {
     cpu: {
-      request: '',
-      requestUnit: 'millicores',
-      limit: '',
-      limitUnit: 'millicores',
+      request: null,
+      requestUnit: 'm',
+      defaultRequestUnit: 'm',
+      limit: null,
+      limitUnit: 'm',
+      defaultLimitUnit: 'm',
     },
     memory: {
-      request: '',
-      requestUnit: 'MiB',
-      limit: '',
-      limitUnit: 'MiB',
+      request: null,
+      requestUnit: 'Mi',
+      defaultRequestUnit: 'Mi',
+      limit: null,
+      limitUnit: 'Mi',
+      defaultLimitUnit: 'Mi',
     },
   },
 };
