@@ -7,19 +7,21 @@ import {
   RouteModel,
   RoleBindingModel,
 } from '@console/internal/models';
-import { k8sCreate, K8sResourceKind } from '@console/internal/module/k8s';
+import { k8sCreate, K8sResourceKind, K8sVerb, k8sUpdate } from '@console/internal/module/k8s';
 import {
   getKnativeServiceDepResource,
   ServiceModel as KnServiceModel,
 } from '@console/knative-plugin';
-import { getAppLabels, getPodLabels } from '../../utils/resource-label-utils';
+import { getAppLabels, getPodLabels, mergeData } from '../../utils/resource-label-utils';
 import {
   createRoute,
   createService,
   annotations,
   dryRunOpt,
+  getRandomChars,
 } from '../../utils/shared-submit-utils';
 import { RegistryType } from '../../utils/imagestream-utils';
+import { AppResources } from '../edit-application/edit-application-types';
 import { DeployImageFormData, Resources } from './import-types';
 
 export const createSystemImagePullerRoleBinding = (
@@ -50,9 +52,12 @@ export const createSystemImagePullerRoleBinding = (
   return k8sCreate(RoleBindingModel, roleBinding, dryRun ? dryRunOpt : {});
 };
 
-export const createImageStream = (
+export const createOrUpdateImageStream = (
   formData: DeployImageFormData,
   dryRun: boolean,
+  originalImageStream?: K8sResourceKind,
+  verb: K8sVerb = 'create',
+  generatedImageStreamName: string = '',
 ): Promise<K8sResourceKind> => {
   const {
     project: { name: namespace },
@@ -62,11 +67,11 @@ export const createImageStream = (
     labels: userLabels,
   } = formData;
   const defaultLabels = getAppLabels(name, application);
-  const imageStream = {
+  const newImageStream = {
     apiVersion: 'image.openshift.io/v1',
     kind: 'ImageStream',
     metadata: {
-      name,
+      name: `${generatedImageStreamName || name}`,
       namespace,
       labels: { ...defaultLabels, ...userLabels },
     },
@@ -87,8 +92,11 @@ export const createImageStream = (
       ],
     },
   };
+  const imageStream = mergeData(originalImageStream, newImageStream);
 
-  return k8sCreate(ImageStreamModel, imageStream, dryRun ? dryRunOpt : {});
+  return verb === 'update'
+    ? k8sUpdate(ImageStreamModel, imageStream)
+    : k8sCreate(ImageStreamModel, newImageStream, dryRun ? dryRunOpt : {});
 };
 
 const getMetadata = (formData: DeployImageFormData) => {
@@ -97,9 +105,10 @@ const getMetadata = (formData: DeployImageFormData) => {
     name,
     isi: { image },
     labels: userLabels,
+    imageStream: { image: imgName, tag: imgTag, namespace: imgNamespace },
   } = formData;
 
-  const defaultLabels = getAppLabels(name, application);
+  const defaultLabels = getAppLabels(name, application, imgName || undefined, imgTag, imgNamespace);
   const labels = { ...defaultLabels, ...userLabels };
   const podLabels = getPodLabels(name);
 
@@ -122,16 +131,22 @@ const getMetadata = (formData: DeployImageFormData) => {
   return { labels, podLabels, volumes, volumeMounts };
 };
 
-export const createDeployment = (
+export const createOrUpdateDeployment = (
   formData: DeployImageFormData,
   dryRun: boolean,
+  originalDeployment?: K8sResourceKind,
+  verb: K8sVerb = 'create',
 ): Promise<K8sResourceKind> => {
   const {
     registry,
     project: { name: namespace },
     name,
     isi: { image, ports, tag: imageStreamTag },
-    deployment: { env, replicas },
+    deployment: {
+      env,
+      replicas,
+      triggers: { image: imageChange },
+    },
     labels: userLabels,
     limits: { cpu, memory },
     imageStream: { image: imgName, namespace: imgNamespace },
@@ -148,6 +163,7 @@ export const createDeployment = (
           namespace: imgNamespace || namespace,
         },
         fieldPath: `spec.template.spec.containers[?(@.name=="${name}")].image`,
+        pause: `${!imageChange}`,
       },
     ]),
   };
@@ -159,7 +175,7 @@ export const createDeployment = (
       ? `${name}:${imageStreamTag}`
       : _.get(image, 'dockerImageReference');
 
-  const deployment = {
+  const newDeployment = {
     kind: 'Deployment',
     apiVersion: 'apps/v1',
     metadata: {
@@ -209,12 +225,19 @@ export const createDeployment = (
       },
     },
   };
-  return k8sCreate(DeploymentModel, deployment, dryRun ? dryRunOpt : {});
+
+  const deployment = mergeData(originalDeployment, newDeployment);
+
+  return verb === 'update'
+    ? k8sUpdate(DeploymentModel, deployment)
+    : k8sCreate(DeploymentModel, deployment, dryRun ? dryRunOpt : {});
 };
 
-export const createDeploymentConfig = (
+export const createOrUpdateDeploymentConfig = (
   formData: DeployImageFormData,
   dryRun: boolean,
+  originalDeploymentConfig?: K8sResourceKind,
+  verb: K8sVerb = 'create',
 ): Promise<K8sResourceKind> => {
   const {
     project: { name: namespace },
@@ -227,8 +250,7 @@ export const createDeploymentConfig = (
   } = formData;
 
   const { labels, podLabels, volumes, volumeMounts } = getMetadata(formData);
-
-  const deploymentConfig = {
+  const newDeploymentConfig = {
     kind: 'DeploymentConfig',
     apiVersion: 'apps.openshift.io/v1',
     metadata: {
@@ -290,7 +312,11 @@ export const createDeploymentConfig = (
     },
   };
 
-  return k8sCreate(DeploymentConfigModel, deploymentConfig, dryRun ? dryRunOpt : {});
+  const deploymentConfig = mergeData(originalDeploymentConfig, newDeploymentConfig);
+
+  return verb === 'update'
+    ? k8sUpdate(DeploymentConfigModel, deploymentConfig)
+    : k8sCreate(DeploymentConfigModel, deploymentConfig, dryRun ? dryRunOpt : {});
 };
 
 export const ensurePortExists = (formData: DeployImageFormData): DeployImageFormData => {
@@ -317,15 +343,19 @@ export const ensurePortExists = (formData: DeployImageFormData): DeployImageForm
   return values;
 };
 
-export const createResources = async (
+export const createOrUpdateDeployImageResources = async (
   rawFormData: DeployImageFormData,
   dryRun: boolean = false,
+  verb: K8sVerb = 'create',
+  appResources?: AppResources,
 ): Promise<K8sResourceKind[]> => {
   const formData = ensurePortExists(rawFormData);
   const {
+    name,
     registry,
-    route: { create: canCreateRoute },
-    isi: { ports, tag: imageStreamTag },
+    route: { create: canCreateRoute, disable },
+    isi: { ports, tag: imageStreamTag, image },
+    imageStream: { image: internalImageName, namespace: internalImageNamespace },
   } = formData;
 
   const requests: Promise<K8sResourceKind>[] = [];
@@ -333,29 +363,85 @@ export const createResources = async (
     formData.imageStream.grantAccess &&
       requests.push(createSystemImagePullerRoleBinding(formData, dryRun));
   }
+  const imageStreamList = appResources?.imageStream?.data;
+  const imageStreamData = _.orderBy(imageStreamList, ['metadata.resourceVersion'], ['desc']);
+  const originalImageStream = (imageStreamData.length && imageStreamData[0]) || {};
   if (formData.resources !== Resources.KnativeService) {
-    registry === RegistryType.External && requests.push(createImageStream(formData, dryRun));
+    registry === RegistryType.External &&
+      (await createOrUpdateImageStream(formData, dryRun, originalImageStream, verb));
     if (formData.resources === Resources.Kubernetes) {
-      requests.push(createDeployment(formData, dryRun));
+      requests.push(
+        createOrUpdateDeployment(
+          formData,
+          dryRun,
+          _.get(appResources, 'editAppResource.data'),
+          verb,
+        ),
+      );
     } else {
-      requests.push(createDeploymentConfig(formData, dryRun));
+      requests.push(
+        createOrUpdateDeploymentConfig(
+          formData,
+          dryRun,
+          _.get(appResources, 'editAppResource.data'),
+          verb,
+        ),
+      );
     }
     if (!_.isEmpty(ports)) {
-      const service = createService(formData);
-      requests.push(k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}));
-      if (canCreateRoute) {
-        const route = createRoute(formData);
+      const service = createService(formData, undefined, _.get(appResources, 'service.data'));
+      requests.push(
+        verb === 'update'
+          ? k8sUpdate(ServiceModel, service)
+          : k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}),
+      );
+      const route = createRoute(formData, undefined, _.get(appResources, 'route.data'));
+      if (verb === 'update' && disable) {
+        requests.push(k8sUpdate(RouteModel, route));
+      } else if (canCreateRoute) {
         requests.push(k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
       }
     }
   } else if (!dryRun) {
     // Do not run serverless call during the dry run.
-    const imageStreamResponse = await createImageStream(formData, dryRun);
-    const imageStreamUrl = imageStreamTag
-      ? `${imageStreamResponse.status.dockerImageRepository}:${imageStreamTag}`
-      : imageStreamResponse.status.dockerImageRepository;
-    const knDeploymentResource = getKnativeServiceDepResource(formData, imageStreamUrl);
-    requests.push(k8sCreate(KnServiceModel, knDeploymentResource));
+    let imageStreamUrl: string = image?.dockerImageReference;
+    if (registry === RegistryType.External) {
+      let generatedImageStreamName: string = '';
+      if (imageStreamList && imageStreamList.length && verb === 'update') {
+        const originalImageStreamTag = _.find(originalImageStream?.status?.tags, [
+          'tag',
+          imageStreamTag,
+        ]);
+        if (!_.isEmpty(originalImageStreamTag)) {
+          generatedImageStreamName = `${name}-${getRandomChars()}`;
+        }
+      }
+      const imageStreamResponse = await createOrUpdateImageStream(
+        formData,
+        dryRun,
+        originalImageStream,
+        generatedImageStreamName ? 'create' : verb,
+        generatedImageStreamName,
+      );
+      const imageStreamRepo = imageStreamResponse.status.dockerImageRepository;
+      imageStreamUrl = imageStreamTag ? `${imageStreamRepo}:${imageStreamTag}` : imageStreamRepo;
+    }
+    const originalAnnotations = appResources?.editAppResource?.data?.metadata?.annotations || {};
+    const newAnnotations = { ...originalAnnotations, ...annotations };
+    const knDeploymentResource = getKnativeServiceDepResource(
+      formData,
+      imageStreamUrl,
+      internalImageName || name,
+      imageStreamTag,
+      internalImageNamespace,
+      newAnnotations,
+      _.get(appResources, 'editAppResource.data'),
+    );
+    requests.push(
+      verb === 'update'
+        ? k8sUpdate(KnServiceModel, knDeploymentResource)
+        : k8sCreate(KnServiceModel, knDeploymentResource),
+    );
   }
 
   return Promise.all(requests);
