@@ -1,12 +1,17 @@
 import * as React from 'react';
-import { CheckboxField } from '../../formik-fields';
+import { CheckboxField } from '@console/shared';
 
-const RouteCheckbox: React.FC = () => {
+interface RouteCheckboxProps {
+  isDisabled?: boolean;
+}
+
+const RouteCheckbox: React.FC<RouteCheckboxProps> = ({ isDisabled }) => {
   return (
     <CheckboxField
       name="route.create"
       label="Create a route to the application"
       helpText="Exposes your application at a public URL"
+      isDisabled={isDisabled}
     />
   );
 };
