@@ -1,4 +1,6 @@
 export { default as PipelineDetails } from './pipeline-details/PipelineDetails';
 export { default as PipelineParameters } from './PipelineParameters';
+export { default as PipelineParametersForm } from './PipelineParametersForm';
 export { default as PipelineResources } from './PipelineResources';
+export { default as PipelineResourcesForm } from './PipelineResourcesForm';
 export { default as PipelineRuns } from './PipelineRuns';
