@@ -2,10 +2,9 @@ import * as React from 'react';
 import cx from 'classnames';
 import { useField, useFormikContext, FormikValues } from 'formik';
 import { FormGroup } from '@patternfly/react-core';
+import { DropdownFieldProps, getFieldId, useFormikValidationFix } from '@console/shared';
 import PipelineResourceDropdown from '../../dropdown/PipelineResourceDropdown';
 import PipelineResourceForm from '../pipeline-resource/PipelineResourceForm';
-import { DropdownFieldProps } from '../../formik-fields/field-types';
-import { getFieldId } from '../../formik-fields/field-utils';
 
 export const CREATE_PIPELINE_RESOURCE = '#CREATE_PIPELINE_RESOURCE#';
 
@@ -50,6 +49,8 @@ const PipelineResourceDropdownField: React.FC<PipelineResourceDropdownFieldProps
     [field, props.name],
   );
 
+  useFormikValidationFix(field.value);
+
   return (
     <>
       <FormGroup
@@ -81,6 +82,7 @@ const PipelineResourceDropdownField: React.FC<PipelineResourceDropdownFieldProps
       {createMode && (
         <div style={{ marginTop: 'var(--pf-global--spacer--sm)' }}>
           <PipelineResourceForm
+            namespace={values.namespace}
             type={props.filterType}
             closeDisabled={isListEmpty}
             onClose={() => {
