@@ -1,7 +1,7 @@
 import * as React from 'react';
 import { match as RMatch } from 'react-router';
-import { NamespaceBar } from '@console/internal/components/namespace';
-import RenderProjectAccessPage, { RenderProjectAccessPageProps } from './RenderProjectAccessPage';
+import RenderProjectAccess from './RenderProjectAccessPage';
+import NamespacedPage, { NamespacedPageVariants } from '../NamespacedPage';
 
 export interface ProjectAccessPageProps {
   match: RMatch<{
@@ -11,14 +11,13 @@ export interface ProjectAccessPageProps {
 
 const ProjectAccessPage: React.FC<ProjectAccessPageProps> = ({ match }) => {
   const namespace = match.params.ns;
-  const props: RenderProjectAccessPageProps = {
+  const props: React.ComponentProps<typeof RenderProjectAccess> = {
     namespace,
   };
   return (
-    <>
-      <NamespaceBar />
-      <RenderProjectAccessPage {...props} />
-    </>
+    <NamespacedPage variant={NamespacedPageVariants.light}>
+      <RenderProjectAccess {...props} />
+    </NamespacedPage>
   );
 };
 
