@@ -1,6 +1,15 @@
 import * as React from 'react';
-import { useSize, useHover, createSvgIdUrl } from '@console/topology';
-import SvgResourceIcon from '../topology/shapes/ResourceIcon';
+import {
+  useSize,
+  useHover,
+  WithDndDragProps,
+  useCombineRefs,
+  createSvgIdUrl,
+} from '@console/topology';
+import { truncateMiddle } from '@console/internal/components/utils';
+import { RESOURCE_NAME_TRUNCATE_LENGTH } from '../../const';
+import SvgResourceIcon from '../topology/components/nodes/ResourceIcon';
+import SvgCircledIcon from './SvgCircledIcon';
 import SvgDropShadowFilter from './SvgDropShadowFilter';
 
 export interface SvgBoxedTextProps {
@@ -12,7 +21,10 @@ export interface SvgBoxedTextProps {
   y?: number;
   cornerRadius?: number;
   kind?: string;
+  typeIconClass?: string;
+  typeIconPadding?: number;
   truncate?: number;
+  dragRef?: WithDndDragProps['dndDragRef'];
   // TODO remove with 2.0
   onMouseEnter?: React.MouseEventHandler<SVGGElement>;
   onMouseLeave?: React.MouseEventHandler<SVGGElement>;
@@ -20,13 +32,6 @@ export interface SvgBoxedTextProps {
 
 const FILTER_ID = 'SvgBoxedTextDropShadowFilterId';
 
-const truncateEnd = (text: string = '', length: number): string => {
-  if (text.length <= length) {
-    return text;
-  }
-  return `${text.substr(0, length - 1)}…`;
-};
-
 /**
  * Renders a `<text>` component with a `<rect>` box behind.
  */
@@ -39,24 +44,30 @@ const SvgBoxedText: React.FC<SvgBoxedTextProps> = ({
   x = 0,
   y = 0,
   kind,
+  typeIconClass,
+  typeIconPadding = 4,
   onMouseEnter,
   onMouseLeave,
-  truncate,
+  truncate = RESOURCE_NAME_TRUNCATE_LENGTH,
+  dragRef,
   ...other
 }) => {
-  const [labelHover, labelHoverRef] = useHover(200);
+  const [labelHover, labelHoverRef] = useHover();
   const [textSize, textRef] = useSize([children, className, labelHover]);
   const [iconSize, iconRef] = useSize([kind]);
   const iconSpace = kind && iconSize ? iconSize.width + paddingX : 0;
+  const refs = useCombineRefs(dragRef, typeof truncate === 'number' ? labelHoverRef : undefined);
+  const typedIconWidth = typeIconClass && iconSize ? iconSize.height + typeIconPadding * 2 : 0;
+  const midX = typedIconWidth ? x + typedIconWidth / 2 : x;
 
   return (
-    <g className={className} ref={typeof truncate === 'number' ? labelHoverRef : undefined}>
+    <g className={className} ref={refs}>
       <SvgDropShadowFilter id={FILTER_ID} />
       {textSize && (
         <rect
           filter={createSvgIdUrl(FILTER_ID)}
-          x={x - paddingX - textSize.width / 2 - iconSpace / 2}
-          width={textSize.width + paddingX * 2 + iconSpace}
+          x={midX - paddingX - textSize.width / 2 - iconSpace / 2 - (typeIconClass ? 10 : 0)}
+          width={textSize.width + paddingX * 2 + iconSpace + (typeIconClass ? 10 : 0)}
           y={y - paddingY - textSize.height / 2}
           height={textSize.height + paddingY * 2}
           rx={cornerRadius}
@@ -66,25 +77,35 @@ const SvgBoxedText: React.FC<SvgBoxedTextProps> = ({
       {textSize && kind && (
         <SvgResourceIcon
           ref={iconRef}
-          x={x - textSize.width / 2 - paddingX / 2}
+          x={midX - textSize.width / 2 - paddingX / 2}
           y={y}
           kind={kind}
         />
       )}
+      {textSize && iconSize && typeIconClass && (
+        <SvgCircledIcon
+          x={midX - (textSize.width + iconSpace) / 2 - paddingX}
+          y={y - iconSize.height + paddingY * 1.5}
+          width={iconSize.height + paddingY}
+          height={iconSize.height + paddingY}
+          iconClass={typeIconClass}
+          padding={typeIconPadding}
+        />
+      )}
       <text
         {...other}
         ref={textRef}
-        x={x + iconSpace / 2}
+        x={midX + iconSpace / 2}
         y={y}
         textAnchor="middle"
         dy="0.35em"
         onMouseEnter={onMouseEnter}
         onMouseLeave={onMouseLeave}
       >
-        {typeof truncate === 'number'
+        {truncate > 0
           ? labelHover
             ? children
-            : truncateEnd(children, truncate)
+            : truncateMiddle(children, { length: truncate })
           : children}
       </text>
     </g>
