@@ -1,11 +1,11 @@
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
 import { connect } from 'react-redux';
-import { matchPath, match as RMatch, Link } from 'react-router-dom';
-import { Tooltip } from '@patternfly/react-core';
-import { ListIcon, TopologyIcon } from '@patternfly/react-icons';
+import { matchPath, match as RMatch, Link, Redirect } from 'react-router-dom';
+import { Tooltip, Popover, Button } from '@patternfly/react-core';
+import { ListIcon, TopologyIcon, QuestionCircleIcon } from '@patternfly/react-icons';
 import { getActiveApplication } from '@console/internal/reducers/ui';
-import { ALL_APPLICATIONS_KEY } from '@console/internal/const';
+import { ALL_APPLICATIONS_KEY } from '@console/shared';
 import { StatusBox, Firehose, HintBlock, AsyncComponent } from '@console/internal/components/utils';
 import { RootState } from '@console/internal/redux';
 import { FLAG_KNATIVE_SERVING_SERVICE } from '@console/knative-plugin';
@@ -17,6 +17,9 @@ import { ALLOW_SERVICE_BINDING } from '../../const';
 import { getCheURL } from './topology-utils';
 import ConnectedTopologyDataController, { RenderProps } from './TopologyDataController';
 import Topology from './Topology';
+import TopologyShortcuts from './TopologyShortcuts';
+import { LAST_TOPOLOGY_VIEW_LOCAL_STORAGE_KEY } from './const';
+import './TopologyPage.scss';
 
 interface StateProps {
   activeApplication: string;
@@ -33,6 +36,14 @@ export interface TopologyPageProps {
 
 type Props = TopologyPageProps & StateProps;
 
+const setTopologyActiveView = (id: string) => {
+  localStorage.setItem(LAST_TOPOLOGY_VIEW_LOCAL_STORAGE_KEY, id);
+};
+
+const getTopologyActiveView = () => {
+  return localStorage.getItem(LAST_TOPOLOGY_VIEW_LOCAL_STORAGE_KEY);
+};
+
 const EmptyMsg = () => (
   <EmptyState
     title="Topology"
@@ -56,17 +67,7 @@ export function renderTopology({ loaded, loadError, serviceBinding, data }: Rend
       loadError={loadError}
       EmptyMsg={EmptyMsg}
     >
-      <div
-        style={{
-          display: 'flex',
-          flexDirection: 'column',
-          position: 'absolute',
-          left: 0,
-          right: 0,
-          top: 0,
-          bottom: 0,
-        }}
-      >
+      <div className="odc-topology">
         <Topology data={data} serviceBinding={serviceBinding} />
       </div>
     </StatusBox>
@@ -86,6 +87,26 @@ const TopologyPage: React.FC<Props> = ({
     path: '*/list',
     exact: true,
   });
+  const showGraphView = !!matchPath(match.path, {
+    path: '*/graph',
+    exact: true,
+  });
+
+  React.useEffect(() => setTopologyActiveView(showListView && !showGraphView ? 'list' : 'graph'), [
+    showListView,
+    showGraphView,
+  ]);
+
+  if (!showGraphView && !showListView) {
+    return (
+      <Redirect
+        to={`/topology/${namespace ? `ns/${namespace}` : 'all-namespaces'}/${
+          getTopologyActiveView() === 'list' ? 'list' : 'graph'
+        }`}
+      />
+    );
+  }
+
   return (
     <>
       <Helmet>
@@ -95,16 +116,35 @@ const TopologyPage: React.FC<Props> = ({
         variant={showListView ? NamespacedPageVariants.light : NamespacedPageVariants.default}
         hideApplications={showListView}
         toolbar={
-          <Tooltip position="left" content={showListView ? 'Topology View' : 'List View'}>
-            <Link
-              className="pf-c-button pf-m-plain"
-              to={`/topology/${namespace ? `ns/${namespace}` : 'all-namespaces'}${
-                showListView ? '' : '/list'
-              }`}
-            >
-              {showListView ? <TopologyIcon size="md" /> : <ListIcon size="md" />}
-            </Link>
-          </Tooltip>
+          <>
+            {!showListView && namespace && (
+              <Popover
+                aria-label="Shortcuts"
+                bodyContent={TopologyShortcuts}
+                position="left"
+                maxWidth="100vw"
+              >
+                <Button
+                  type="button"
+                  variant="link"
+                  className="odc-topology__shortcuts-button"
+                  icon={<QuestionCircleIcon />}
+                >
+                  View shortcuts
+                </Button>
+              </Popover>
+            )}
+            <Tooltip position="left" content={showListView ? 'Topology View' : 'List View'}>
+              <Link
+                className="pf-c-button pf-m-plain"
+                to={`/topology/${namespace ? `ns/${namespace}` : 'all-namespaces'}${
+                  showListView ? '/graph' : '/list'
+                }`}
+              >
+                {showListView ? <TopologyIcon size="md" /> : <ListIcon size="md" />}
+              </Link>
+            </Tooltip>
+          </>
         }
       >
         <Firehose resources={[{ kind: 'Project', prop: 'projects', isList: true }]}>
