@@ -1,7 +1,7 @@
 import * as React from 'react';
 import { ResourceOverviewPage } from '@console/internal/components/overview/resource-overview-page';
 import * as _ from 'lodash';
-import { KnativeOverviewPage } from '@console/knative-plugin/src/components/overview/KnativeResourceOverviewPage';
+import KnativeResourceOverviewPage from '@console/knative-plugin/src/components/overview/KnativeResourceOverviewPage';
 import { TopologyDataObject } from './topology-types';
 
 export type TopologyResourcePanelProps = {
@@ -13,7 +13,7 @@ const TopologyResourcePanel: React.FC<TopologyResourcePanelProps> = ({ item }) =
   // adds extra check, custom sidebar for all knative resources excluding deployment
   const itemKind = _.get(item, 'data.kind', null);
   if (_.get(item, 'data.isKnativeResource', false) && itemKind && itemKind !== 'Deployment') {
-    return <KnativeOverviewPage item={item.resources} />;
+    return <KnativeResourceOverviewPage item={item.resources} />;
   }
   return (
     resourceItemToShowOnSideBar && (
