@@ -1,7 +1,8 @@
 import { ComponentType } from 'react';
 import { FirehoseResult, KebabOption } from '@console/internal/components/utils';
 import { ExtPodKind, OverviewItem, PodControllerOverviewItem } from '@console/shared';
-import { DeploymentKind, K8sResourceKind, PodKind } from '@console/internal/module/k8s';
+import { DeploymentKind, K8sResourceKind, PodKind, EventKind } from '@console/internal/module/k8s';
+import { ClusterServiceVersionKind } from '@console/operator-lifecycle-manager';
 import { Pipeline, PipelineRun } from '../../utils/pipeline-augment';
 
 export type Point = [number, number];
@@ -17,6 +18,7 @@ export interface TopologyDataResources {
   buildConfigs: FirehoseResult;
   builds: FirehoseResult;
   daemonSets?: FirehoseResult;
+  secrets?: FirehoseResult;
   ksroutes?: FirehoseResult;
   configurations?: FirehoseResult;
   revisions?: FirehoseResult;
@@ -29,8 +31,9 @@ export interface TopologyDataResources {
   eventSourceApiServer?: FirehoseResult;
   eventSourceCamel?: FirehoseResult;
   eventSourceKafka?: FirehoseResult;
-  clusterServiceVersion?: FirehoseResult;
+  clusterServiceVersions?: FirehoseResult;
   serviceBindingRequests?: FirehoseResult;
+  events?: FirehoseResult<EventKind[]>;
 }
 
 export interface Node {
@@ -46,7 +49,7 @@ export interface Edge {
   type?: string;
   source: string;
   target: string;
-  data?: { sbr?: K8sResourceKind };
+  data?: {};
 }
 
 export interface Group {
@@ -84,6 +87,7 @@ export interface TopologyDataObject<D = {}> {
   pods?: ExtPodKind[];
   data: D;
   operatorBackedService: boolean;
+  groupResources?: TopologyDataObject[];
 }
 
 export interface TopologyApplicationObject {
@@ -107,6 +111,7 @@ export interface WorkloadData {
   build: K8sResourceKind;
   donutStatus: DonutStatusData;
   connectedPipeline: ConnectedWorkloadPipeline;
+  showPodCount?: boolean;
 }
 
 export interface DonutStatusData {
@@ -117,6 +122,10 @@ export interface DonutStatusData {
   isRollingOut: boolean;
 }
 
+export type OperatorBackedServiceKindMap = {
+  [name: string]: ClusterServiceVersionKind;
+};
+
 export interface GraphApi {
   zoomIn(): void;
   zoomOut(): void;
@@ -199,6 +208,33 @@ export type GroupProps = ViewGroup &
     groupRef(element: GroupElementInterface): void;
   };
 
+export type TrafficData = {
+  nodes: KialiNode[];
+  edges: KialiEdge[];
+};
+
+export type KialiNode = {
+  data: {
+    id: string;
+    nodeType: string;
+    namespace: string;
+    workload: string;
+    app: string;
+    version?: string;
+    destServices?: { [key: string]: any }[];
+    traffic?: { [key: string]: any }[];
+  };
+};
+
+export type KialiEdge = {
+  data: {
+    id: string;
+    source: string;
+    target: string;
+    traffic: { [key: string]: any };
+  };
+};
+
 export type NodeProvider = (type: string) => ComponentType<NodeProps>;
 
 export type EdgeProvider = (type: string) => ComponentType<EdgeProps>;
@@ -210,3 +246,8 @@ export type ActionProvider = (type: GraphElementType, id: string) => KebabOption
 export type ContextMenuProvider = {
   open: (type: GraphElementType, id: string, eventX: number, eventY: number) => boolean;
 };
+
+export type GraphData = {
+  namespace: string;
+  createResourceAccess: string[];
+};
