@@ -1,6 +1,7 @@
 import * as _ from 'lodash';
 import {
   K8sKind,
+  k8sGet,
   k8sList,
   k8sPatch,
   k8sKill,
@@ -9,6 +10,7 @@ import {
   k8sCreate,
   LabelSelector,
   referenceFor,
+  referenceForModel,
 } from '@console/internal/module/k8s';
 import {
   ImageStreamModel,
@@ -21,6 +23,10 @@ import {
   DaemonSetModel,
   StatefulSetModel,
 } from '@console/internal/models';
+import {
+  ClusterServiceVersionKind,
+  ClusterServiceVersionModel,
+} from '@console/operator-lifecycle-manager';
 import {
   ServiceModel as KnativeServiceModel,
   RouteModel as KnativeRouteModel,
@@ -31,11 +37,28 @@ import {
   EventSourceKafkaModel,
 } from '@console/knative-plugin';
 import { checkAccess } from '@console/internal/components/utils';
-import { TopologyDataObject } from '../components/topology/topology-types';
+import {
+  OperatorBackedServiceKindMap,
+  TopologyDataObject,
+} from '../components/topology/topology-types';
 import { detectGitType } from '../components/import/import-validation-utils';
 import { GitTypes } from '../components/import/import-types';
+import { CREATE_APPLICATION_KEY, UNASSIGNED_KEY } from '../const';
 import { ServiceBindingRequestModel } from '../models';
 
+export const sanitizeApplicationValue = (
+  application: string,
+  applicationType: string = application,
+): string => {
+  switch (applicationType) {
+    case UNASSIGNED_KEY:
+    case CREATE_APPLICATION_KEY:
+      return '';
+    default:
+      return application;
+  }
+};
+
 export const edgesFromAnnotations = (annotations): string[] => {
   let edges: string[] = [];
   if (_.has(annotations, ['app.openshift.io/connects-to'])) {
@@ -184,10 +207,10 @@ const updateItemAppConnectTo = (
   connectValue: string,
   oldValue: string = undefined,
 ) => {
-  const model = modelFor(referenceFor(item));
+  const model = modelFor(referenceFor(item) || item.kind);
 
   if (!model) {
-    return Promise.reject();
+    return Promise.reject(new Error(`Unable to retrieve model for: ${item.kind}`));
   }
 
   const tags = _.toPairs(item.metadata.annotations);
@@ -234,7 +257,7 @@ const updateItemAppConnectTo = (
 export const createServiceBinding = (
   source: K8sResourceKind,
   target: K8sResourceKind,
-): Promise<any> => {
+): Promise<K8sResourceKind> => {
   if (!source || !target || source === target) {
     return Promise.reject();
   }
@@ -286,7 +309,7 @@ export const createResourceConnection = (
   source: K8sResourceKind,
   target: K8sResourceKind,
   replacedTarget: K8sResourceKind = null,
-): Promise<any> => {
+): Promise<K8sResourceKind[] | K8sResourceKind> => {
   if (!source || !target || source === target) {
     return Promise.reject();
   }
@@ -303,7 +326,9 @@ export const createResourceConnection = (
     );
   const instanceName = _.get(source, ['metadata', 'labels', 'app.kubernetes.io/instance']);
 
-  const patches: Promise<any>[] = [updateItemAppConnectTo(source, connectValue, replaceValue)];
+  const patches: Promise<K8sResourceKind>[] = [
+    updateItemAppConnectTo(source, connectValue, replaceValue),
+  ];
 
   // If there is no instance label, only update this item
   if (!instanceName) {
@@ -437,3 +462,76 @@ export const cleanUpWorkload = (
   });
   return Promise.all(reqs);
 };
+
+export const getOperatorBackedServiceKindMap = (
+  installedOperators: ClusterServiceVersionKind[],
+): OperatorBackedServiceKindMap => {
+  let operatorBackedServiceKindMap: OperatorBackedServiceKindMap = {};
+  if (installedOperators) {
+    operatorBackedServiceKindMap = installedOperators.reduce((kindMap, csv) => {
+      (csv?.spec?.customresourcedefinitions?.owned || []).forEach((crd) => {
+        if (!(crd.kind in kindMap)) {
+          kindMap[crd.kind] = csv;
+        }
+      });
+      return kindMap;
+    }, {});
+  }
+
+  return operatorBackedServiceKindMap;
+};
+
+export const doContextualBinding = async (
+  resources: K8sResourceKind[],
+  contextualSource: string,
+  serviceBindingAvailable: boolean = false,
+): Promise<K8sResourceKind[]> => {
+  if (!contextualSource) {
+    return Promise.reject(new Error('Cannot do a contextual binding without a source'));
+  }
+
+  const linkingModelRefs = [
+    referenceForModel(DeploymentConfigModel),
+    referenceForModel(DeploymentModel),
+  ];
+  const newResource: K8sResourceKind = resources.find((resource) =>
+    linkingModelRefs.includes(referenceFor(resource)),
+  );
+
+  if (!newResource) {
+    // Not a resource we want to connect to
+    return resources;
+  }
+
+  const {
+    metadata: { namespace },
+  } = newResource;
+  const [groupVersionKind, resourceName] = contextualSource.split('/');
+  const contextualResource: K8sResourceKind = await k8sGet(
+    modelFor(groupVersionKind),
+    resourceName,
+    namespace,
+  );
+
+  if (!contextualResource) {
+    return Promise.reject(
+      new Error(`Cannot find resource (${contextualSource}) to do a contextual binding to`),
+    );
+  }
+
+  if (serviceBindingAvailable) {
+    const operatorBackedServiceKindMap = getOperatorBackedServiceKindMap(
+      await k8sList(ClusterServiceVersionModel, { ns: namespace }),
+    );
+    const ownerResourceKind = newResource?.metadata?.ownerReferences?.[0]?.kind;
+    const isOperatorBacked = ownerResourceKind in operatorBackedServiceKindMap;
+
+    if (isOperatorBacked) {
+      await createServiceBinding(contextualResource, newResource);
+    }
+  }
+
+  await createResourceConnection(contextualResource, newResource);
+
+  return resources;
+};
