@@ -1,6 +1,5 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import { ListGroup } from 'patternfly-react';
 import { K8sResourceKind, referenceForModel } from '@console/internal/module/k8s';
 import {
   ResourceLink,
@@ -14,14 +13,14 @@ export type EventSinkServicesOverviewListProps = {
 };
 
 const EventSinkServicesOverviewList: React.FC<EventSinkServicesOverviewListProps> = ({ obj }) => {
-  const sink = _.get(obj, 'spec.sink', null);
+  const sink = _.get(obj, 'spec.sink.ref') || _.get(obj, 'spec.sink');
   const sinkUri = _.get(obj, 'status.sinkUri', null);
   const namespace = _.get(obj, 'metadata.namespace', null);
   return (
     <>
       <SidebarSectionHeading text="Knative Services" />
       {sink && sink.kind === ServiceModel.kind ? (
-        <ListGroup componentClass="ul">
+        <ul className="list-group">
           <li className="list-group-item">
             <ResourceLink
               kind={referenceForModel(ServiceModel)}
@@ -39,7 +38,7 @@ const EventSinkServicesOverviewList: React.FC<EventSinkServicesOverviewListProps
               </>
             )}
           </li>
-        </ListGroup>
+        </ul>
       ) : (
         <span className="text-muted">No services found for this resource.</span>
       )}
