@@ -4,6 +4,7 @@ import { clickHorizontalTab } from '@console/internal-integration-tests/views/ho
 import { isLoaded, resourceTitle } from '@console/internal-integration-tests/views/crud.view';
 import { activeTab } from '../../views/detailView.view';
 import * as VmsListView from '../../views/vms.list.view';
+import { TAB } from '../utils/consts';
 
 export class DetailView {
   readonly name: string;
@@ -38,7 +39,23 @@ export class DetailView {
     await this.navigateToListView();
     await VmsListView.vmListByName(this.name).click();
     await isLoaded();
-    await clickHorizontalTab('Overview');
+    await clickHorizontalTab(TAB.Details);
+    await isLoaded();
+  }
+
+  async navigateToDashboard() {
+    await this.navigateToListView();
+    await VmsListView.vmListByName(this.name).click();
+    await isLoaded();
+    await clickHorizontalTab(TAB.Overview);
+    await isLoaded();
+  }
+
+  async navigateToConsoles() {
+    await this.navigateToListView();
+    await VmsListView.vmListByName(this.name).click();
+    await isLoaded();
+    await clickHorizontalTab(TAB.Consoles);
     await isLoaded();
   }
 
