@@ -1,7 +1,19 @@
 import { testName } from '@console/internal-integration-tests/protractor.conf';
-import { CloudInitConfig } from './types';
-import { STORAGE_CLASS, COMMON_TEMPLATES_VERSION } from './consts';
-import { getRandomMacAddress } from './utils';
+import { CloudInitConfig, BaseVMConfig, StorageResource } from './types';
+import {
+  STORAGE_CLASS,
+  COMMON_TEMPLATES_VERSION,
+  NIC_MODEL,
+  NIC_TYPE,
+  DISK_INTERFACE,
+  KUBEVIRT_STORAGE_CLASS_DEFAULTS,
+  KUBEVIRT_PROJECT_NAME,
+  COMMON_TEMPLATES_NAMESPACE,
+  COMMON_TEMPLATES_REVISION,
+  DISK_SOURCE,
+} from './consts';
+import { getRandomMacAddress, getResourceObject, resolveStorageDataAttribute } from './utils';
+import { Flavor, OperatingSystem, WorkloadProfile } from './constants/wizard';
 
 export const multusNAD = {
   apiVersion: 'k8s.cni.cncf.io/v1',
@@ -45,37 +57,71 @@ export const dataVolumeManifest = ({ name, namespace, sourceURL, accessMode, vol
   };
 };
 
-export const basicVMConfig = {
-  operatingSystem: 'Red Hat Enterprise Linux 7.6',
-  flavor: 'tiny',
-  workloadProfile: 'desktop',
-  sourceURL: 'https://download.cirros-cloud.net/0.4.0/cirros-0.4.0-x86_64-disk.img',
+export const basicVMConfig: BaseVMConfig = {
+  operatingSystem: OperatingSystem.RHEL7_6,
+  flavor: Flavor.TINY,
+  workloadProfile: WorkloadProfile.DESKTOP,
+  sourceURL:
+    'http://cnv-qe-server.rhevdev.lab.eng.rdu2.redhat.com/files/files-https/cirros/cirros-qcow2.img',
   sourceContainer: 'kubevirt/cirros-registry-disk-demo',
-  cloudInitScript: `#cloud-config\nuser: cloud-user\npassword: atomic\nchpasswd: {expire: False}\nhostname: vm-${testName}.example.com`,
+  cloudInitScript: `#cloud-config\nuser: cloud-user\npassword: atomic\nchpasswd: {expire: False}\nhostname: vm-${testName}`,
 };
 
-export const networkInterface = {
+export const defaultWizardPodNetworkingInterface = {
+  name: 'nic0',
+  mac: '-',
+  model: NIC_MODEL.VirtIO,
+  type: NIC_TYPE.masquerade,
+  network: 'Pod Networking',
+};
+
+export const defaultYAMLPodNetworkingInterface = {
+  name: 'default',
+  mac: '-',
+  model: NIC_MODEL.VirtIO,
+  type: NIC_TYPE.masquerade,
+  network: 'Pod Networking',
+};
+
+// Fake windows machine, still cirros in the heart
+export const widowsVMConfig: BaseVMConfig = {
+  operatingSystem: OperatingSystem.WINDOWS_10,
+  flavor: Flavor.MEDIUM,
+  workloadProfile: WorkloadProfile.DESKTOP,
+  sourceURL:
+    'http://cnv-qe-server.rhevdev.lab.eng.rdu2.redhat.com/files/files-https/cirros/cirros-qcow2.img',
+  sourceContainer: 'kubevirt/cirros-registry-disk-demo',
+  cloudInitScript: `#cloud-config\nuser: cloud-user\npassword: atomic\nchpasswd: {expire: False}\nhostname: vm-${testName}`, // reusing cirros
+};
+
+export const multusNetworkInterface = {
   name: `nic1-${testName.slice(-5)}`,
+  model: NIC_MODEL.VirtIO,
   mac: getRandomMacAddress(),
-  binding: 'bridge',
-  networkDefinition: multusNAD.metadata.name,
+  type: NIC_TYPE.bridge,
+  network: multusNAD.metadata.name,
 };
 
-export const networkBindingMethods = {
-  masquerade: 'masquerade',
-  bridge: 'bridge',
-  sriov: 'sriov',
-};
-
-export const rootDisk = {
+export const rootDisk: StorageResource = {
   name: 'rootdisk',
   size: '1',
+  interface: DISK_INTERFACE.VirtIO,
   storageClass: `${STORAGE_CLASS}`,
 };
 
-export const hddDisk = {
+export const cdGuestTools: StorageResource = {
+  source: DISK_SOURCE.Container,
+  interface: DISK_INTERFACE.VirtIO,
+  storageClass: `${STORAGE_CLASS}`,
+  sourceConfig: {
+    container: 'kubevirt/virtio-container-disk',
+  },
+};
+
+export const hddDisk: StorageResource = {
   name: `disk-${testName.slice(-5)}`,
-  size: '2',
+  size: '1',
+  interface: DISK_INTERFACE.VirtIO,
   storageClass: `${STORAGE_CLASS}`,
 };
 
@@ -85,11 +131,12 @@ export const cloudInitCustomScriptConfig: CloudInitConfig = {
   customScript: basicVMConfig.cloudInitScript,
 };
 
-export function getVMManifest(
-  provisionSource: string,
+function getMetadata(
+  provisionSource: 'URL' | 'PXE' | 'Container',
   namespace: string,
   name?: string,
   cloudinit?: string,
+  finalizers?: [string],
 ) {
   const vmName = name || `${provisionSource.toLowerCase()}-${namespace.slice(-5)}`;
   const metadata = {
@@ -98,14 +145,15 @@ export function getVMManifest(
       'name.os.template.kubevirt.io/rhel7.6': 'Red Hat Enterprise Linux 7.6',
       description: namespace,
     },
+    finalizers,
     namespace,
     labels: {
       app: vmName,
       'flavor.template.kubevirt.io/tiny': 'true',
       'os.template.kubevirt.io/rhel7.6': 'true',
-      'vm.kubevirt.io/template': `rhel7-desktop-tiny-${COMMON_TEMPLATES_VERSION}`,
-      'vm.kubevirt.io/template-namespace': 'openshift',
-      'vm.kubevirt.io/template.revision': '1',
+      'vm.kubevirt.io/template': `rhel7-desktop-${basicVMConfig.flavor}-${COMMON_TEMPLATES_VERSION}`,
+      'vm.kubevirt.io/template.namespace': COMMON_TEMPLATES_NAMESPACE,
+      'vm.kubevirt.io/template.revision': COMMON_TEMPLATES_REVISION,
       'vm.kubevirt.io/template.version': COMMON_TEMPLATES_VERSION,
       'workload.template.kubevirt.io/desktop': 'true',
     },
@@ -115,14 +163,20 @@ export function getVMManifest(
       url: basicVMConfig.sourceURL,
     },
   };
+  const kubevirtStorage = getResourceObject(
+    KUBEVIRT_STORAGE_CLASS_DEFAULTS,
+    KUBEVIRT_PROJECT_NAME,
+    'configMap',
+  );
   const dataVolumeTemplate = {
     metadata: {
       name: `${metadata.name}-rootdisk`,
     },
     spec: {
       pvc: {
-        accessModes: ['ReadWriteMany'],
-        volumeMode: 'Block',
+        accessModes: [resolveStorageDataAttribute(kubevirtStorage, 'accessMode')],
+        volumeMode: resolveStorageDataAttribute(kubevirtStorage, 'volumeMode'),
+        dataSource: null,
         resources: {
           requests: {
             storage: '1Gi',
@@ -195,6 +249,88 @@ export function getVMManifest(
       throw Error('Provision source not Implemented');
   }
 
+  const vmiSpec = {
+    domain: {
+      cpu: {
+        cores: 1,
+        sockets: 1,
+        threads: 1,
+      },
+      devices: {
+        disks,
+        inputs: [
+          {
+            bus: 'virtio',
+            name: 'tablet',
+            type: 'tablet',
+          },
+        ],
+        interfaces: [
+          {
+            bootOrder: 2,
+            masquerade: {},
+            name: 'nic0',
+            model: 'virtio',
+          },
+        ],
+        rng: {},
+      },
+      resources: {
+        requests: {
+          memory: '1073741824',
+        },
+      },
+    },
+    evictionStrategy: 'LiveMigrate',
+    terminationGracePeriodSeconds: 0,
+    networks: [
+      {
+        name: 'nic0',
+        pod: {},
+      },
+    ],
+    volumes,
+  };
+
+  return {
+    metadata,
+    dataVolumeTemplates,
+    vmiSpec,
+  };
+}
+
+export function getVMIManifest(
+  provisionSource: 'URL' | 'PXE' | 'Container',
+  namespace: string,
+  name?: string,
+  cloudinit?: string,
+) {
+  const { metadata, vmiSpec } = getMetadata(provisionSource, namespace, name, cloudinit);
+
+  const vmiResource = {
+    apiVersion: 'kubevirt.io/v1alpha3',
+    kind: 'VirtualMachineInstance',
+    metadata,
+    spec: vmiSpec,
+  };
+
+  return vmiResource;
+}
+
+export function getVMManifest(
+  provisionSource: 'URL' | 'PXE' | 'Container',
+  namespace: string,
+  name?: string,
+  cloudinit?: string,
+) {
+  const { metadata, dataVolumeTemplates, vmiSpec } = getMetadata(
+    provisionSource,
+    namespace,
+    name,
+    cloudinit,
+    ['k8s.v1.cni.cncf.io/kubeMacPool'],
+  );
+
   const vmResource = {
     apiVersion: 'kubevirt.io/v1alpha3',
     kind: 'VirtualMachine',
@@ -206,53 +342,29 @@ export function getVMManifest(
         metadata: {
           labels: {
             'kubevirt.io/domain': metadata.name,
-            'kubevirt.io/size': 'tiny',
+            'kubevirt.io/size': basicVMConfig.flavor,
             'vm.kubevirt.io/name': metadata.name,
           },
         },
-        spec: {
-          domain: {
-            cpu: {
-              cores: 1,
-              sockets: 1,
-              threads: 1,
-            },
-            devices: {
-              disks,
-              inputs: [
-                {
-                  bus: 'virtio',
-                  name: 'tablet',
-                  type: 'tablet',
-                },
-              ],
-              interfaces: [
-                {
-                  bootOrder: 2,
-                  masquerade: {},
-                  name: 'nic0',
-                },
-              ],
-              rng: {},
-            },
-            resources: {
-              requests: {
-                memory: '1G',
-              },
-            },
-          },
-          evictionStrategy: 'LiveMigrate',
-          terminationGracePeriodSeconds: 0,
-          networks: [
-            {
-              name: 'nic0',
-              pod: {},
-            },
-          ],
-          volumes,
-        },
+        spec: vmiSpec,
       },
     },
   };
+
   return vmResource;
 }
+
+export const datavolumeClonerClusterRole = {
+  apiVersion: 'rbac.authorization.k8s.io/v1',
+  kind: 'ClusterRole',
+  metadata: {
+    name: 'datavolume-cloner',
+  },
+  rules: [
+    {
+      apiGroups: ['cdi.kubevirt.io'],
+      resources: ['datavolumes/source'],
+      verbs: ['*'],
+    },
+  ],
+};
