@@ -1,15 +1,22 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { compose } from 'redux';
 import { connect } from 'react-redux';
-import { createVm, createVmTemplate } from 'kubevirt-web-ui-components';
+import { createVm as importVM } from 'kubevirt-web-ui-components';
 import { Wizard, WizardStep } from '@patternfly/react-core';
+import { FLAGS } from '@console/shared';
+import {
+  featureReducerName,
+  connectToFlags,
+  FlagsObject,
+} from '@console/internal/reducers/features';
 import { TemplateModel } from '@console/internal/models';
 import { Firehose, history, units } from '@console/internal/components/utils';
 import { k8sGet, TemplateKind } from '@console/internal/module/k8s';
 import { Location } from 'history';
 import { match as RouterMatch } from 'react-router';
 import { withReduxID } from '../../utils/redux/common';
-import { VirtualMachineModel } from '../../models';
+import { DataVolumeModel, VirtualMachineModel } from '../../models';
 import {
   TEMPLATE_TYPE_BASE,
   TEMPLATE_TYPE_LABEL,
@@ -31,9 +38,9 @@ import { NetworkWrapper } from '../../k8s/wrapper/vm/network-wrapper';
 import { NetworkInterfaceWrapper } from '../../k8s/wrapper/vm/network-interface-wrapper';
 import { VolumeWrapper } from '../../k8s/wrapper/vm/volume-wrapper';
 import { DiskWrapper } from '../../k8s/wrapper/vm/disk-wrapper';
-import { DataVolumeWrapper } from '../../k8s/wrapper/vm/data-volume-wrapper';
+import { MutableDataVolumeWrapper } from '../../k8s/wrapper/vm/data-volume-wrapper';
 import {
-  getDefaultSCAccessMode,
+  getDefaultSCAccessModes,
   getDefaultSCVolumeMode,
 } from '../../selectors/config-map/sc-defaults';
 import { getStorageClassConfigMap } from '../../k8s/requests/config-map/storage-class';
@@ -45,6 +52,7 @@ import {
   CloudInitDataHelper,
   CloudInitDataFormKeys,
 } from '../../k8s/wrapper/vm/cloud-init-data-helper';
+import { createVM, createVMTemplate } from '../../k8s/requests/vm/create/create';
 import {
   ChangedCommonData,
   CommonData,
@@ -70,6 +78,7 @@ import { ReviewTab } from './tabs/review-tab/review-tab';
 import { ResultTab } from './tabs/result-tab/result-tab';
 import { StorageTab } from './tabs/storage-tab/storage-tab';
 import { CloudInitTab } from './tabs/cloud-init-tab/cloud-init-tab';
+import { VirtualHardwareTab } from './tabs/virtual-hardware-tab/virtual-hardware-tab';
 
 import './create-vm-wizard.scss';
 
@@ -137,7 +146,7 @@ const kubevirtInterOP = async ({
     ({ type, disk, volume, dataVolume, persistentVolumeClaim, importData }) => {
       const diskWrapper = DiskWrapper.initialize(disk);
       const volumeWrapper = VolumeWrapper.initialize(volume);
-      const dataVolumeWrapper = dataVolume && DataVolumeWrapper.initialize(dataVolume);
+      const dataVolumeWrapper = dataVolume && new MutableDataVolumeWrapper(dataVolume, true);
       const persistentVolumeClaimWrapper =
         persistentVolumeClaim && PersistentVolumeClaimWrapper.initialize(persistentVolumeClaim);
 
@@ -147,23 +156,21 @@ const kubevirtInterOP = async ({
           VMWizardStorageType.V2V_VMWARE_IMPORT,
           VMWizardStorageType.V2V_VMWARE_IMPORT_TEMP,
         ].includes(type);
-      const resolveType = () => {
+      const resolveType = (dv) => {
         if (type === VMWizardStorageType.V2V_VMWARE_IMPORT) {
           return 'external-import';
         }
         if (type === VMWizardStorageType.V2V_VMWARE_IMPORT_TEMP) {
           return 'external-v2v-temp';
         }
-        return volumeWrapper.getType() === VolumeType.DATA_VOLUME && dataVolume
-          ? 'datavolume'
-          : undefined;
+        return volumeWrapper.getType() === VolumeType.DATA_VOLUME && dv ? 'datavolume' : undefined;
       };
 
       if (isImport) {
         return {
           name: diskWrapper.getName(),
           isBootable: diskWrapper.isFirstBootableDevice(),
-          storageType: resolveType(),
+          storageType: resolveType(dataVolume),
           size: persistentVolumeClaimWrapper.getSize().value,
           unit: persistentVolumeClaimWrapper.getSize().unit,
           storageClass: persistentVolumeClaimWrapper.getStorageClassName(),
@@ -171,32 +178,24 @@ const kubevirtInterOP = async ({
         };
       }
 
+      let finalDataVolume;
+      if (dataVolumeWrapper) {
+        finalDataVolume = dataVolumeWrapper
+          .assertDefaultModes(
+            getDefaultSCVolumeMode(storageClassConfigMap, dataVolumeWrapper.getStorageClassName()),
+            getDefaultSCAccessModes(storageClassConfigMap, dataVolumeWrapper.getStorageClassName()),
+          )
+          .asResource();
+      }
+
       return {
         name: diskWrapper.getName(),
         isBootable: diskWrapper.isFirstBootableDevice(),
-        storageType: resolveType(),
+        storageType: resolveType(finalDataVolume),
         templateStorage: {
           volume,
           disk,
-          dataVolumeTemplate: dataVolumeWrapper
-            ? DataVolumeWrapper.mergeWrappers(
-                dataVolumeWrapper,
-                DataVolumeWrapper.initializeFromSimpleData({
-                  accessModes: dataVolumeWrapper.getAccessModes() || [
-                    getDefaultSCAccessMode(
-                      storageClassConfigMap,
-                      dataVolumeWrapper.getStorageClassName(),
-                    ),
-                  ],
-                  volumeMode:
-                    dataVolumeWrapper.getVolumeMode() ||
-                    getDefaultSCVolumeMode(
-                      storageClassConfigMap,
-                      dataVolumeWrapper.getStorageClassName(),
-                    ),
-                }),
-              ).asResource()
-            : undefined,
+          dataVolumeTemplate: finalDataVolume,
         },
       };
     },
@@ -268,7 +267,7 @@ export class CreateVMWizardComponent extends React.Component<CreateVMWizardCompo
 
   finish = async () => {
     this.props.onResultsChanged({ errors: [], requestResults: [] }, null, true, true); // reset
-    const create = this.props.isCreateTemplate ? createVmTemplate : createVm;
+    const { isCreateTemplate, activeNamespace, isProviderImport, openshiftFlag } = this.props;
 
     const enhancedK8sMethods = new EnhancedK8sMethods();
     const vmSettings = iGetIn(this.props.stepData, [VMWizardTab.VM_SETTINGS, 'value']).toJS();
@@ -278,30 +277,47 @@ export class CreateVMWizardComponent extends React.Component<CreateVMWizardCompo
     const storages = immutableListToShallowJS(
       iGetIn(this.props.stepData, [VMWizardTab.STORAGE, 'value']),
     );
-    const templates = immutableListToShallowJS(
-      concatImmutableLists(
-        iGetLoadedData(this.props[VMWizardProps.commonTemplates]),
-        iGetLoadedData(this.props[VMWizardProps.userTemplates]),
-      ),
-    );
 
-    const { interOPVMSettings, interOPNetworks, interOPStorages } = await kubevirtInterOP({
-      vmSettings,
-      networks,
-      storages,
-      templates,
-      activeNamespace: this.props.activeNamespace,
-    });
+    const iUserTemplates = iGetLoadedData(this.props[VMWizardProps.userTemplates]);
+    const iCommonTemplates = iGetLoadedData(this.props[VMWizardProps.commonTemplates]);
+    let promise;
 
-    create(
-      enhancedK8sMethods,
-      templates,
-      interOPVMSettings,
-      interOPNetworks,
-      interOPStorages,
-      [],
-      units,
-    )
+    if (isProviderImport) {
+      const templates = immutableListToShallowJS<TemplateKind>(
+        concatImmutableLists(iUserTemplates, iCommonTemplates),
+      );
+      const { interOPVMSettings, interOPNetworks, interOPStorages } = await kubevirtInterOP({
+        vmSettings,
+        networks,
+        storages,
+        templates,
+        activeNamespace,
+      });
+
+      promise = importVM(
+        enhancedK8sMethods,
+        templates,
+        interOPVMSettings,
+        interOPNetworks,
+        interOPStorages,
+        [],
+        units,
+      );
+    } else {
+      const create = isCreateTemplate ? createVMTemplate : createVM;
+      promise = create({
+        enhancedK8sMethods,
+        vmSettings,
+        networks,
+        storages,
+        iUserTemplates,
+        iCommonTemplates,
+        namespace: activeNamespace,
+        openshiftFlag,
+      });
+    }
+
+    promise
       .then(() => getResults(enhancedK8sMethods))
       .catch((error) => cleanupAndGetResults(enhancedK8sMethods, error))
       .then(({ requestResults, errors, mainError, isValid }: ResultsWrapper) =>
@@ -357,6 +373,15 @@ export class CreateVMWizardComponent extends React.Component<CreateVMWizardCompo
               </>
             ),
           },
+          {
+            id: VMWizardTab.ADVANCED_VIRTUAL_HARDWARE,
+            component: (
+              <>
+                <ResourceLoadErrors wizardReduxID={reduxID} />
+                <VirtualHardwareTab wizardReduxID={reduxID} />
+              </>
+            ),
+          },
         ],
       },
       {
@@ -483,38 +508,49 @@ export const CreateVMWizardPageComponent: React.FC<CreateVMWizardPageComponentPr
   reduxID,
   match,
   location,
+  flags,
 }) => {
   const activeNamespace = match && match.params && match.params.ns;
   const path = (match && match.path) || '';
   const search = location && location.search;
+
   const resources = [
     getResource(VirtualMachineModel, {
       namespace: activeNamespace,
       prop: VMWizardProps.virtualMachines,
     }),
-    getResource(TemplateModel, {
+    getResource(DataVolumeModel, {
       namespace: activeNamespace,
-      prop: VMWizardProps.userTemplates,
-      matchLabels: { [TEMPLATE_TYPE_LABEL]: TEMPLATE_TYPE_VM },
-    }),
-    getResource(TemplateModel, {
-      namespace: 'openshift',
-      prop: VMWizardProps.commonTemplates,
-      matchLabels: { [TEMPLATE_TYPE_LABEL]: TEMPLATE_TYPE_BASE },
+      prop: VMWizardProps.dataVolumes,
     }),
   ];
 
+  if (flags[FLAGS.OPENSHIFT]) {
+    resources.push(
+      getResource(TemplateModel, {
+        namespace: activeNamespace,
+        prop: VMWizardProps.userTemplates,
+        matchLabels: { [TEMPLATE_TYPE_LABEL]: TEMPLATE_TYPE_VM },
+      }),
+      getResource(TemplateModel, {
+        namespace: 'openshift',
+        prop: VMWizardProps.commonTemplates,
+        matchLabels: { [TEMPLATE_TYPE_LABEL]: TEMPLATE_TYPE_BASE },
+      }),
+    );
+  }
+
   const dataIDReferences = makeIDReferences(resources);
 
   dataIDReferences[VMWizardProps.activeNamespace] = ['UI', 'activeNamespace'];
+  dataIDReferences[VMWizardProps.openshiftFlag] = [featureReducerName, FLAGS.OPENSHIFT];
 
   return (
-    <Firehose resources={resources}>
+    <Firehose resources={resources} doNotConnectToState>
       <CreateVMWizard
         isCreateTemplate={!path.includes('/virtualmachines/')}
         isProviderImport={new URLSearchParams(search).get('mode') === 'import'}
         dataIDReferences={dataIDReferences}
-        activeNamespace={activeNamespace}
         reduxID={reduxID}
         onClose={() => history.goBack()}
       />
@@ -526,6 +562,10 @@ type CreateVMWizardPageComponentProps = {
   reduxID?: string;
   location?: Location;
   match?: RouterMatch<{ ns: string; plural: string; appName?: string }>;
+  flags: FlagsObject;
 };
 
-export const CreateVMWizardPage = withReduxID(CreateVMWizardPageComponent);
+export const CreateVMWizardPage = compose(
+  connectToFlags(FLAGS.OPENSHIFT),
+  withReduxID,
+)(CreateVMWizardPageComponent);
