@@ -1,11 +1,14 @@
 import { CloudInitField } from '../../types';
+import { InitialStepStateGetter } from './types';
 
-export const getCloudInitInitialState = () => ({
+export const getCloudInitInitialState: InitialStepStateGetter = () => ({
   value: {
     [CloudInitField.IS_FORM]: {
       value: true,
     },
   },
+  error: null,
   isValid: true,
   hasAllRequiredFilled: true,
+  isLocked: false,
 });
