@@ -1,10 +1,13 @@
 import { ValidationObject } from '@console/shared';
-import { VMLikeEntityKind } from '../../types';
+import { VMLikeEntityKind } from '../../types/vmLike';
 import { CombinedDisk } from '../../k8s/wrapper/vm/combined-disk';
+import { UIDiskValidation } from '../../utils/validations/vm/types';
+import { TemplateValidations } from '../../utils/validations/template/template-validations';
 
 export type StorageSimpleData = {
   name?: string;
-  type?: string;
+  content?: string;
+  source?: string;
   diskInterface?: string;
   size?: string;
   storageClass?: string;
@@ -12,7 +15,8 @@ export type StorageSimpleData = {
 
 export type StorageSimpleDataValidation = {
   name?: ValidationObject;
-  type?: ValidationObject;
+  content?: ValidationObject;
+  source?: ValidationObject;
   diskInterface?: ValidationObject;
   size?: ValidationObject;
   storageClass?: ValidationObject;
@@ -20,10 +24,13 @@ export type StorageSimpleDataValidation = {
 
 export type StorageBundle = StorageSimpleData & {
   disk: CombinedDisk;
+  templateValidations?: TemplateValidations;
+  diskValidations?: UIDiskValidation;
 };
 
 export type VMStorageRowActionOpts = {
   withProgress: (promise: Promise<any>) => void;
+  templateValidations?: TemplateValidations;
 };
 
 export type VMStorageRowCustomData = {
