@@ -9,3 +9,11 @@ export const diskTableColumnClasses = [
   classNames('col-lg-2'),
   Kebab.columnClass,
 ];
+
+export const cdTableColumnClasses = [
+  classNames('col-lg-3'),
+  classNames('col-lg-3'),
+  classNames('col-lg-3'),
+  classNames('col-lg-3'),
+  Kebab.columnClass,
+];
