@@ -3,9 +3,10 @@ import { Table } from '@console/internal/components/factory';
 import { sortable } from '@patternfly/react-table';
 import { useSafetyFirst } from '@console/internal/components/safety-first';
 import { createBasicLookup, dimensifyHeader } from '@console/shared';
+import { EmptyBox } from '@console/internal/components/utils';
 import { Button, ButtonVariant } from '@patternfly/react-core';
-import { VMLikeEntityKind } from '../../types';
-import { getInterfaces, getNetworks, asVM } from '../../selectors/vm';
+import { VMGenericLikeEntityKind } from '../../types/vmLike';
+import { isVMI } from '../../selectors/vm';
 import { VMLikeEntityTabProps } from '../vms/types';
 import { NetworkInterfaceWrapper } from '../../k8s/wrapper/vm/network-interface-wrapper';
 import { nicModalEnhanced } from '../modals/nic-modal/nic-modal-enhanced';
@@ -15,12 +16,18 @@ import { wrapWithProgress } from '../../utils/utils';
 import { NicRow } from './nic-row';
 import { NetworkBundle } from './types';
 import { nicTableColumnClasses } from './utils';
+import { asVMILikeWrapper } from '../../k8s/wrapper/utils/convert';
+import { ADD_NETWORK_INTERFACE } from '../../utils/strings';
 
-const getNicsData = (vmLikeEntity: VMLikeEntityKind): NetworkBundle[] => {
-  const vm = asVM(vmLikeEntity);
-  const networkLookup = createBasicLookup(getNetworks(vm), getSimpleName);
+const getNicsData = (vmLikeEntity: VMGenericLikeEntityKind): NetworkBundle[] => {
+  const vmiLikeWrapper = asVMILikeWrapper(vmLikeEntity);
 
-  return getInterfaces(vm).map((nic) => {
+  const networks = vmiLikeWrapper?.getNetworks() || [];
+  const interfaces = vmiLikeWrapper?.getInterfaces() || [];
+
+  const networkLookup = createBasicLookup(networks, getSimpleName);
+
+  return interfaces.map((nic) => {
     const network = networkLookup[nic.name];
     const interfaceWrapper = NetworkInterfaceWrapper.initialize(nic);
     const networkWrapper = NetworkWrapper.initialize(network);
@@ -44,6 +51,8 @@ export type VMNicsTableProps = {
   columnClasses: string[];
 };
 
+const NoDataEmptyMsg = () => <EmptyBox label="Network Interfaces" />;
+
 export const VMNicsTable: React.FC<VMNicsTableProps> = ({
   data,
   customData,
@@ -54,6 +63,7 @@ export const VMNicsTable: React.FC<VMNicsTableProps> = ({
     <Table
       aria-label="VM Nics List"
       data={data}
+      NoDataEmptyMsg={NoDataEmptyMsg}
       Header={() =>
         dimensifyHeader(
           [
@@ -102,25 +112,27 @@ export const VMNics: React.FC<VMLikeEntityTabProps> = ({ obj: vmLikeEntity }) =>
   const withProgress = wrapWithProgress(setIsLocked);
   return (
     <div className="co-m-list">
-      <div className="co-m-pane__filter-bar">
-        <div className="co-m-pane__filter-bar-group">
-          <Button
-            variant={ButtonVariant.primary}
-            id="create-nic-btn"
-            onClick={() =>
-              withProgress(
-                nicModalEnhanced({
-                  blocking: true,
-                  vmLikeEntity,
-                }).result,
-              )
-            }
-            isDisabled={isLocked}
-          >
-            Create Network Interface
-          </Button>
+      {!isVMI(vmLikeEntity) && (
+        <div className="co-m-pane__filter-bar">
+          <div className="co-m-pane__filter-bar-group">
+            <Button
+              variant={ButtonVariant.primary}
+              id="create-nic-btn"
+              onClick={() =>
+                withProgress(
+                  nicModalEnhanced({
+                    blocking: true,
+                    vmLikeEntity,
+                  }).result,
+                )
+              }
+              isDisabled={isLocked}
+            >
+              {ADD_NETWORK_INTERFACE}
+            </Button>
+          </div>
         </div>
-      </div>
+      )}
       <div className="co-m-pane__body">
         <VMNicsTable
           data={getNicsData(vmLikeEntity)}
