@@ -1,5 +1,4 @@
 import * as React from 'react';
-import { getServicesForVm } from 'kubevirt-web-ui-components';
 import {
   Firehose,
   StatusBox,
@@ -10,52 +9,75 @@ import {
   asAccessReview,
 } from '@console/internal/components/utils';
 import { getNamespace } from '@console/shared';
-import { K8sResourceKind, PodKind, TemplateKind } from '@console/internal/module/k8s';
+import { K8sKind, K8sResourceKind, PodKind, TemplateKind } from '@console/internal/module/k8s';
 import { ServiceModel } from '@console/internal/models';
 import { ServicesList } from '@console/internal/components/service';
 import { VMKind, VMIKind } from '../../types';
 import { getLoadedData, getResource } from '../../utils';
-import { VirtualMachineInstanceModel } from '../../models';
+import { VirtualMachineInstanceModel, VirtualMachineModel } from '../../models';
+import { getServicesForVmi } from '../../selectors/service';
 import { VMResourceSummary, VMDetailsList } from './vm-resource';
 import { VMTabProps } from './types';
+import { isVM, isVMI } from '../../selectors/vm/vmlike';
 
 export const VMDetailsFirehose: React.FC<VMTabProps> = ({
-  obj: vm,
-  vmi,
+  obj: objProp,
+  vm: vmProp,
+  vmi: vmiProp,
   pods,
   migrations,
   templates,
+  customData: { kindObj },
 }) => {
-  const resources = [getResource(ServiceModel, { namespace: getNamespace(vm), prop: 'services' })];
+  const vm =
+    kindObj === VirtualMachineModel && isVM(objProp) ? objProp : isVM(vmProp) ? vmProp : null;
+  const vmi =
+    kindObj === VirtualMachineInstanceModel && isVMI(objProp)
+      ? objProp
+      : isVMI(vmiProp)
+      ? vmiProp
+      : null;
+
+  const resources = [
+    getResource(ServiceModel, { namespace: getNamespace(objProp), prop: 'services' }),
+  ];
 
   return (
     <div className="co-m-pane__body">
       <Firehose resources={resources}>
-        <VMDetails vm={vm} vmi={vmi} pods={pods} migrations={migrations} templates={templates} />
+        <VMDetails
+          kindObj={kindObj}
+          vm={vm}
+          vmi={vmi}
+          pods={pods}
+          migrations={migrations}
+          templates={templates}
+        />
       </Firehose>
     </div>
   );
 };
 
 const VMDetails: React.FC<VMDetailsProps> = (props) => {
-  const { vm, vmi, pods, migrations, templates, ...restProps } = props;
+  const { kindObj, vm, vmi, pods, migrations, templates, ...restProps } = props;
   const mainResources = {
     vm,
     vmi,
     pods,
     migrations,
     templates,
+    kindObj,
   };
 
-  const vmServicesData = getServicesForVm(getLoadedData(props.services, []), vm);
-
-  const canUpdate = useAccessReview(asAccessReview(VirtualMachineInstanceModel, vm, 'patch'));
+  const vmiLike = kindObj === VirtualMachineModel ? vm : vmi;
+  const vmServicesData = getServicesForVmi(getLoadedData(props.services, []), vmi);
+  const canUpdate = useAccessReview(asAccessReview(kindObj, vmiLike || {}, 'patch')) && !!vmiLike;
 
   return (
-    <StatusBox data={vm} {...restProps}>
+    <StatusBox data={vmiLike} {...restProps}>
       <ScrollToTopOnMount />
       <div className="co-m-pane__body">
-        <SectionHeading text="VM Overview" />
+        <SectionHeading text={`${kindObj.label} Details`} />
         <div className="row">
           <div className="col-sm-6">
             <VMResourceSummary canUpdateVM={canUpdate} {...mainResources} />
@@ -74,10 +96,11 @@ const VMDetails: React.FC<VMDetailsProps> = (props) => {
 };
 
 type VMDetailsProps = {
-  vm: VMKind;
+  kindObj: K8sKind;
+  vm?: VMKind;
+  vmi?: VMIKind;
   pods?: PodKind[];
   migrations?: K8sResourceKind[];
-  vmi?: VMIKind;
   services?: FirehoseResult<K8sResourceKind[]>;
   templates?: TemplateKind[];
 };
