@@ -14,9 +14,12 @@ import {
   DashboardsInventoryItemGroup,
   ReduxReducer,
   ProjectDashboardInventoryItem,
+  DashboardsOverviewResourceActivity,
 } from '@console/plugin-sdk';
 import { DashboardsStorageCapacityDropdownItem } from '@console/ceph-storage-plugin';
+import { FLAGS } from '@console/shared/src/constants';
 import { TemplateModel, PodModel } from '@console/internal/models';
+import { getName } from '@console/shared/src/selectors/common';
 import * as models from './models';
 import { VMTemplateYAMLTemplates, VirtualMachineYAMLTemplates } from './models/templates';
 import { getKubevirtHealthState } from './components/dashboards-page/overview-dashboard/health';
@@ -41,7 +44,8 @@ type ConsumedExtensions =
   | DashboardsInventoryItemGroup
   | DashboardsStorageCapacityDropdownItem
   | ReduxReducer
-  | ProjectDashboardInventoryItem;
+  | ProjectDashboardInventoryItem
+  | DashboardsOverviewResourceActivity;
 
 export const FLAG_KUBEVIRT = 'KUBEVIRT';
 
@@ -66,9 +70,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Virtual Machines',
         resource: models.VirtualMachineModel.plural,
-        required: FLAG_KUBEVIRT,
       },
-      mergeAfter: 'Pods',
+      mergeBefore: 'Deployments',
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT],
     },
   },
   {
@@ -81,9 +87,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Virtual Machine Templates',
         resource: 'vmtemplates',
-        required: FLAG_KUBEVIRT,
       },
-      mergeAfter: 'Virtual Machines',
+      mergeBefore: 'Deployments',
+    },
+    flags: {
+      required: [FLAG_KUBEVIRT, FLAGS.OPENSHIFT],
     },
   },
   {
@@ -111,40 +119,18 @@ const plugin: Plugin<ConsumedExtensions> = [
       templateName: 'vm-template',
     },
   },
-  {
-    type: 'Page/Resource/Details',
-    properties: {
-      model: models.VirtualMachineModel,
-      loader: () =>
-        import('./components/vms/vm-details-page' /* webpackChunkName: "kubevirt" */).then(
-          (m) => m.VirtualMachinesDetailsPage,
-        ),
-    },
-  },
   {
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: ['/k8s/ns/:ns/vmtemplates', '/k8s/all-namespaces/vmtemplates'],
+      path: ['/k8s/ns/:ns/virtualmachines/~new'],
       loader: () =>
-        import('./components/vm-templates/vm-template' /* webpackChunkName: "kubevirt" */).then(
-          (m) => m.VirtualMachineTemplatesPage,
+        import('./components/vms/vm-create-yaml' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.VMCreateYAML,
         ),
       required: FLAG_KUBEVIRT,
     },
   },
-  {
-    type: 'Page/Route',
-    properties: {
-      exact: true,
-      path: ['/k8s/ns/:ns/vmtemplates/~new'],
-      loader: () =>
-        import(
-          './components/vm-templates/vm-template-create-yaml' /* webpackChunkName: "kubevirt" */
-        ).then((m) => m.CreateVMTemplateYAML),
-      required: FLAG_KUBEVIRT,
-    },
-  },
   {
     type: 'Page/Route',
     properties: {
@@ -157,6 +143,38 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: FLAG_KUBEVIRT,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      path: '/k8s/ns/:ns/virtualmachines/:name',
+      loader: () =>
+        import('./components/vms/vm-details-page' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.VirtualMachinesDetailsPage,
+        ),
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      path: '/k8s/ns/:ns/virtualmachineinstances/:name',
+      loader: () =>
+        import('./components/vms/vmi-details-page' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.VirtualMachinesInstanceDetailsPage,
+        ),
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/k8s/ns/:ns/vmtemplates/~new'],
+      loader: () =>
+        import(
+          './components/vm-templates/vm-template-create-yaml' /* webpackChunkName: "kubevirt" */
+        ).then((m) => m.CreateVMTemplateYAML),
+      required: FLAG_KUBEVIRT,
+    },
+  },
   {
     type: 'Page/Route',
     properties: {
@@ -180,13 +198,23 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: FLAG_KUBEVIRT,
     },
   },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: ['/k8s/ns/:ns/vmtemplates', '/k8s/all-namespaces/vmtemplates'],
+      loader: () =>
+        import('./components/vm-templates/vm-template' /* webpackChunkName: "kubevirt" */).then(
+          (m) => m.VirtualMachineTemplatesPage,
+        ),
+      required: FLAG_KUBEVIRT,
+    },
+  },
   {
     type: 'Dashboards/Overview/Health/URL',
     properties: {
       title: 'Virtualization',
-      url: `apis/subresources.${models.VirtualMachineModel.apiGroup}/${
-        models.VirtualMachineModel.apiVersion
-      }/healthz`,
+      url: `apis/subresources.${models.VirtualMachineModel.apiGroup}/${models.VirtualMachineModel.apiVersion}/healthz`,
       healthHandler: getKubevirtHealthState,
       required: FLAG_KUBEVIRT,
     },
@@ -194,11 +222,6 @@ const plugin: Plugin<ConsumedExtensions> = [
   {
     type: 'Dashboards/Overview/Inventory/Item',
     properties: {
-      resource: {
-        isList: true,
-        kind: models.VirtualMachineModel.kind,
-        prop: 'vms',
-      },
       additionalResources: [
         {
           isList: true,
@@ -275,6 +298,42 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: FLAG_KUBEVIRT,
     },
   },
+  {
+    type: 'Dashboards/Overview/Activity/Resource',
+    properties: {
+      k8sResource: {
+        isList: true,
+        kind: models.DataVolumeModel.kind,
+        prop: 'dvs',
+      },
+      isActivity: (resource) =>
+        resource?.status?.phase === 'ImportInProgress' &&
+        !!resource?.metadata?.ownerReferences?.[0],
+      getTimestamp: (resource) => new Date(resource.metadata.creationTimestamp),
+      loader: () =>
+        import(
+          './components/dashboards-page/overview-dashboard/activity' /* webpackChunkName: "kubevirt-activity" */
+        ).then((m) => m.DiskImportActivity),
+      required: FLAG_KUBEVIRT,
+    },
+  },
+  {
+    type: 'Dashboards/Overview/Activity/Resource',
+    properties: {
+      k8sResource: {
+        isList: true,
+        kind: PodModel.kind,
+        prop: 'pods',
+      },
+      isActivity: (resource) => getName(resource).startsWith('kubevirt-v2v-conversion'),
+      getTimestamp: (resource) => new Date(resource.metadata.creationTimestamp),
+      loader: () =>
+        import(
+          './components/dashboards-page/overview-dashboard/activity' /* webpackChunkName: "kubevirt-activity" */
+        ).then((m) => m.V2VImportActivity),
+      required: FLAG_KUBEVIRT,
+    },
+  },
 ];
 
 export default plugin;
