@@ -12,24 +12,14 @@ const getSCConfigMapAttribute = (
     storageClassName &&
     attributeName &&
     _.has(storageClassConfigMap, ['data', `${storageClassName}.${attributeName}`]);
-  return _.get(
-    storageClassConfigMap,
-    ['data', hasSubAttribute ? `${storageClassName}.${attributeName}` : attributeName],
-    defaultValue,
+  return (
+    _.get(storageClassConfigMap, [
+      'data',
+      hasSubAttribute ? `${storageClassName}.${attributeName}` : attributeName,
+    ]) || defaultValue
   );
 };
 
-export const getDefaultSCAccessMode = (
-  storageClassConfigMap: ConfigMapKind,
-  storageClassName: string,
-) =>
-  getSCConfigMapAttribute(
-    storageClassConfigMap,
-    storageClassName,
-    'accessMode',
-    PVC_ACCESSMODE_DEFAULT,
-  );
-
 export const getDefaultSCVolumeMode = (
   storageClassConfigMap: ConfigMapKind,
   storageClassName: string,
@@ -40,3 +30,17 @@ export const getDefaultSCVolumeMode = (
     'volumeMode',
     PVC_VOLUMEMODE_DEFAULT,
   );
+
+export const getDefaultSCAccessModes = (
+  storageClassConfigMap: ConfigMapKind,
+  storageClassName: string,
+) => {
+  return [
+    getSCConfigMapAttribute(
+      storageClassConfigMap,
+      storageClassName,
+      'accessMode',
+      PVC_ACCESSMODE_DEFAULT,
+    ),
+  ];
+};
