@@ -4,3 +4,5 @@ export * from './disk';
 export * from './nic';
 export * from './selectors';
 export * from './volume';
+export * from './vmlike';
+export * from './cpu';
