@@ -8,7 +8,7 @@ import { Helmet } from 'react-helmet';
 import { AddCircleOIcon } from '@patternfly/react-icons';
 import { Alert, Card, CardBody, CardFooter, CardHeader } from '@patternfly/react-core';
 import * as UIActions from '@console/internal/actions/ui';
-import { getName, Status, WarningStatus, getNamespace, getUID } from '@console/shared';
+import { ALL_NAMESPACES_KEY, Status, WarningStatus, getNamespace, getUID } from '@console/shared';
 import {
   DetailsPage,
   Table,
@@ -16,8 +16,7 @@ import {
   TableData,
   MultiListPage,
 } from '@console/internal/components/factory';
-import { ALL_NAMESPACES_KEY } from '@console/internal/const';
-import { withFallback } from '@console/internal/components/utils/error-boundary';
+import { withFallback } from '@console/shared/src/components/error/error-boundary';
 import {
   modelFor,
   referenceForModel,
@@ -59,6 +58,7 @@ import {
   PackageManifestModel,
   CatalogSourceModel,
   InstallPlanModel,
+  OperatorGroupModel,
 } from '../models';
 import {
   APIServiceDefinition,
@@ -66,39 +66,30 @@ import {
   ClusterServiceVersionKind,
   ClusterServiceVersionPhase,
   CRDDescription,
-  CSVConditionReason,
   InstallPlanKind,
   PackageManifestKind,
   SubscriptionKind,
-  SubscriptionState,
 } from '../types';
+import { subscriptionForCSV, getSubscriptionStatus } from '../status/csv-status';
+import { getInternalObjects, isInternalObject } from '../utils';
 import { ProvidedAPIsPage, ProvidedAPIPage } from './operand';
 import { createUninstallOperatorModal } from './modals/uninstall-operator-modal';
 import { operatorGroupFor, operatorNamespaceFor } from './operator-group';
 import { SubscriptionDetails, catalogSourceForSubscription } from './subscription';
 import { ClusterServiceVersionLogo, referenceForProvidedAPI, providedAPIsFor } from './index';
 
-const subscriptionForCSV = (
-  subscriptions: SubscriptionKind[],
-  csv: ClusterServiceVersionKind,
-): SubscriptionKind =>
-  _.find(subscriptions, {
-    metadata: {
-      namespace: _.get(csv, ['metadata', 'annotations', 'olm.operatorNamespace']),
-    },
-    status: {
-      installedCSV: getName(csv),
-    },
-  } as any); // 'as any' to supress typescript error caused by lodash
-
 const isSubscription = (obj) => referenceFor(obj) === referenceForModel(SubscriptionModel);
 const isCSV = (obj) => referenceFor(obj) === referenceForModel(ClusterServiceVersionModel);
+const isPackageServer = (obj) =>
+  obj.metadata.name === 'packageserver' &&
+  obj.metadata.namespace === 'openshift-operator-lifecycle-manager';
+
 const tableColumnClasses = [
-  classNames('col-lg-3', 'col-md-4', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-2', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'hidden-xs'),
-  classNames('col-lg-3', 'col-md-3', 'hidden-sm', 'hidden-xs'),
+  '',
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
   Kebab.columnClass,
 ];
 
@@ -115,11 +106,11 @@ export const ClusterServiceVersionTableHeader = () => {
       props: { className: tableColumnClasses[1] },
     },
     {
-      title: 'Deployment',
+      title: 'Status',
       props: { className: tableColumnClasses[2] },
     },
     {
-      title: 'Status',
+      title: 'Deployment',
       props: { className: tableColumnClasses[3] },
     },
     {
@@ -172,34 +163,20 @@ const menuActionsForCSV = (
   subscription: SubscriptionKind,
 ): KebabAction[] => {
   return _.isEmpty(subscription)
-    ? [Kebab.factory.Edit, Kebab.factory.Delete]
+    ? [Kebab.factory.Delete]
     : [
-        Kebab.factory.Edit,
         () => editSubscription(subscription),
         () => uninstall(subscription, _.get(csv, 'spec.displayName')),
       ];
 };
 
-const getSubscriptionState = (subscription: SubscriptionKind): string => {
-  const state: SubscriptionState = _.get(subscription, 'status.state');
-  switch (state) {
-    case SubscriptionState.SubscriptionStateUpgradeAvailable:
-      return 'Upgrade available';
-    case SubscriptionState.SubscriptionStateUpgradePending:
-      return 'Upgrading';
-    case SubscriptionState.SubscriptionStateAtLatest:
-      return 'Up to date';
-    default:
-      return '';
-  }
-};
-
 const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> = ({
   catalogSourceMissing,
   obj,
   subscription,
 }) => {
   const status = _.get(obj, 'status.phase');
+  const subscriptionStatus = getSubscriptionStatus(subscription);
 
   if (obj.metadata.deletionTimestamp) {
     return (
@@ -218,30 +195,27 @@ const ClusterServiceVersionStatus: React.FC<ClusterServiceVersionStatusProps> =
     );
   }
 
-  return (
+  return status ? (
     <>
-      {status ? (
-        <>
-          <span className="co-icon-and-text">
-            <Status status={status} />
-          </span>
-          {subscription && <span className="text-muted">{getSubscriptionState(subscription)}</span>}
-        </>
-      ) : null}
+      <span className="co-icon-and-text">
+        <Status status={status} />
+      </span>
+      {subscription && <span className="text-muted">{subscriptionStatus.title}</span>}
     </>
-  );
+  ) : null;
 };
 
 export const ClusterServiceVersionTableRow = withFallback<ClusterServiceVersionTableRowProps>(
-  ({ obj, key, subscription, catalogSourceMissing, ...rest }) => {
+  ({ obj, key, subscription, catalogSourceMissing, index, style }) => {
     const { displayName, provider, version } = _.get(obj, 'spec');
     const [icon] = _.get(obj, 'spec.icon', []);
     const deploymentName = _.get(obj, 'spec.install.spec.deployments[0].name');
     const namespace = getNamespace(obj);
     const route = resourceObjPath(obj, referenceFor(obj));
     const uid = getUID(obj);
+    const internalObjects = getInternalObjects(obj);
     return (
-      <TableRow id={uid} trKey={key} {...rest}>
+      <TableRow id={uid} trKey={key} index={index} style={style}>
         {/* Name */}
         <TableData className={tableColumnClasses[0]}>
           <Link
@@ -263,18 +237,8 @@ export const ClusterServiceVersionTableRow = withFallback<ClusterServiceVersionT
           <ResourceLink kind="Namespace" title={namespace} name={namespace} />
         </TableData>
 
-        {/* Deployment */}
-        <TableData className={tableColumnClasses[2]}>
-          <ResourceLink
-            kind="Deployment"
-            name={deploymentName}
-            namespace={operatorNamespaceFor(obj)}
-            title={deploymentName}
-          />
-        </TableData>
-
         {/* Status */}
-        <TableData className={tableColumnClasses[3]}>
+        <TableData className={tableColumnClasses[2]}>
           <div className="co-clusterserviceversion-row__status">
             <ClusterServiceVersionStatus
               catalogSourceMissing={catalogSourceMissing}
@@ -284,20 +248,31 @@ export const ClusterServiceVersionTableRow = withFallback<ClusterServiceVersionT
           </div>
         </TableData>
 
+        {/* Deployment */}
+        <TableData className={tableColumnClasses[3]}>
+          <ResourceLink
+            kind="Deployment"
+            name={deploymentName}
+            namespace={operatorNamespaceFor(obj)}
+            title={deploymentName}
+          />
+        </TableData>
+
         {/* Provided APIs */}
         <TableData className={tableColumnClasses[4]}>
-          {_.take(providedAPIsFor(obj), 4).map((desc) => (
+          {_.take(
+            providedAPIsFor(obj).filter((desc) => !isInternalObject(internalObjects, desc.name)),
+            4,
+          ).map((desc) => (
             <div key={referenceForProvidedAPI(desc)}>
               <Link to={`${route}/${referenceForProvidedAPI(desc)}`} title={desc.name}>
-                {desc.displayName}
+                {desc.displayName || desc.kind}
               </Link>
             </div>
           ))}
-          {providedAPIsFor(obj).length > 4 && (
-            <Link
-              to={`${route}/instances`}
-              title={`View ${providedAPIsFor(obj).length - 4} more...`}
-            >
+          {providedAPIsFor(obj).filter((desc) => !isInternalObject(internalObjects, desc.name))
+            .length > 4 && (
+            <Link to={route} title={`View ${providedAPIsFor(obj).length - 4} more...`}>
               {`View ${providedAPIsFor(obj).length - 4} more...`}
             </Link>
           )}
@@ -320,7 +295,8 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
   catalogSourceMissing,
   key,
   obj,
-  ...rest
+  index,
+  style,
 }) => {
   const csvName = _.get(obj, 'spec.name');
   const menuActions = [Kebab.factory.Edit, () => uninstall(obj, obj.spec.displayName)];
@@ -333,7 +309,7 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
       return (
         <>
           <WarningStatus title="Cannot update" />
-          <span className="text-muted">Catalog source was removed.</span>
+          <span className="text-muted">Catalog source was removed</span>
         </>
       );
     }
@@ -345,7 +321,7 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
   };
 
   return (
-    <TableRow id={uid} trKey={key} {...rest}>
+    <TableRow id={uid} trKey={key} index={index} style={style}>
       {/* Name */}
       <TableData className={tableColumnClasses[0]}>
         <Link to={route}>
@@ -363,14 +339,14 @@ const SubscriptionTableRow: React.FC<SubscriptionTableRowProps> = ({
         <ResourceLink kind="Namespace" title={namespace} name={namespace} />
       </TableData>
 
+      {/* Status */}
+      <TableData className={tableColumnClasses[3]}>{getStatus()}</TableData>
+
       {/* Deployment */}
       <TableData className={tableColumnClasses[2]}>
         <span className="text-muted">None</span>
       </TableData>
 
-      {/* Status */}
-      <TableData className={tableColumnClasses[3]}>{getStatus()}</TableData>
-
       {/* Provided APIs */}
       <TableData className={tableColumnClasses[4]}>
         <span className="text-muted">None</span>
@@ -393,9 +369,12 @@ const InstalledOperatorTableRow: React.FC<InstalledOperatorTableRowProps> = ({
   const subscription = isCSV(obj)
     ? subscriptionForCSV(subscriptions, obj as ClusterServiceVersionKind)
     : (obj as SubscriptionKind);
-  // Only warn about missing catalog sources if the user was able to list them.
+  // Only warn about missing catalog sources if the user was able to list them
+  // but exclude PackageServer as it does not have a subscription.
   const catalogSourceMissing =
-    !_.isEmpty(catalogSources) && !catalogSourceForSubscription(catalogSources, subscription);
+    !_.isEmpty(catalogSources) &&
+    !catalogSourceForSubscription(catalogSources, subscription) &&
+    !isPackageServer(obj);
 
   return isCSV(obj) ? (
     <ClusterServiceVersionTableRow
@@ -551,9 +530,7 @@ export const CRDCard: React.SFC<CRDCardProps> = (props) => {
   const reference = referenceForProvidedAPI(crd);
   const model = modelFor(reference);
   const createRoute = () =>
-    `/k8s/ns/${csv.metadata.namespace}/${ClusterServiceVersionModel.plural}/${
-      csv.metadata.name
-    }/${reference}/~new`;
+    `/k8s/ns/${csv.metadata.namespace}/${ClusterServiceVersionModel.plural}/${csv.metadata.name}/${reference}/~new`;
   return (
     <Card>
       <CardHeader>
@@ -561,7 +538,7 @@ export const CRDCard: React.SFC<CRDCardProps> = (props) => {
           kind={referenceForProvidedAPI(crd)}
           title={crd.name}
           linkTo={false}
-          displayName={crd.displayName}
+          displayName={crd.displayName || crd.kind}
         />
       </CardHeader>
       <CardBody>
@@ -595,27 +572,39 @@ const crdCardRowStateToProps = ({ k8s }, { crdDescs }) => {
   };
 };
 
-export const CRDCardRow = connect(crdCardRowStateToProps)((props: CRDCardRowProps) => (
-  <div className="co-crd-card-row">
-    {_.isEmpty(props.crdDescs) ? (
-      <span className="text-muted">No Kubernetes APIs are being provided by this Operator.</span>
-    ) : (
-      props.crdDescs.map((desc) => (
-        <CRDCard
-          key={referenceForProvidedAPI(desc)}
-          crd={desc}
-          csv={props.csv}
-          canCreate={props.createable.includes(referenceForProvidedAPI(desc))}
-        />
-      ))
-    )}
-  </div>
-));
+export const CRDCardRow = connect(crdCardRowStateToProps)((props: CRDCardRowProps) => {
+  const internalObjects = getInternalObjects(props.csv);
+  return (
+    <div className="co-crd-card-row">
+      {_.isEmpty(props.crdDescs) ? (
+        <span className="text-muted">No Kubernetes APIs are being provided by this Operator.</span>
+      ) : (
+        props.crdDescs.reduce(
+          (acc, desc) =>
+            !isInternalObject(internalObjects, desc.name)
+              ? [
+                  ...acc,
+                  <CRDCard
+                    key={referenceForProvidedAPI(desc)}
+                    crd={desc}
+                    csv={props.csv}
+                    canCreate={props.createable.includes(referenceForProvidedAPI(desc))}
+                  />,
+                ]
+              : acc,
+          [],
+        )
+      )}
+    </div>
+  );
+});
 
 export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetailsProps> = (
   props,
 ) => {
   const { spec, metadata, status } = props.obj;
+  const { 'marketplace.openshift.io/support-workflow': marketplaceSupportWorkflow } =
+    metadata.annotations || {};
 
   return (
     <>
@@ -644,6 +633,14 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
                 <dd>
                   {spec.provider && spec.provider.name ? spec.provider.name : 'Not available'}
                 </dd>
+                {marketplaceSupportWorkflow && (
+                  <>
+                    <dt>Support</dt>
+                    <dd>
+                      <ExternalLink href={marketplaceSupportWorkflow} text="Get support" />
+                    </dd>
+                  </>
+                )}
                 <dt>Created At</dt>
                 <dd>
                   <Timestamp timestamp={metadata.creationTimestamp} />
@@ -686,7 +683,7 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
         </div>
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="ClusterServiceVersion Overview" />
+        <SectionHeading text="ClusterServiceVersion Details" />
         <div className="co-m-pane__body-group">
           <div className="row">
             <div className="col-sm-6">
@@ -724,17 +721,17 @@ export const ClusterServiceVersionDetails: React.SFC<ClusterServiceVersionDetail
                 </>
               )}
               <dt>Operator Group</dt>
-              {_.get(status, 'reason') === CSVConditionReason.CSVReasonCopied ? (
-                <dd>
+              <dd>
+                {operatorGroupFor(props.obj) ? (
                   <ResourceLink
-                    name={metadata.name}
+                    name={operatorGroupFor(props.obj)}
                     namespace={operatorNamespaceFor(props.obj)}
-                    kind={referenceFor(props.obj)}
+                    kind={referenceForModel(OperatorGroupModel)}
                   />
-                </dd>
-              ) : (
-                <dd>{operatorGroupFor(props.obj) || '-'}</dd>
-              )}
+                ) : (
+                  '-'
+                )}
+              </dd>
             </div>
           </div>
         </div>
@@ -762,11 +759,10 @@ export const CSVSubscription: React.FC<CSVSubscriptionProps> = ({
     <MsgBox title="No Operator Subscription" detail="This Operator will not receive updates." />
   );
 
-  const [subscription, setSubscription] = React.useState();
-
-  React.useEffect(() => {
-    setSubscription(subscriptionForCSV(subscriptions, obj));
-  }, [obj, subscriptions]);
+  const subscription = React.useMemo(() => subscriptionForCSV(subscriptions, obj), [
+    obj,
+    subscriptions,
+  ]);
 
   return (
     <StatusBox EmptyMsg={EmptyMsg} loaded data={subscription}>
@@ -779,26 +775,40 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
   props,
 ) => {
   const instancePagesFor = (obj: ClusterServiceVersionKind) => {
-    return (providedAPIsFor(obj).length > 1
-      ? [{ href: 'instances', name: 'All Instances', component: ProvidedAPIsPage }]
-      : ([] as Page[])
-    ).concat(
-      providedAPIsFor(obj).map((desc: CRDDescription) => ({
-        href: referenceForProvidedAPI(desc),
-        name: desc.displayName,
-        component: React.memo(
-          () => (
-            <ProvidedAPIPage
-              csv={obj}
-              kind={referenceForProvidedAPI(desc)}
-              namespace={obj.metadata.namespace}
-            />
-          ),
-          _.isEqual,
-        ),
-      })),
+    const internalObjects = getInternalObjects(obj);
+    const allInstancesPage: Page = {
+      href: 'instances',
+      name: 'All Instances',
+      component: ProvidedAPIsPage,
+    };
+
+    return (providedAPIsFor(obj).length > 1 ? [allInstancesPage] : ([] as Page[])).concat(
+      providedAPIsFor(obj).reduce(
+        (acc, desc: CRDDescription) =>
+          !isInternalObject(internalObjects, desc.name)
+            ? [
+                ...acc,
+                {
+                  href: referenceForProvidedAPI(desc),
+                  name: desc.displayName || desc.kind,
+                  component: React.memo(
+                    () => (
+                      <ProvidedAPIPage
+                        csv={obj}
+                        kind={referenceForProvidedAPI(desc)}
+                        namespace={obj.metadata.namespace}
+                      />
+                    ),
+                    _.isEqual,
+                  ),
+                },
+              ]
+            : acc,
+        [],
+      ),
     );
   };
+
   type ExtraResources = { subscriptions: SubscriptionKind[] };
   const menuActions = (
     model,
@@ -807,7 +817,6 @@ export const ClusterServiceVersionsDetailsPage: React.FC<ClusterServiceVersionsD
   ) => {
     const subscription = subscriptionForCSV(subscriptions, obj);
     return [
-      Kebab.factory.Edit(model, obj),
       ...(_.isEmpty(subscription)
         ? [Kebab.factory.Delete(model, obj)]
         : [editSubscription(subscription), uninstall(subscription)]),
