@@ -2,9 +2,9 @@ import * as React from 'react';
 import { match as RouterMatch } from 'react-router-dom';
 import { shallow, ShallowWrapper } from 'enzyme';
 import * as _ from 'lodash';
+import * as k8sModels from '@console/internal/module/k8s';
 import { Table, DetailsPage, MultiListPage, ListPage } from '@console/internal/components/factory';
 import { Timestamp, LabelList, StatusBox, ResourceKebab } from '@console/internal/components/utils';
-import { referenceFor, referenceForModel, K8sResourceKind } from '@console/internal/module/k8s';
 import {
   testCRD,
   testResourceInstance,
@@ -27,12 +27,22 @@ import {
   OperandDetailsPage,
   ProvidedAPIPage,
   ProvidedAPIPageProps,
+  OperandStatus,
+  OperandStatusProps,
 } from './operand';
 import { Resources } from './k8s-resource';
 import { StatusDescriptor } from './descriptors/status';
 import { SpecDescriptor } from './descriptors/spec';
 import { referenceForProvidedAPI, OperandLink } from '.';
 
+const COLUMNS = OperandTableHeader();
+const NAME_INDEX = _.findIndex(COLUMNS, { title: 'Name' });
+const KIND_INDEX = _.findIndex(COLUMNS, { title: 'Kind' });
+const STATUS_INDEX = _.findIndex(COLUMNS, { title: 'Status' });
+const VERSION_INDEX = _.findIndex(COLUMNS, { title: 'Version' });
+const LABELS_INDEX = _.findIndex(COLUMNS, { title: 'Labels' });
+const LAST_UPDATED_INDEX = _.findIndex(COLUMNS, { title: 'Last Updated' });
+
 describe(OperandTableHeader.displayName, () => {
   it('returns column header definition for resource', () => {
     expect(Array.isArray(OperandTableHeader())).toBe(true);
@@ -47,7 +57,7 @@ describe(OperandTableRow.displayName, () => {
   });
 
   it('renders column for resource name', () => {
-    const col = wrapper.childAt(0);
+    const col = wrapper.childAt(NAME_INDEX);
     const link = col.find(OperandLink);
 
     expect(link.props().obj).toEqual(testResourceInstance);
@@ -62,12 +72,12 @@ describe(OperandTableRow.displayName, () => {
     expect(kebab.props().actions[1](testModel, testOwnedResourceInstance).label).toEqual(
       `Delete ${testModel.label}`,
     );
-    expect(kebab.props().kind).toEqual(referenceFor(testResourceInstance));
+    expect(kebab.props().kind).toEqual(k8sModels.referenceFor(testResourceInstance));
     expect(kebab.props().resource).toEqual(testResourceInstance);
   });
 
   it('renders column for resource labels', () => {
-    const col = wrapper.childAt(1);
+    const col = wrapper.childAt(LABELS_INDEX);
     const labelList = col.find(LabelList);
 
     expect(labelList.props().kind).toEqual(testResourceInstance.kind);
@@ -75,34 +85,25 @@ describe(OperandTableRow.displayName, () => {
   });
 
   it('renders column for resource type', () => {
-    const col = wrapper.childAt(2);
+    const col = wrapper.childAt(KIND_INDEX);
 
     expect(col.shallow().text()).toEqual(testResourceInstance.kind);
   });
 
   it('renders column for resource status', () => {
-    const col = wrapper.childAt(3);
+    const col = wrapper.childAt(STATUS_INDEX);
 
-    expect(col.shallow().text()).toEqual('Unknown');
-  });
-
-  it('renders column for resource status if unknown', () => {
-    const obj = _.cloneDeep(testResourceInstance);
-    obj.status = null;
-    wrapper.setProps({ obj });
-    const col = wrapper.childAt(3);
-
-    expect(col.shallow().text()).toEqual('Unknown');
+    expect(col.find(OperandStatus).props().operand).toEqual(testResourceInstance);
   });
 
   it('renders column for resource version', () => {
-    const col = wrapper.childAt(4);
+    const col = wrapper.childAt(VERSION_INDEX);
 
     expect(col.shallow().text()).toEqual(testResourceInstance.spec.version || 'Unknown');
   });
 
   it('renders column for last updated timestamp', () => {
-    const col = wrapper.childAt(5);
+    const col = wrapper.childAt(LAST_UPDATED_INDEX);
     const timestamp = col.find(Timestamp);
 
     expect(timestamp.props().timestamp).toEqual(testResourceInstance.metadata.creationTimestamp);
@@ -111,7 +112,7 @@ describe(OperandTableRow.displayName, () => {
 
 describe(OperandList.displayName, () => {
   let wrapper: ShallowWrapper<OperandListProps>;
-  let resources: K8sResourceKind[];
+  let resources: k8sModels.K8sResourceKind[];
 
   beforeEach(() => {
     resources = [testResourceInstance];
@@ -208,7 +209,7 @@ describe('ResourcesList', () => {
     match = {
       params: {
         appName: 'etcd',
-        plural: referenceFor(testResourceInstance),
+        plural: k8sModels.referenceFor(testResourceInstance),
         name: 'my-etcd',
         ns: 'default',
       },
@@ -229,7 +230,7 @@ describe('ResourcesList', () => {
 
     expect(resourceComponent.props().resources).toEqual(
       testClusterServiceVersion.spec.customresourcedefinitions.owned[0].resources.map(
-        (resource) => ({ kind: resource.kind, namespaced: true }),
+        (resource) => ({ kind: resource.kind, namespaced: true, prop: 'Pod' }),
       ),
     );
   });
@@ -256,7 +257,7 @@ describe(OperandDetailsPage.displayName, () => {
 
     wrapper = shallow(
       <OperandDetailsPage.WrappedComponent
-        modelRef={referenceFor(testResourceInstance)}
+        modelRef={k8sModels.referenceFor(testResourceInstance)}
         match={match}
       />,
     );
@@ -265,7 +266,7 @@ describe(OperandDetailsPage.displayName, () => {
   it('renders a `DetailsPage` with the correct subpages', () => {
     const detailsPage = wrapper.find(DetailsPage);
 
-    expect(detailsPage.props().pages[0].name).toEqual('Overview');
+    expect(detailsPage.props().pages[0].name).toEqual('Details');
     expect(detailsPage.props().pages[0].href).toEqual('');
     expect(detailsPage.props().pages[1].name).toEqual('YAML');
     expect(detailsPage.props().pages[1].href).toEqual('yaml');
@@ -276,7 +277,7 @@ describe(OperandDetailsPage.displayName, () => {
   it('renders a `DetailsPage` which also watches the parent CSV', () => {
     expect(wrapper.find(DetailsPage).props().resources).toEqual([
       {
-        kind: referenceForModel(ClusterServiceVersionModel),
+        kind: k8sModels.referenceForModel(ClusterServiceVersionModel),
         name: match.params.appName,
         namespace: match.params.ns,
         isList: false,
@@ -385,6 +386,11 @@ describe(OperandDetailsPage.displayName, () => {
 describe(ProvidedAPIsPage.displayName, () => {
   let wrapper: ShallowWrapper<ProvidedAPIsPageProps>;
 
+  beforeAll(() => {
+    // Since crd models have not been loaded into redux state, just force return of the correct model type
+    spyOn(k8sModels, 'modelFor').and.returnValue(testModel);
+  });
+
   beforeEach(() => {
     wrapper = shallow(<ProvidedAPIsPage.WrappedComponent obj={testClusterServiceVersion} />);
   });
@@ -436,9 +442,7 @@ describe(ProvidedAPIsPage.displayName, () => {
     expect(
       listPage.props().createProps.createLink(obj.spec.customresourcedefinitions.owned[0].name),
     ).toEqual(
-      `/k8s/ns/default/${
-        ClusterServiceVersionModel.plural
-      }/testapp/testapp.coreos.com~v1alpha1~TestResource/~new`,
+      `/k8s/ns/default/${ClusterServiceVersionModel.plural}/testapp/testapp.coreos.com~v1alpha1~TestResource/~new`,
     );
   });
 
@@ -451,9 +455,7 @@ describe(ProvidedAPIsPage.displayName, () => {
     expect(listPage.props().createProps.items).not.toBeDefined();
     expect(listPage.props().createProps.createLink).not.toBeDefined();
     expect(listPage.props().createProps.to).toEqual(
-      `/k8s/ns/default/${
-        ClusterServiceVersionModel.plural
-      }/testapp/testapp.coreos.com~v1alpha1~TestResource/~new`,
+      `/k8s/ns/default/${ClusterServiceVersionModel.plural}/testapp/testapp.coreos.com~v1alpha1~TestResource/~new`,
     );
   });
 
@@ -485,7 +487,7 @@ describe(ProvidedAPIPage.displayName, () => {
     wrapper = shallow(
       <ProvidedAPIPage.WrappedComponent
         kindObj={readonlyModel}
-        kind={referenceForModel(readonlyModel)}
+        kind={k8sModels.referenceForModel(readonlyModel)}
         csv={testClusterServiceVersion}
       />,
     );
@@ -493,3 +495,125 @@ describe(ProvidedAPIPage.displayName, () => {
     expect(wrapper.find(ListPage).props().canCreate).toBe(false);
   });
 });
+
+describe('OperandStatus', () => {
+  let wrapper: ShallowWrapper<OperandStatusProps>;
+
+  it('displays the correct status for a `status` value of `Running`', () => {
+    const obj = {
+      status: {
+        status: 'Running',
+        state: 'Degraded',
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'True',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.childAt(0).text()).toEqual('Status');
+    expect(wrapper.childAt(2).props().title).toEqual('Running');
+  });
+
+  it('displays the correct status for a `phase` value of `Running`', () => {
+    const obj = {
+      status: {
+        phase: 'Running',
+        status: 'Installed',
+        state: 'Degraded',
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'True',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.childAt(0).text()).toEqual('Phase');
+    expect(wrapper.childAt(2).props().title).toEqual('Running');
+  });
+
+  it('displays the correct status for a `phase` value of `Running`', () => {
+    const obj = {
+      status: {
+        phase: 'Running',
+        status: 'Installed',
+        state: 'Degraded',
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'True',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.childAt(0).text()).toEqual('Phase');
+    expect(wrapper.childAt(2).props().title).toEqual('Running');
+  });
+
+  it('displays the correct status for a `state` value of `Running`', () => {
+    const obj = {
+      status: {
+        state: 'Running',
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'True',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.childAt(0).text()).toEqual('State');
+    expect(wrapper.childAt(2).props().title).toEqual('Running');
+  });
+
+  it('displays the correct status for a condition status of `True`', () => {
+    const obj = {
+      status: {
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'False',
+          },
+          {
+            type: 'Running',
+            status: 'True',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.childAt(0).text()).toEqual('Condition');
+    expect(wrapper.childAt(2).props().title).toEqual('Running');
+  });
+
+  it('displays the `Unknown` status when no conditions are `True`', () => {
+    const obj = {
+      status: {
+        conditions: [
+          {
+            type: 'Failed',
+            status: 'False',
+          },
+          {
+            type: 'Installed',
+            status: 'False',
+          },
+        ],
+      },
+    };
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.find('.text-muted').text()).toEqual('Unknown');
+  });
+
+  it('displays Unknown for a missing status stanza', () => {
+    const obj = {};
+    wrapper = shallow(<OperandStatus operand={obj} />);
+    expect(wrapper.find('.text-muted').text()).toEqual('Unknown');
+  });
+});
