@@ -33,6 +33,7 @@ import { connectToModel, connectToPlural } from '@console/internal/kinds';
 import {
   GroupVersionKind,
   K8sKind,
+  K8sResourceCondition,
   K8sResourceKind,
   OwnerReference,
   apiVersionForReference,
@@ -47,6 +48,7 @@ import { RootState } from '@console/internal/redux';
 import * as plugins from '@console/internal/plugins';
 import { ClusterServiceVersionModel } from '../models';
 import { ClusterServiceVersionKind } from '../types';
+import { isInternalObject, getInternalAPIReferences, getInternalObjects } from '../utils';
 import { StatusDescriptor } from './descriptors/status';
 import { SpecDescriptor } from './descriptors/spec';
 import { StatusCapability, Descriptor } from './descriptors/types';
@@ -119,12 +121,12 @@ const getActions = (selectedObj: any) => {
 };
 
 const tableColumnClasses = [
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-3', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  '',
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-16-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-2xl'),
   Kebab.columnClass,
 ];
 
@@ -137,26 +139,26 @@ export const OperandTableHeader = () => {
       props: { className: tableColumnClasses[0] },
     },
     {
-      title: 'Labels',
-      sortField: 'metadata.labels',
+      title: 'Kind',
+      sortField: 'kind',
       transforms: [sortable],
       props: { className: tableColumnClasses[1] },
     },
     {
-      title: 'Kind',
-      sortField: 'kind',
+      title: 'Status',
+      sortFunc: 'operandStatus',
       transforms: [sortable],
       props: { className: tableColumnClasses[2] },
     },
     {
-      title: 'Status',
-      sortField: 'status.phase',
+      title: 'Version',
+      sortField: 'spec.version',
       transforms: [sortable],
       props: { className: tableColumnClasses[3] },
     },
     {
-      title: 'Version',
-      sortField: 'spec.version',
+      title: 'Labels',
+      sortField: 'metadata.labels',
       transforms: [sortable],
       props: { className: tableColumnClasses[4] },
     },
@@ -173,33 +175,87 @@ export const OperandTableHeader = () => {
   ];
 };
 
+type OperandStatusType = {
+  type: string;
+  value: string;
+};
+
+const getOperandStatus = (obj: K8sResourceKind): OperandStatusType => {
+  const { phase, status, state, conditions } = obj?.status || {};
+
+  if (phase && _.isString(phase)) {
+    return {
+      type: 'Phase',
+      value: phase,
+    };
+  }
+
+  if (status && _.isString(status)) {
+    return {
+      type: 'Status',
+      value: status,
+    };
+  }
+
+  if (state && _.isString(state)) {
+    return {
+      type: 'State',
+      value: state,
+    };
+  }
+
+  const trueConditions = conditions?.filter((c: K8sResourceCondition) => c.status === 'True');
+  if (trueConditions?.length) {
+    const types = trueConditions.map((c: K8sResourceCondition) => c.type);
+    return {
+      type: types.length === 1 ? 'Condition' : 'Conditions',
+      value: types.join(', '),
+    };
+  }
+
+  return null;
+};
+
+export const OperandStatus: React.FunctionComponent<OperandStatusProps> = ({ operand }) => {
+  const status: OperandStatusType = getOperandStatus(operand);
+  if (!status) {
+    return <div className="text-muted">Unknown</div>;
+  }
+
+  const { type, value } = status;
+  return (
+    <span className="co-icon-and-text">
+      {type}:&nbsp;
+      {value === 'Running' ? <SuccessStatus title={value} /> : <Status status={value} />}
+    </span>
+  );
+};
+
+const getOperandStatusText = (operand: K8sResourceKind) => {
+  const status = getOperandStatus(operand);
+  return status ? `${status.type}: ${status.value}` : 'Unknown';
+};
+
 export const OperandTableRow: React.FC<OperandTableRowProps> = ({ obj, index, key, style }) => {
-  const status = _.get(obj.status, 'phase');
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
         <OperandLink obj={obj} />
       </TableData>
-      <TableData className={tableColumnClasses[1]}>
-        <LabelList kind={obj.kind} labels={obj.metadata.labels} />
-      </TableData>
       <TableData
-        className={classNames(tableColumnClasses[2], 'co-break-word')}
+        className={classNames(tableColumnClasses[1], 'co-break-word')}
         data-test-operand-kind={obj.kind}
       >
         {obj.kind}
       </TableData>
+      <TableData className={tableColumnClasses[2]}>
+        <OperandStatus operand={obj} />
+      </TableData>
       <TableData className={tableColumnClasses[3]}>
-        {_.isEmpty(status) ? (
-          <div className="text-muted">Unknown</div>
-        ) : (
-          <>
-            {status === 'Running' ? <SuccessStatus title={status} /> : <Status status={status} />}
-          </>
-        )}
+        {_.get(obj.spec, 'version') || <div className="text-muted">Unknown</div>}
       </TableData>
       <TableData className={tableColumnClasses[4]}>
-        {_.get(obj.spec, 'version') || <div className="text-muted">Unknown</div>}
+        <LabelList kind={obj.kind} labels={obj.metadata.labels} />
       </TableData>
       <TableData className={tableColumnClasses[5]}>
         <Timestamp timestamp={obj.metadata.creationTimestamp} />
@@ -234,6 +290,9 @@ export const OperandList: React.SFC<OperandListProps> = (props) => {
   return (
     <Table
       {...props}
+      customSorts={{
+        operandStatus: getOperandStatusText,
+      }}
       data={ensureKind(props.data)}
       EmptyMsg={EmptyMsg}
       aria-label="Operands"
@@ -251,10 +310,12 @@ const inFlightStateToProps = ({ k8s }: RootState) => ({
 export const ProvidedAPIsPage = connect(inFlightStateToProps)((props: ProvidedAPIsPageProps) => {
   const { obj } = props;
   const { owned = [] } = obj.spec.customresourcedefinitions;
+  const internalObjects = getInternalObjects(obj);
+  const internalAPIs = getInternalAPIReferences(obj);
   const firehoseResources = owned.reduce((resources, desc) => {
     const reference = referenceForProvidedAPI(desc);
     const model = modelFor(reference);
-    return model
+    return model && !internalAPIs.some((api) => api === reference)
       ? [
           ...resources,
           {
@@ -279,7 +340,13 @@ export const ProvidedAPIsPage = connect(inFlightStateToProps)((props: ProvidedAP
   const createProps =
     owned.length > 1
       ? {
-          items: owned.reduce((acc, crd) => ({ ...acc, [crd.name]: crd.displayName }), {}),
+          items: owned.reduce(
+            (acc, crd) =>
+              !isInternalObject(internalObjects, crd.name)
+                ? { ...acc, [crd.name]: crd.displayName }
+                : acc,
+            {},
+          ),
           createLink,
         }
       : { to: owned.length === 1 ? createLink(owned[0].name) : null };
@@ -343,9 +410,7 @@ export const ProvidedAPIPage = connectToModel((props: ProvidedAPIPageProps) => {
   }
 
   const to = kindObj.namespaced
-    ? `/k8s/ns/${csv.metadata.namespace}/${ClusterServiceVersionModel.plural}/${
-        csv.metadata.name
-      }/${kind}/~new`
+    ? `/k8s/ns/${csv.metadata.namespace}/${ClusterServiceVersionModel.plural}/${csv.metadata.name}/${kind}/~new`
     : `${resourcePathFromModel(kindObj)}/~new`;
   return (
     <ListPage
@@ -375,7 +440,6 @@ export const OperandDetails = connectToModel((props: OperandDetailsProps) => {
     !_.isEmpty(descriptor) ? _.get(block, descriptor.path, descriptor.value) : undefined;
 
   const { kind, metadata, spec, status } = props.obj;
-  const conditions = status && status.conditions;
 
   // Find the matching CRD spec for the kind of this resource in the CSV.
   const ownedDefinitions = _.get(
@@ -401,9 +465,7 @@ export const OperandDetails = connectToModel((props: OperandDetailsProps) => {
   const primaryDescriptors = statusDescriptors.filter((descriptor) => isMainDescriptor(descriptor));
 
   const header = (
-    <h2 className="co-section-heading">{`${
-      thisDefinition ? thisDefinition.displayName : kind
-    } Overview`}</h2>
+    <h2 className="co-section-heading">{thisDefinition?.displayName || kind} Overview</h2>
   );
 
   const primaryDescriptor = primaryDescriptors.map((statusDescriptor: Descriptor) => {
@@ -489,10 +551,10 @@ export const OperandDetails = connectToModel((props: OperandDetailsProps) => {
           <div className="co-m-pane__body">{details}</div>
         </>
       )}
-      {conditions && (
+      {_.isArray(status?.conditions) && (
         <div className="co-m-pane__body">
           <SectionHeading text="Conditions" />
-          <Conditions conditions={conditions} />
+          <Conditions conditions={status.conditions} />
         </div>
       )}
     </div>
@@ -559,6 +621,10 @@ export type OperandListProps = {
   staticFilters?: any;
 };
 
+export type OperandStatusProps = {
+  operand: K8sResourceKind;
+};
+
 export type OperandHeaderProps = {
   data: K8sResourceKind[];
 };
