@@ -1,6 +1,7 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { Helmet } from 'react-helmet';
+import { Link } from 'react-router-dom';
 import { match } from 'react-router';
 import {
   Firehose,
@@ -9,8 +10,8 @@ import {
   MsgBox,
   ExternalLink,
   skeletonCatalog,
-  withFallback,
 } from '@console/internal/components/utils';
+import { withFallback } from '@console/shared/src/components/error/error-boundary';
 import { ErrorBoundaryFallback } from '@console/internal/components/error';
 import { referenceForModel } from '@console/internal/module/k8s';
 import { fromRequirements } from '@console/internal/module/k8s/selector';
@@ -30,66 +31,93 @@ export const OperatorHubList: React.SFC<OperatorHubListProps> = (props) => {
     [] as PackageManifestKind[],
   );
   const localItems = _.get(props, 'packageManifest.data', [] as PackageManifestKind[]);
-  const items: OperatorHubItem[] = marketplaceItems.concat(localItems).map(
-    (pkg): OperatorHubItem => {
-      const { channels, defaultChannel } = _.get(pkg, 'status');
-      const { currentCSVDesc } = _.find(channels || [], { name: defaultChannel } as any);
-      const currentCSVAnnotations: OperatorHubCSVAnnotations = _.get(
-        currentCSVDesc,
-        'annotations',
-        {},
-      );
-      const {
-        certifiedLevel,
-        healthIndex,
-        repository,
-        containerImage,
-        createdAt,
-        support,
-        capabilities: capabilityLevel,
-      } = currentCSVAnnotations;
+  const getPackageStatus = (pkg) => _.get(pkg, 'status');
+  const items: OperatorHubItem[] = marketplaceItems
+    .concat(localItems)
+    .filter((pkg) => {
+      // if a package does not have status.defaultChannel, exclude it so the app doesn't fail
+      const { defaultChannel } = getPackageStatus(pkg);
+      if (!defaultChannel) {
+        // eslint-disable-next-line no-console
+        console.warn(
+          `PackageManifest ${pkg.metadata.name} has no status.defaultChannel and has been excluded`,
+        );
+        return false;
+      }
+      return true;
+    })
+    .map(
+      (pkg): OperatorHubItem => {
+        const { channels, defaultChannel } = getPackageStatus(pkg);
+        const { currentCSVDesc } = _.find(channels || [], { name: defaultChannel } as any);
+        const currentCSVAnnotations: OperatorHubCSVAnnotations = _.get(
+          currentCSVDesc,
+          'annotations',
+          {},
+        );
+        const {
+          certifiedLevel,
+          healthIndex,
+          repository,
+          containerImage,
+          createdAt,
+          support,
+          capabilities: capabilityLevel,
+          'marketplace.openshift.io/action-text': marketplaceActionText,
+          'marketplace.openshift.io/remote-workflow': marketplaceRemoteWorkflow,
+          'marketplace.openshift.io/support-workflow': marketplaceSupportWorkflow,
+        } = currentCSVAnnotations;
 
-      return {
-        obj: pkg,
-        kind: PackageManifestModel.kind,
-        name: _.get(currentCSVDesc, 'displayName', pkg.metadata.name),
-        uid: `${pkg.metadata.name}-${pkg.status.catalogSource}-${
-          pkg.status.catalogSourceNamespace
-        }`,
-        installed: installedFor(subscription.data)(operatorGroup.data)(pkg.status.packageName)(
-          namespace,
-        ),
-        subscription: subscriptionFor(subscription.data)(operatorGroup.data)(
-          pkg.status.packageName,
-        )(namespace),
-        // FIXME: Just use `installed`
-        installState: installedFor(subscription.data)(operatorGroup.data)(pkg.status.packageName)(
-          namespace,
-        )
-          ? InstalledState.Installed
-          : InstalledState.NotInstalled,
-        imgUrl: iconFor(pkg),
-        description: currentCSVAnnotations.description || currentCSVDesc.description,
-        longDescription: currentCSVDesc.description || currentCSVAnnotations.description,
-        provider: _.get(pkg, 'status.provider.name', _.get(pkg, 'metadata.labels.provider')),
-        providerType: getOperatorProviderType(pkg),
-        tags: [],
-        version: _.get(currentCSVDesc, 'version'),
-        categories: _.get(currentCSVAnnotations, 'categories', '')
-          .split(',')
-          .map((category) => category.trim()),
-        catalogSource: _.get(pkg, 'status.catalogSource'),
-        catalogSourceNamespace: _.get(pkg, 'status.catalogSourceNamespace'),
-        certifiedLevel,
-        healthIndex,
-        repository,
-        containerImage,
-        createdAt,
-        support,
-        capabilityLevel,
-      };
-    },
-  );
+        return {
+          obj: pkg,
+          kind: PackageManifestModel.kind,
+          name: _.get(currentCSVDesc, 'displayName', pkg.metadata.name),
+          uid: `${pkg.metadata.name}-${pkg.status.catalogSource}-${pkg.status.catalogSourceNamespace}`,
+          installed: installedFor(subscription.data)(operatorGroup.data)(pkg.status.packageName)(
+            namespace,
+          ),
+          subscription: subscriptionFor(subscription.data)(operatorGroup.data)(
+            pkg.status.packageName,
+          )(namespace),
+          // FIXME: Just use `installed`
+          installState: installedFor(subscription.data)(operatorGroup.data)(pkg.status.packageName)(
+            namespace,
+          )
+            ? InstalledState.Installed
+            : InstalledState.NotInstalled,
+          imgUrl: iconFor(pkg),
+          description: currentCSVAnnotations.description || currentCSVDesc.description,
+          longDescription: currentCSVDesc.description || currentCSVAnnotations.description,
+          provider: _.get(pkg, 'status.provider.name', _.get(pkg, 'metadata.labels.provider')),
+          providerType: getOperatorProviderType(pkg),
+          tags: [],
+          version: _.get(currentCSVDesc, 'version'),
+          categories: _.get(currentCSVAnnotations, 'categories', '')
+            .split(',')
+            .map((category) => category.trim()),
+          catalogSource: _.get(pkg, 'status.catalogSource'),
+          catalogSourceNamespace: _.get(pkg, 'status.catalogSourceNamespace'),
+          certifiedLevel,
+          healthIndex,
+          repository,
+          containerImage,
+          createdAt,
+          support,
+          capabilityLevel,
+          marketplaceActionText,
+          marketplaceRemoteWorkflow,
+          marketplaceSupportWorkflow,
+        };
+      },
+    );
+
+  const uniqueItems = _.uniqBy(items, 'uid');
+  if (uniqueItems.length !== items.length) {
+    // eslint-disable-next-line no-console
+    console.warn(
+      `${items.length - uniqueItems.length} duplicate packagemanifests returned from olm query.`,
+    );
+  }
 
   return (
     <StatusBox
@@ -115,7 +143,7 @@ export const OperatorHubList: React.SFC<OperatorHubListProps> = (props) => {
         />
       )}
     >
-      <OperatorHubTileView items={items} namespace={namespace} />
+      <OperatorHubTileView items={uniqueItems} namespace={namespace} />
     </StatusBox>
   );
 };
@@ -131,12 +159,16 @@ export const OperatorHubPage = withFallback(
           <PageHeading title="OperatorHub" />
           <p className="co-catalog-page__description">
             Discover Operators from the Kubernetes community and Red Hat partners, curated by Red
-            Hat. Operators can be installed on your clusters to provide optional add-ons and shared
-            services to your developers. Once installed, the capabilities provided by the Operator
-            appear in the <a href="/catalog">Developer Catalog</a>, providing a self-service
-            experience.
+            Hat. You can purchase commercial software through{' '}
+            <ExternalLink
+              href="https://marketplace.redhat.com/en-us?utm_source=openshift_console"
+              text="Red Hat Marketplace"
+            />
+            . You can install Operators on your clusters to provide optional add-ons and shared
+            services to your developers. After installation, the Operator capabilities will appear
+            in the <Link to="/catalog">Developer Catalog</Link> providing a self-service experience.
           </p>
-          <div className="co-catalog-connect">
+          <div className="co-catalog__body">
             <Firehose
               resources={[
                 {
@@ -169,7 +201,7 @@ export const OperatorHubPage = withFallback(
               ]}
             >
               {/* FIXME(alecmerdler): Hack because `Firehose` injects props without TypeScript knowing about it */}
-              <OperatorHubList {...props as any} namespace={props.match.params.ns} />
+              <OperatorHubList {...(props as any)} namespace={props.match.params.ns} />
             </Firehose>
           </div>
         </div>
