@@ -1,3 +1,3 @@
 export * from './ColaLayout';
-export { default as DagreLayout } from './DagreLayout';
+export * from './DagreLayout';
 export { default as ForceLayout } from './ForceLayout';
