@@ -1,20 +1,15 @@
 import { Dispatch } from 'react-redux';
 import * as _ from 'lodash-es';
 import { ActionType as Action, action } from 'typesafe-actions';
-import { getInfrastructurePlatform } from '@console/shared/src/selectors';
-import {
-  GroupModel,
-  InfrastructureModel,
-  SelfSubjectAccessReviewModel,
-  UserModel,
-} from '../models';
-import { k8sBasePath, ClusterVersionKind, k8sCreate, k8sGet, K8sResourceKind } from '../module/k8s';
+import { FLAGS } from '@console/shared/src/constants/common';
+import { GroupModel, SelfSubjectAccessReviewModel, UserModel } from '../models';
+import { k8sBasePath, ClusterVersionKind, k8sCreate } from '../module/k8s';
 import { receivedResources } from './k8s';
 import { coFetchJSON } from '../co-fetch';
 import { MonitoringRoutes } from '../reducers/monitoring';
 import { setMonitoringURL } from './monitoring';
-import { setClusterID, setConsoleLinks, setCreateProjectMessage, setUser } from './ui';
-import { FLAGS } from '../const';
+import * as plugins from '../plugins';
+import { setClusterID, setCreateProjectMessage, setUser, setConsoleLinks } from './common';
 
 export enum ActionType {
   SetFlag = 'setFlag',
@@ -25,13 +20,14 @@ export const defaults = _.mapValues(FLAGS, (flag) =>
   flag === FLAGS.AUTH_ENABLED ? !window.SERVER_FLAGS.authDisabled : undefined,
 );
 
-export const setFlag = (flag: FLAGS, value: boolean) => action(ActionType.SetFlag, { flag, value });
+export const setFlag = (flag: FLAGS | string, value: boolean) =>
+  action(ActionType.SetFlag, { flag, value });
 
 const retryFlagDetection = (dispatch, cb) => {
   setTimeout(() => cb(dispatch), 15000);
 };
 
-const handleError = (res, flag, dispatch, cb) => {
+export const handleError = (res, flag, dispatch, cb) => {
   const status = _.get(res, 'response.status');
   if (_.includes([403, 502], status)) {
     dispatch(setFlag(flag, undefined));
@@ -127,7 +123,7 @@ const ssarChecks = [
     // TODO: Move into OLM plugin
     flag: FLAGS.CAN_LIST_PACKAGE_MANIFEST,
     resourceAttributes: {
-      group: 'operators.coreos.com',
+      group: 'packages.operators.coreos.com',
       resource: 'packagemanifests',
       verb: 'list',
     },
@@ -165,17 +161,6 @@ const detectOpenShift = (dispatch) =>
         : handleError(err, FLAGS.OPENSHIFT, dispatch, detectOpenShift),
   );
 
-const detectBaremetalPlatform = (dispatch) =>
-  k8sGet(InfrastructureModel, 'cluster').then(
-    (infra: K8sResourceKind) =>
-      dispatch(setFlag(FLAGS.BAREMETAL, getInfrastructurePlatform(infra) === 'BareMetal')),
-    (err) => {
-      _.get(err, 'response.status') === 404
-        ? dispatch(setFlag(FLAGS.BAREMETAL, false))
-        : handleError(err, FLAGS.BAREMETAL, dispatch, detectBaremetalPlatform);
-    },
-  );
-
 const clusterVersionPath = `${k8sBasePath}/apis/config.openshift.io/v1/clusterversions/version`;
 const detectClusterVersion = (dispatch) =>
   coFetchJSON(clusterVersionPath).then(
@@ -208,28 +193,6 @@ const detectCanCreateProject = (dispatch) =>
     },
   );
 
-const monitoringConfigMapPath = `${k8sBasePath}/api/v1/namespaces/openshift-monitoring/configmaps/sharing-config`;
-const detectMonitoringURLs = (dispatch) =>
-  coFetchJSON(monitoringConfigMapPath).then(
-    (res) => {
-      const { alertmanagerURL, grafanaURL, prometheusURL } = res.data;
-      if (!_.isEmpty(alertmanagerURL)) {
-        dispatch(setMonitoringURL(MonitoringRoutes.AlertManager, alertmanagerURL));
-      }
-      if (!_.isEmpty(grafanaURL)) {
-        dispatch(setMonitoringURL(MonitoringRoutes.Grafana, grafanaURL));
-      }
-      if (!_.isEmpty(prometheusURL)) {
-        dispatch(setMonitoringURL(MonitoringRoutes.Prometheus, prometheusURL));
-      }
-    },
-    (err) => {
-      if (!_.includes([401, 403, 404, 500], _.get(err, 'response.status'))) {
-        setTimeout(() => detectMonitoringURLs(dispatch), 15000);
-      }
-    },
-  );
-
 const loggingConfigMapPath = `${k8sBasePath}/api/v1/namespaces/openshift-logging/configmaps/sharing-config`;
 const detectLoggingURL = (dispatch) =>
   coFetchJSON(loggingConfigMapPath).then(
@@ -292,13 +255,14 @@ const ssarCheckActions = ssarChecks.map(({ flag, resourceAttributes, after }) =>
 export const detectFeatures = () => (dispatch: Dispatch) =>
   [
     detectOpenShift,
-    // TODO(vojtech): move this flag definition to metal3-plugin via ActionFeatureFlag extension
-    detectBaremetalPlatform,
     detectCanCreateProject,
-    detectMonitoringURLs,
     detectClusterVersion,
     detectUser,
     detectLoggingURL,
     detectConsoleLinks,
     ...ssarCheckActions,
+    ...plugins.registry
+      .getFeatureFlags()
+      .filter(plugins.isActionFeatureFlag)
+      .map((ff) => ff.properties.detect),
   ].forEach((detect) => detect(dispatch));
