@@ -12,11 +12,13 @@ import { detectFeatures } from '../actions/features';
 import AppContents from './app-contents';
 import { getBrandingDetails, Masthead } from './masthead';
 import { ConsoleNotifier } from './console-notifier';
+import { ConnectedNotificationDrawer } from './notification-drawer';
 import { Navigation } from './nav';
-import { history } from './utils';
+import { history, Firehose } from './utils';
 import * as UIActions from '../actions/ui';
-import { fetchSwagger, getCachedResources } from '../module/k8s';
+import { fetchSwagger, getCachedResources, referenceForModel } from '../module/k8s';
 import { receivedResources, watchAPIServices } from '../actions/k8s';
+import { ClusterVersionModel } from '../models';
 import '../vendor.scss';
 import '../style.scss';
 
@@ -24,6 +26,18 @@ import '../style.scss';
 import { Page } from '@patternfly/react-core';
 
 const breakpointMD = 768;
+const NOTIFICATION_DRAWER_BREAKPOINT = 1800;
+
+const cvResource = [
+  {
+    kind: referenceForModel(ClusterVersionModel),
+    namespaced: false,
+    name: 'version',
+    isList: false,
+    prop: 'cv',
+    optional: true,
+  },
+];
 
 // Edge lacks URLSearchParams
 import 'url-search-params-polyfill';
@@ -34,16 +48,19 @@ class App extends React.PureComponent {
 
     this._onNavToggle = this._onNavToggle.bind(this);
     this._onNavSelect = this._onNavSelect.bind(this);
+    this._onNotificationDrawerToggle = this._onNotificationDrawerToggle.bind(this);
     this._isDesktop = this._isDesktop.bind(this);
     this._onResize = this._onResize.bind(this);
     this.previousDesktopState = this._isDesktop();
+    this.previousDrawerInlineState = this._isLargeLayout();
 
     this.state = {
       isNavOpen: this._isDesktop(),
+      isDrawerInline: this._isLargeLayout(),
     };
   }
 
-  componentWillMount() {
+  UNSAFE_componentWillMount() {
     window.addEventListener('resize', this._onResize);
   }
 
@@ -64,6 +81,10 @@ class App extends React.PureComponent {
     store.dispatch(UIActions.setCurrentLocation(pathname));
   }
 
+  _isLargeLayout() {
+    return window.innerWidth >= NOTIFICATION_DRAWER_BREAKPOINT;
+  }
+
   _isDesktop() {
     return window.innerWidth >= breakpointMD;
   }
@@ -72,7 +93,7 @@ class App extends React.PureComponent {
     // Some components, like svg charts, need to reflow when nav is toggled.
     // Fire event after a short delay to allow nav animation to complete.
     setTimeout(() => {
-      window.dispatchEvent(new Event('nav_toggle'));
+      window.dispatchEvent(new Event('sidebar_toggle'));
     }, 100);
 
     this.setState((prevState) => {
@@ -82,6 +103,15 @@ class App extends React.PureComponent {
     });
   }
 
+  _onNotificationDrawerToggle() {
+    if (this._isLargeLayout()) {
+      // Fire event after the drawer animation speed delay.
+      setTimeout(() => {
+        window.dispatchEvent(new Event('sidebar_toggle'));
+      }, 250);
+    }
+  }
+
   _onNavSelect() {
     //close nav on mobile nav selects
     if (!this._isDesktop()) {
@@ -91,14 +121,19 @@ class App extends React.PureComponent {
 
   _onResize() {
     const isDesktop = this._isDesktop();
+    const isDrawerInline = this._isLargeLayout();
     if (this.previousDesktopState !== isDesktop) {
       this.setState({ isNavOpen: isDesktop });
       this.previousDesktopState = isDesktop;
     }
+    if (this.previousDrawerInlineState !== isDrawerInline) {
+      this.setState({ isDrawerInline });
+      this.previousDrawerInlineState = isDrawerInline;
+    }
   }
 
   render() {
-    const { isNavOpen } = this.state;
+    const { isNavOpen, isDrawerInline } = this.state;
     const { productName } = getBrandingDetails();
 
     return (
@@ -115,7 +150,14 @@ class App extends React.PureComponent {
             />
           }
         >
-          <AppContents />
+          <Firehose resources={cvResource}>
+            <ConnectedNotificationDrawer
+              isDesktop={isDrawerInline}
+              onDrawerChange={this._onNotificationDrawerToggle}
+            >
+              <AppContents />
+            </ConnectedNotificationDrawer>
+          </Firehose>
         </Page>
         <ConsoleNotifier location="BannerBottom" />
       </>
@@ -146,7 +188,11 @@ fetchSwagger();
 
 // Used by GUI tests to check for unhandled exceptions
 window.windowError = false;
-window.onerror = window.onunhandledrejection = () => (window.windowError = true);
+window.onerror = window.onunhandledrejection = (e) => {
+  // eslint-disable-next-line no-console
+  console.error('Uncaught error', e);
+  window.windowError = e || true;
+};
 
 if ('serviceWorker' in navigator) {
   if (window.SERVER_FLAGS.loadTestFactor > 1) {
