@@ -1,11 +1,10 @@
 import * as React from 'react';
-import * as _ from 'lodash-es';
-
 import { Timestamp } from './utils';
 import { CamelCaseWrap } from './utils/camel-case-wrap';
+import { K8sResourceCondition } from '../module/k8s';
 
 export const Conditions: React.SFC<ConditionsProps> = ({ conditions }) => {
-  const rows = _.map(conditions, (condition, i) => (
+  const rows = conditions?.map?.((condition: K8sResourceCondition, i: number) => (
     <div className="row" data-test-id={condition.type} key={i}>
       <div className="col-xs-4 col-sm-2 col-md-2">
         <CamelCaseWrap value={condition.type} />
@@ -14,21 +13,21 @@ export const Conditions: React.SFC<ConditionsProps> = ({ conditions }) => {
         {condition.status}
       </div>
       <div className="hidden-xs hidden-sm col-md-2">
-        <Timestamp timestamp={condition.lastUpdateTime || condition.lastTransitionTime} />
+        <Timestamp timestamp={condition.lastTransitionTime} />
       </div>
       <div className="col-xs-4 col-sm-3 col-md-2">
         <CamelCaseWrap value={condition.reason} />
       </div>
       {/* remove initial newline which appears in route messages */}
       <div className="hidden-xs col-sm-5 col-md-4 co-break-word co-pre-line">
-        {_.trim(condition.message) || '-'}
+        {condition.message?.trim() || '-'}
       </div>
     </div>
   ));
 
   return (
     <>
-      {conditions ? (
+      {conditions?.length ? (
         <div className="co-m-table-grid co-m-table-grid--bordered">
           <div className="row co-m-table-grid__head">
             <div className="col-xs-4 col-sm-2 col-md-2">Type</div>
@@ -48,17 +47,8 @@ export const Conditions: React.SFC<ConditionsProps> = ({ conditions }) => {
   );
 };
 
-export type conditionProps = {
-  type: string;
-  status: string;
-  reason?: string;
-  message?: string;
-  lastUpdateTime?: string;
-  lastTransitionTime?: string;
-};
-
 export type ConditionsProps = {
-  conditions: conditionProps[];
+  conditions: K8sResourceCondition[];
   title?: string;
   subTitle?: string;
 };
