@@ -2,22 +2,26 @@ import * as _ from 'lodash-es';
 import * as PropTypes from 'prop-types';
 import * as React from 'react';
 import { connect } from 'react-redux';
-import { getNodeRoles } from '@console/shared';
+import { getNodeRoles, getMachinePhase } from '@console/shared';
 import * as UIActions from '../../actions/ui';
 import { ingressValidHosts } from '../ingress';
 import { alertStateOrder, silenceStateOrder } from '../../reducers/monitoring';
-import { EmptyBox, StatusBox, WithScrollContainer } from '../utils';
+import { convertToBaseValue, EmptyBox, StatusBox, WithScrollContainer } from '../utils';
 import {
-  getJobTypeAndCompletions,
-  NodeKind,
-  planExternalName,
-  podPhase,
-  podReadiness,
-  serviceCatalogStatus,
-  serviceClassDisplayName,
   getClusterOperatorStatus,
   getClusterOperatorVersion,
+  getJobTypeAndCompletions,
   getTemplateInstanceStatus,
+  K8sResourceKind,
+  NodeKind,
+  planExternalName,
+  PodKind,
+  podPhase,
+  podReadiness,
+  podRestarts,
+  serviceCatalogStatus,
+  serviceClassDisplayName,
+  MachineKind,
 } from '../../module/k8s';
 
 import {
@@ -100,8 +104,15 @@ const sorts = {
   },
   numReplicas: (resource) => _.toInteger(_.get(resource, 'status.replicas')),
   planExternalName,
+  namespaceCPU: (ns: K8sResourceKind): number => UIActions.getNamespaceMetric(ns, 'cpu'),
+  namespaceMemory: (ns: K8sResourceKind): number => UIActions.getNamespaceMetric(ns, 'memory'),
+  podCPU: (pod: PodKind): number => UIActions.getPodMetric(pod, 'cpu'),
+  podMemory: (pod: PodKind): number => UIActions.getPodMetric(pod, 'memory'),
   podPhase,
-  podReadiness,
+  podReadiness: (pod: PodKind): number => podReadiness(pod).readyCount,
+  podRestarts,
+  pvStorage: (pv) => _.toInteger(convertToBaseValue(pv?.spec?.capacity?.storage)),
+  pvcStorage: (pvc) => _.toInteger(convertToBaseValue(pvc?.status?.capacity?.storage)),
   serviceClassDisplayName,
   silenceStateOrder,
   string: (val) => JSON.stringify(val),
@@ -113,11 +124,13 @@ const sorts = {
     const roles = getNodeRoles(node);
     return roles.sort().join(', ');
   },
+  machinePhase: (machine: MachineKind): string => getMachinePhase(machine),
 };
 
 const stateToProps = (
   { UI },
   {
+    customSorts = {},
     data = [],
     defaultSortField = 'metadata.name',
     defaultSortFunc = undefined,
@@ -152,6 +165,9 @@ const stateToProps = (
       } else {
         sortBy = (resource) => sorts.string(_.get(resource, currentSortField, ''));
       }
+    } else if (currentSortFunc && customSorts[currentSortFunc]) {
+      // Sort resources by a function in the 'customSorts' prop
+      sortBy = customSorts[currentSortFunc];
     } else if (currentSortFunc && sorts[currentSortFunc]) {
       // Sort resources by a function in the 'sorts' object
       sortBy = sorts[currentSortFunc];
@@ -327,6 +343,7 @@ export type VirtualBodyProps = {
 
 export type TableProps = {
   customData?: any;
+  customSorts?: { [key: string]: any };
   data?: any[];
   defaultSortFunc?: string;
   defaultSortField?: string;
@@ -358,14 +375,9 @@ export const Table = connect<
   TablePropsFromDispatch,
   TableProps,
   TableOptionProps
->(
-  stateToProps,
-  { sortList: UIActions.sortList },
-  null,
-  {
-    areStatesEqual: ({ UI: next }, { UI: prev }) => next.get('listSorts') === prev.get('listSorts'),
-  },
-)(
+>(stateToProps, { sortList: UIActions.sortList }, null, {
+  areStatesEqual: ({ UI: next }, { UI: prev }) => next.get('listSorts') === prev.get('listSorts'),
+})(
   class TableInner extends React.Component<TableInnerProps, TableInnerState> {
     static propTypes = {
       customData: PropTypes.any,
