@@ -1,5 +1,4 @@
 import * as React from 'react';
-import * as _ from 'lodash-es';
 import { sortable } from '@patternfly/react-table';
 import * as classNames from 'classnames';
 import {
@@ -10,6 +9,7 @@ import {
   getMachineRole,
   getMachineZone,
   Status,
+  getMachinePhase,
 } from '@console/shared';
 import { MachineModel } from '../models';
 import { MachineKind, referenceForModel } from '../module/k8s';
@@ -33,12 +33,13 @@ const menuActions = [...Kebab.getExtensionsActionsForKind(MachineModel), ...comm
 export const machineReference = referenceForModel(MachineModel);
 
 const tableColumnClasses = [
-  classNames('col-lg-2', 'col-md-3', 'col-sm-3', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-3', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-3', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-3', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  '',
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-md'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
   Kebab.columnClass,
 ];
 
@@ -64,35 +65,44 @@ const MachineTableHeader = () => {
     },
     {
       title: 'Phase',
-      sortField: 'status.phase',
+      sortFunc: 'machinePhase',
       transforms: [sortable],
       props: { className: tableColumnClasses[3] },
     },
+    {
+      title: 'Provider State',
+      sortField: 'status.providerStatus.instanceState',
+      transforms: [sortable],
+      props: { className: tableColumnClasses[4] },
+    },
     {
       title: 'Region',
       sortField: "metadata.labels['machine.openshift.io/region']",
       transforms: [sortable],
-      props: { className: tableColumnClasses[4] },
+      props: { className: tableColumnClasses[5] },
     },
     {
       title: 'Availability Zone',
       sortField: "metadata.labels['machine.openshift.io/zone']",
       transforms: [sortable],
-      props: { className: tableColumnClasses[5] },
+      props: { className: tableColumnClasses[6] },
     },
     {
       title: '',
-      props: { className: tableColumnClasses[6] },
+      props: { className: tableColumnClasses[7] },
     },
   ];
 };
 MachineTableHeader.displayName = 'MachineTableHeader';
 
+const getMachineProviderState = (obj: MachineKind): string =>
+  obj?.status?.providerStatus?.instanceState;
+
 const MachineTableRow: React.FC<MachineTableRowProps> = ({ obj, index, key, style }) => {
   const nodeName = getMachineNodeName(obj);
-  const status = obj.status ? obj.status.phase : null;
   const region = getMachineRegion(obj);
   const zone = getMachineZone(obj);
+  const providerState = getMachineProviderState(obj);
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={classNames(tableColumnClasses[0], 'co-break-word')}>
@@ -110,11 +120,12 @@ const MachineTableRow: React.FC<MachineTableRowProps> = ({ obj, index, key, styl
         {nodeName ? <NodeLink name={nodeName} /> : '-'}
       </TableData>
       <TableData className={tableColumnClasses[3]}>
-        <Status status={status} />
+        <Status status={getMachinePhase(obj)} />
       </TableData>
-      <TableData className={tableColumnClasses[4]}>{region || '-'}</TableData>
-      <TableData className={tableColumnClasses[5]}>{zone || '-'}</TableData>
-      <TableData className={tableColumnClasses[6]}>
+      <TableData className={tableColumnClasses[4]}>{providerState ?? '-'}</TableData>
+      <TableData className={tableColumnClasses[5]}>{region || '-'}</TableData>
+      <TableData className={tableColumnClasses[6]}>{zone || '-'}</TableData>
+      <TableData className={tableColumnClasses[7]}>
         <ResourceKebab actions={menuActions} kind={machineReference} resource={obj} />
       </TableData>
     </TableRow>
@@ -134,17 +145,27 @@ const MachineDetails: React.SFC<MachineDetailsProps> = ({ obj }: { obj: MachineK
   const instanceType = getMachineInstanceType(obj);
   const region = getMachineRegion(obj);
   const zone = getMachineZone(obj);
+  const providerState = getMachineProviderState(obj);
   return (
     <>
       <div className="co-m-pane__body">
-        <SectionHeading text="Machine Overview" />
+        <SectionHeading text="Machine Details" />
         <div className="co-m-pane__body-group">
           <div className="row">
             <div className="col-sm-6">
               <ResourceSummary resource={obj} />
             </div>
             <div className="col-sm-6">
-              <DetailsItem label="Status" obj={obj} path="status.phase" />
+              <DetailsItem label="Phase" obj={obj} path="status.phase">
+                <Status status={getMachinePhase(obj)} />
+              </DetailsItem>
+              <DetailsItem
+                label="Provider State"
+                obj={obj}
+                path="status.providerStatus.instanceState"
+              >
+                {providerState}
+              </DetailsItem>
               {nodeName && (
                 <>
                   <dt>Node</dt>
@@ -187,7 +208,7 @@ const MachineDetails: React.SFC<MachineDetailsProps> = ({ obj }: { obj: MachineK
       </div>
       <div className="co-m-pane__body">
         <SectionHeading text="Conditions" />
-        <Conditions conditions={_.get(obj, 'status.providerStatus.conditions')} />
+        <Conditions conditions={obj.status?.providerStatus?.conditions} />
       </div>
     </>
   );
@@ -224,6 +245,7 @@ export const MachineDetailsPage: React.SFC<MachineDetailsPageProps> = (props) =>
       navFactory.editYaml(),
       navFactory.events(ResourceEventStream),
     ]}
+    getResourceStatus={getMachinePhase}
   />
 );
 
