@@ -40,6 +40,7 @@ export const ConfigureCountModal = withHandlePromise((props: ConfigureCountModal
           changeValueBy={(operation) => setValue(_.toInteger(value) + operation)}
           autoFocus
           required
+          min={0}
         />
       </ModalBody>
       <ModalSubmitFooter
@@ -77,9 +78,7 @@ export const configureJobParallelismModal = (props) => {
       {
         defaultValue: 1,
         title: 'Edit Parallelism',
-        message: `${
-          props.resourceKind.labelPlural
-        } create one or more pods and ensure that a specified number of them successfully terminate. When the specified number of completions is successfully reached, the job is complete.`,
+        message: `${props.resourceKind.labelPlural} create one or more pods and ensure that a specified number of them successfully terminate. When the specified number of completions is successfully reached, the job is complete.`,
         path: '/spec/parallelism',
         buttonText: 'Save',
       },
