@@ -17,27 +17,22 @@ import {
   PlusCircleIcon,
 } from '@patternfly/react-icons';
 
+import { withFallback } from '@console/shared/src/components/error/error-boundary';
 import * as k8sActions from '../actions/k8s';
 import * as UIActions from '../actions/ui';
 import { coFetchJSON } from '../co-fetch';
-import {
-  alertState,
-  AlertStates,
-  connectToURLs,
-  MonitoringRoutes,
-  silenceState,
-  SilenceStates,
-} from '../reducers/monitoring';
+import { alertState, AlertStates, silenceState, SilenceStates } from '../reducers/monitoring';
 import store from '../redux';
 import { Table, TableData, TableRow, TextFilter } from './factory';
 import { confirmModal } from './modals';
+import MonitoringDashboardsPage from './monitoring/dashboards';
 import { graphStateToProps, QueryBrowserPage, ToggleGraph } from './monitoring/metrics';
 import { Labels, QueryBrowser, QueryObj } from './monitoring/query-browser';
 import { CheckBoxes } from './row-filter';
 import { formatPrometheusDuration } from './utils/datetime';
-import { withFallback } from './utils/error-boundary';
-import { AlertManagerYAMLEditorWrapper } from './monitoring/alert-manager-yaml-editor';
-import { AlertManagerConfigWrapper } from './monitoring/alert-manager-config';
+import { AlertmanagerYAMLEditorWrapper } from './monitoring/alert-manager-yaml-editor';
+import { AlertmanagerConfigWrapper } from './monitoring/alert-manager-config';
+import { refreshNotificationPollers } from './notification-drawer';
 import {
   ActionsMenu,
   ButtonBar,
@@ -99,12 +94,6 @@ const silencesToProps = ({ UI }) => UI.getIn(['monitoring', 'silences']) || {};
 const pollers = {};
 const pollerTimeouts = {};
 
-// Force a poller to execute now instead of waiting for the next poll interval
-const refreshPoller = (key) => {
-  clearTimeout(pollerTimeouts[key]);
-  _.invoke(pollers, key);
-};
-
 const silenceAlert = (alert) => ({
   label: 'Silence Alert',
   href: `${SilenceResource.plural}/~new?${labelsToParams(alert.labels)}`,
@@ -130,7 +119,7 @@ const cancelSilence = (silence) => ({
       executeFn: () =>
         coFetchJSON
           .delete(`${window.SERVER_FLAGS.alertManagerBaseURL}/api/v1/silence/${silence.id}`)
-          .then(() => refreshPoller('silences')),
+          .then(() => refreshNotificationPollers()),
     }),
 });
 
@@ -260,10 +249,7 @@ const Graph_: React.FC<GraphProps> = ({
     />
   );
 };
-const Graph = connect(
-  graphStateToProps,
-  { patchQuery: UIActions.queryBrowserPatchQuery },
-)(Graph_);
+const Graph = connect(graphStateToProps, { patchQuery: UIActions.queryBrowserPatchQuery })(Graph_);
 
 const SilenceMatchersList = ({ silence }) => (
   <div className={`co-text-${SilenceResource.kind.toLowerCase()}`}>
@@ -320,7 +306,7 @@ const AlertsDetailsPage = withFallback(
           </div>
           <div className="co-m-pane__body">
             {state !== AlertStates.NotFiring && <ToggleGraph />}
-            <SectionHeading text="Alert Overview" />
+            <SectionHeading text="Alert Details" />
             <div className="co-m-pane__body-group">
               <div className="row">
                 <div className="col-sm-12">
@@ -481,7 +467,7 @@ const AlertRulesDetailsPage = withFallback(
           </div>
           <div className="co-m-pane__body">
             <div className="monitoring-heading">
-              <SectionHeading text="Alerting Rule Overview" />
+              <SectionHeading text="Alerting Rule Details" />
             </div>
             <div className="co-m-pane__body-group">
               <div className="row">
@@ -577,7 +563,7 @@ const silenceParamToProps = (state, { match }) => {
   const { data: silences, loaded, loadError }: Silences = silencesToProps(state);
   const { loaded: alertsLoaded }: Alerts = alertsToProps(state);
   const silence = _.find(silences, { id: _.get(match, 'params.id') });
-  return { alertsLoaded, loaded, loadError, silence };
+  return { alertsLoaded, loaded, loadError, silence, silences };
 };
 
 const SilencesDetailsPage = withFallback(
@@ -618,7 +604,7 @@ const SilencesDetailsPage = withFallback(
             </h1>
           </div>
           <div className="co-m-pane__body">
-            <SectionHeading text="Silence Overview" />
+            <SectionHeading text="Silence Details" />
             <div className="co-m-pane__body-group">
               <div className="row">
                 <div className="col-sm-6">
@@ -774,18 +760,15 @@ const AlertsPageDescription = () => (
   </p>
 );
 
-const HeaderAlertmanagerLink_ = ({ path, urls }) =>
-  _.isEmpty(urls[MonitoringRoutes.AlertManager]) ? null : (
+const HeaderAlertmanagerLink = ({ path }) =>
+  _.isEmpty(window.SERVER_FLAGS.alertManagerPublicURL) ? null : (
     <span className="monitoring-header-link">
       <ExternalLink
-        href={`${urls[MonitoringRoutes.AlertManager]}${path || ''}`}
+        href={`${window.SERVER_FLAGS.alertManagerPublicURL}${path || ''}`}
         text="Alertmanager UI"
       />
     </span>
   );
-const HeaderAlertmanagerLink = connectToURLs(MonitoringRoutes.AlertManager)(
-  HeaderAlertmanagerLink_,
-);
 
 const alertsRowFilter = {
   type: 'alert-state',
@@ -830,7 +813,7 @@ const MonitoringListPage = connect(filtersToProps)(
       history.replace(`${url.pathname}?${params.toString()}${url.hash}`);
     }
 
-    componentWillMount() {
+    UNSAFE_componentWillMount() {
       const { nameFilterID, reduxID } = this.props;
       const params = new URLSearchParams(window.location.search);
 
@@ -1187,7 +1170,7 @@ class SilenceForm_ extends React.Component<SilenceFormProps, SilenceFormState> {
       .post(`${alertManagerBaseURL}/api/v1/silences`, body)
       .then(({ data }) => {
         this.setState({ error: undefined });
-        refreshPoller('silences');
+        refreshNotificationPollers();
         history.push(`${SilenceResource.plural}/${encodeURIComponent(_.get(data, 'silenceId'))}`);
       })
       .catch((err) =>
@@ -1225,7 +1208,7 @@ class SilenceForm_ extends React.Component<SilenceFormProps, SilenceFormState> {
           <div className="co-form-section__separator" />
 
           <div className="form-group">
-            <label className="co-required">Matchers</label> (label selectors)
+            <label className="co-required">Matchers (label selectors)</label>
             <p className="co-help-text">
               Alerts affected by this silence. Matching alerts must satisfy all of the specified
               label constraints, though they may have additional labels as well.
@@ -1367,7 +1350,7 @@ const CreateSilence = () => {
   );
 };
 
-const AlertManagerYAML = () => {
+const AlertmanagerYAML = () => {
   return (
     <Firehose
       resources={[
@@ -1380,12 +1363,12 @@ const AlertManagerYAML = () => {
         },
       ]}
     >
-      <AlertManagerYAMLEditorWrapper />
+      <AlertmanagerYAMLEditorWrapper />
     </Firehose>
   );
 };
 
-const AlertManagerConfig = () => {
+const AlertmanagerConfig = () => {
   return (
     <Firehose
       resources={[
@@ -1398,7 +1381,7 @@ const AlertManagerConfig = () => {
         },
       ]}
     >
-      <AlertManagerConfigWrapper />
+      <AlertmanagerConfigWrapper />
     </Firehose>
   );
 };
@@ -1408,13 +1391,14 @@ const AlertingPage: React.SFC<AlertingPageProps> = ({ match }) => {
   const silencePath = '/monitoring/silences';
   const YAMLPath = '/monitoring/alertmanageryaml';
   const ConfigPath = '/monitoring/alertmanagerconfig';
+  const isAlertmanager = match.url === ConfigPath || match.url === YAMLPath;
   return (
     <>
       <div className="co-m-nav-title co-m-nav-title--detail">
         <h1 className="co-m-pane__heading">
           <div className="co-m-pane__name co-resource-item">
             <span className="co-resource-item__resource-name" data-test-id="resource-title">
-              Alerting
+              {isAlertmanager ? 'Alertmanager' : 'Alerting'}
             </span>
             <HeaderAlertmanagerLink path="/#/alerts" />
           </div>
@@ -1439,14 +1423,14 @@ const AlertingPage: React.SFC<AlertingPageProps> = ({ match }) => {
             </li>
           </>
         )}
-        {(match.url === ConfigPath || match.url === YAMLPath) && (
+        {isAlertmanager && (
           <>
             <li
               className={classNames('co-m-horizontal-nav__menu-item', {
                 'co-m-horizontal-nav-item--active': match.url === ConfigPath,
               })}
             >
-              <Link to={ConfigPath}>Overview</Link>
+              <Link to={ConfigPath}>Details</Link>
             </li>
             <li
               className={classNames('co-m-horizontal-nav__menu-item', {
@@ -1461,8 +1445,8 @@ const AlertingPage: React.SFC<AlertingPageProps> = ({ match }) => {
       <Switch>
         <Route path="/monitoring/alerts" exact component={AlertsPage} />
         <Route path="/monitoring/silences" exact component={SilencesPage} />
-        <Route path={ConfigPath} exact component={AlertManagerConfig} />
-        <Route path="/monitoring/alertmanageryaml" exact component={AlertManagerYAML} />
+        <Route path={ConfigPath} exact component={AlertmanagerConfig} />
+        <Route path="/monitoring/alertmanageryaml" exact component={AlertmanagerYAML} />
       </Switch>
     </>
   );
@@ -1496,7 +1480,7 @@ export const getAlerts = (data: PrometheusRulesResponse['data']): Alert[] => {
 
 const PollerPages = () => {
   React.useEffect(() => {
-    const poll: Poll = (url, key: 'alerts' | 'silences', dataHandler) => {
+    const poll: Poll = (url, key: 'alerts', dataHandler) => {
       store.dispatch(UIActions.monitoringLoading(key));
       const poller = (): void => {
         coFetchJSON(url)
@@ -1509,34 +1493,13 @@ const PollerPages = () => {
       poller();
     };
 
-    const { alertManagerBaseURL, prometheusBaseURL } = window.SERVER_FLAGS;
+    const { prometheusBaseURL } = window.SERVER_FLAGS;
 
     if (prometheusBaseURL) {
       poll(`${prometheusBaseURL}/api/v1/rules`, 'alerts', getAlerts);
     } else {
       store.dispatch(UIActions.monitoringErrored('alerts', new Error('prometheusBaseURL not set')));
     }
-
-    if (alertManagerBaseURL) {
-      poll(`${alertManagerBaseURL}/api/v1/silences`, 'silences', (data) => {
-        // Set a name field on the Silence to make things easier
-        _.each(data, (s) => {
-          s.name = _.get(_.find(s.matchers, { name: 'alertname' }), 'value');
-          if (!s.name) {
-            // No alertname, so fall back to displaying the other matchers
-            s.name = s.matchers
-              .map((m) => `${m.name}${m.isRegex ? '=~' : '='}${m.value}`)
-              .join(', ');
-          }
-        });
-        return data;
-      });
-    } else {
-      store.dispatch(
-        UIActions.monitoringErrored('silences', new Error('alertManagerBaseURL not set')),
-      );
-    }
-
     return () => _.each(pollerTimeouts, clearTimeout);
   }, []);
 
@@ -1558,6 +1521,7 @@ const PollerPages = () => {
 export const MonitoringUI = () => (
   <Switch>
     <Redirect from="/monitoring" exact to="/monitoring/alerts" />
+    <Route path="/monitoring/dashboards/:board?" exact component={MonitoringDashboardsPage} />
     <Route path="/monitoring/query-browser" exact component={QueryBrowserPage} />
     <Route path="/monitoring/silences/~new" exact component={CreateSilence} />
     <Route component={PollerPages} />
