@@ -1,18 +1,22 @@
 import * as React from 'react';
 import { connect } from 'react-redux';
 import * as _ from 'lodash-es';
+import { useExtensions, NavItem, isNavItem } from '@console/plugin-sdk';
 import { createLink } from './items';
 import { NavSection } from './section';
 import AdminNav from './admin-nav';
 import { getActivePerspective } from '../../reducers/ui';
 import { RootState } from '../../redux';
-import * as plugins from '../../plugins';
 
 type StateProps = {
   perspective: string;
 };
 
 const PerspectiveNav: React.FC<StateProps> = ({ perspective }) => {
+  const navItemExtensions = useExtensions<NavItem>(isNavItem).filter(
+    (item) => item.properties.perspective === perspective,
+  );
+
   // Until admin perspective is contributed through extensions, simply render static `AdminNav`
   if (perspective === 'admin') {
     return <AdminNav />;
@@ -24,20 +28,17 @@ const PerspectiveNav: React.FC<StateProps> = ({ perspective }) => {
   return (
     <>
       {_.compact(
-        plugins.registry
-          .getNavItems()
-          .filter((item) => item.properties.perspective === perspective)
-          .map((item) => {
-            const { section } = item.properties;
-            if (section) {
-              if (renderedSections.includes(section)) {
-                return;
-              }
-              renderedSections.push(section);
-              return <NavSection title={section} key={section} />;
+        navItemExtensions.map((item) => {
+          const { section } = item.properties;
+          if (section) {
+            if (renderedSections.includes(section)) {
+              return;
             }
-            return createLink(item, true);
-          }),
+            renderedSections.push(section);
+            return <NavSection title={section} key={section} />;
+          }
+          return createLink(item, true);
+        }),
       )}
     </>
   );
