@@ -1,17 +1,21 @@
 import * as React from 'react';
+import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
 import { sortable } from '@patternfly/react-table';
 import * as classNames from 'classnames';
 import * as _ from 'lodash-es';
-import { Status, ErrorStatus } from '@console/shared';
+import { Status } from '@console/shared';
 import { ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
 
+import * as UIActions from '../actions/ui';
+import { coFetchJSON } from '../co-fetch';
 import { ContainerSpec, K8sResourceKindReference, PodKind } from '../module/k8s';
 import {
   getRestartPolicyLabel,
   podPhase,
   podPhaseFilterReducer,
   podReadiness,
+  podRestarts,
 } from '../module/k8s/pods';
 import { getContainerState, getContainerStatus } from '../module/k8s/container';
 import { ResourceEventStream } from './events';
@@ -29,97 +33,133 @@ import {
   ScrollToTopOnMount,
   SectionHeading,
   Timestamp,
+  formatBytesAsMiB,
+  formatCores,
   humanizeBinaryBytes,
+  humanizeDecimalBytesPerSec,
   humanizeCpuCores,
   navFactory,
   pluralize,
   units,
 } from './utils';
+import { fromNow } from './utils/datetime';
 import { PodLogs } from './pod-logs';
-import { requirePrometheus, Area } from './graphs';
-import { CamelCaseWrap } from './utils/camel-case-wrap';
+import {
+  Area,
+  PROMETHEUS_BASE_PATH,
+  PROMETHEUS_TENANCY_BASE_PATH,
+  requirePrometheus,
+} from './graphs';
 import { VolumesTable } from './volumes-table';
+import { PodModel } from '../models';
+import { Conditions } from './conditions';
 
-export const menuActions = [...Kebab.factory.common];
-const validReadinessStates = new Set(['ContainersNotReady', 'Ready', 'PodCompleted']);
+// Only request metrics if the device's screen width is larger than the
+// breakpoint where metrics are visible.
+const showMetrics =
+  PROMETHEUS_BASE_PATH && PROMETHEUS_TENANCY_BASE_PATH && window.screen.width >= 1200;
 
-export const Readiness: React.FC<ReadinessProps> = ({ pod }) => {
-  const readiness = podReadiness(pod);
-  if (!readiness) {
-    return null;
-  }
-  if (validReadinessStates.has(readiness)) {
-    return <CamelCaseWrap value={readiness} />;
-  }
-  return (
-    <span className="co-error co-icon-and-text">
-      <ErrorStatus title={readiness} />
-    </span>
+const fetchPodMetrics = (namespace: string): Promise<UIActions.PodMetrics> => {
+  const metrics = [
+    {
+      key: 'memory',
+      query: namespace
+        ? `sum(container_memory_working_set_bytes{namespace='${namespace}',container=''}) BY (pod, namespace)`
+        : "sum(container_memory_working_set_bytes{container=''}) BY (pod, namespace)",
+    },
+    {
+      key: 'cpu',
+      query: namespace
+        ? `pod:container_cpu_usage:sum{namespace='${namespace}'}`
+        : 'pod:container_cpu_usage:sum',
+    },
+  ];
+  const promises = metrics.map(
+    ({ key, query }): Promise<UIActions.PodMetrics> => {
+      const url = namespace
+        ? `${PROMETHEUS_TENANCY_BASE_PATH}/api/v1/query?namespace=${namespace}&query=${query}`
+        : `${PROMETHEUS_BASE_PATH}/api/v1/query?query=${query}`;
+      return coFetchJSON(url).then(({ data: { result } }) => {
+        return result.reduce((acc, data) => {
+          const value = Number(data.value[1]);
+          return _.set(acc, [key, data.metric.namespace, data.metric.pod], value);
+        }, {});
+      });
+    },
   );
+  return Promise.all(promises).then((data: any[]) => _.assign({}, ...data));
 };
-Readiness.displayName = 'Readiness';
+
+export const menuActions = [
+  ...Kebab.getExtensionsActionsForKind(PodModel),
+  ...Kebab.factory.common,
+];
 
 const tableColumnClasses = [
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-2', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-2', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-2', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  '',
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg', 'pf-u-w-10-on-lg', 'pf-u-w-8-on-xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-2xl', 'pf-u-w-8-on-2xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
+  classNames('pf-m-hidden', { 'pf-m-visible-on-xl pf-u-w-10-on-2xl': showMetrics }),
+  classNames('pf-m-hidden', { 'pf-m-visible-on-xl pf-u-w-10-on-2xl': showMetrics }),
+  classNames('pf-m-hidden', 'pf-m-visible-on-2xl pf-u-w-10-on-2xl'),
   Kebab.columnClass,
 ];
 
 const kind = 'Pod';
 
-const PodTableRow: React.FC<PodTableRowProps> = ({ obj: pod, index, key, style }) => {
-  const phase = podPhase(pod);
-  return (
-    <TableRow id={pod.metadata.uid} index={index} trKey={key} style={style}>
-      <TableData className={tableColumnClasses[0]}>
-        <ResourceLink
-          kind={kind}
-          name={pod.metadata.name}
-          namespace={pod.metadata.namespace}
-          title={pod.metadata.uid}
-        />
-      </TableData>
-      <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
-        <ResourceLink
-          kind="Namespace"
-          name={pod.metadata.namespace}
-          title={pod.metadata.namespace}
-        />
-      </TableData>
-      <TableData className={tableColumnClasses[2]}>
-        <OwnerReferences resource={pod} />
-      </TableData>
-      <TableData className={tableColumnClasses[3]}>
-        <NodeLink name={pod.spec.nodeName} />
-      </TableData>
-      <TableData className={tableColumnClasses[4]}>
-        <Status status={phase} />
-      </TableData>
-      <TableData className={tableColumnClasses[5]}>
-        <Readiness pod={pod} />
-      </TableData>
-      <TableData className={tableColumnClasses[6]}>
-        <ResourceKebab
-          actions={menuActions}
-          kind={kind}
-          resource={pod}
-          isDisabled={phase === 'Terminating'}
-        />
-      </TableData>
-    </TableRow>
-  );
-};
+const podRowStateToProps = ({ UI }) => ({
+  metrics: UI.getIn(['metrics', 'pod']),
+});
+
+const PodTableRow = connect<PodTableRowPropsFromState, null, PodTableRowProps>(podRowStateToProps)(
+  ({ obj: pod, index, key, style, metrics }: PodTableRowProps & PodTableRowPropsFromState) => {
+    const { name, namespace, creationTimestamp } = pod.metadata;
+    const { readyCount, totalContainers } = podReadiness(pod);
+    const phase = podPhase(pod);
+    const restarts = podRestarts(pod);
+    const bytes: number = _.get(metrics, ['memory', namespace, name]);
+    const cores: number = _.get(metrics, ['cpu', namespace, name]);
+    return (
+      <TableRow id={pod.metadata.uid} index={index} trKey={key} style={style}>
+        <TableData className={tableColumnClasses[0]}>
+          <ResourceLink kind={kind} name={name} namespace={namespace} />
+        </TableData>
+        <TableData className={classNames(tableColumnClasses[1], 'co-break-word')}>
+          <ResourceLink kind="Namespace" name={namespace} />
+        </TableData>
+        <TableData className={tableColumnClasses[2]}>
+          <Status status={phase} />
+        </TableData>
+        <TableData className={tableColumnClasses[3]}>
+          {readyCount}/{totalContainers}
+        </TableData>
+        <TableData className={tableColumnClasses[4]}>{restarts}</TableData>
+        <TableData className={tableColumnClasses[5]}>
+          <OwnerReferences resource={pod} />
+        </TableData>
+        <TableData className={tableColumnClasses[6]}>
+          {bytes ? `${formatBytesAsMiB(bytes)} MiB` : '-'}
+        </TableData>
+        <TableData className={tableColumnClasses[7]}>
+          {cores ? `${formatCores(cores)} cores` : '-'}
+        </TableData>
+        <TableData className={tableColumnClasses[8]}>{fromNow(creationTimestamp)}</TableData>
+        <TableData className={tableColumnClasses[9]}>
+          <ResourceKebab
+            actions={menuActions}
+            kind={kind}
+            resource={pod}
+            isDisabled={phase === 'Terminating'}
+          />
+        </TableData>
+      </TableRow>
+    );
+  },
+);
 PodTableRow.displayName = 'PodTableRow';
-type PodTableRowProps = {
-  obj: PodKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 const PodTableHeader = () => {
   return [
@@ -136,33 +176,51 @@ const PodTableHeader = () => {
       props: { className: tableColumnClasses[1] },
     },
     {
-      title: 'Owner',
-      sortField: 'metadata.ownerReferences[0].name',
+      title: 'Status',
+      sortFunc: 'podPhase',
       transforms: [sortable],
       props: { className: tableColumnClasses[2] },
     },
     {
-      title: 'Node',
-      sortField: 'spec.nodeName',
+      title: 'Ready',
+      sortFunc: 'podReadiness',
       transforms: [sortable],
       props: { className: tableColumnClasses[3] },
     },
     {
-      title: 'Status',
-      sortFunc: 'podPhase',
+      title: 'Restarts',
+      sortFunc: 'podRestarts',
       transforms: [sortable],
       props: { className: tableColumnClasses[4] },
     },
     {
-      title: 'Readiness',
-      sortFunc: 'podReadiness',
+      title: 'Owner',
+      sortField: 'metadata.ownerReferences[0].name',
       transforms: [sortable],
       props: { className: tableColumnClasses[5] },
     },
     {
-      title: '',
+      title: 'Memory',
+      sortFunc: 'podMemory',
+      transforms: [sortable],
       props: { className: tableColumnClasses[6] },
     },
+    {
+      title: 'CPU',
+      sortFunc: 'podCPU',
+      transforms: [sortable],
+      props: { className: tableColumnClasses[7] },
+    },
+    {
+      title: 'Created',
+      sortField: 'metadata.creationTimestamp',
+      transforms: [sortable],
+      props: { className: tableColumnClasses[8] },
+    },
+    {
+      title: '',
+      props: { className: tableColumnClasses[9] },
+    },
   ];
 };
 PodTableHeader.displayName = 'PodTableHeader';
@@ -242,9 +300,7 @@ const PodGraphs = requirePrometheus(({ pod }) => (
           humanize={humanizeBinaryBytes}
           byteDataType={ByteDataTypes.BinaryBytes}
           namespace={pod.metadata.namespace}
-          query={`sum(container_memory_working_set_bytes{pod='${pod.metadata.name}',namespace='${
-            pod.metadata.namespace
-          }',container='',}) BY (pod, namespace)`}
+          query={`sum(container_memory_working_set_bytes{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}',container='',}) BY (pod, namespace)`}
         />
       </div>
       <div className="col-md-12 col-lg-4">
@@ -252,9 +308,7 @@ const PodGraphs = requirePrometheus(({ pod }) => (
           title="CPU Usage"
           humanize={humanizeCpuCores}
           namespace={pod.metadata.namespace}
-          query={`pod:container_cpu_usage:sum{pod='${pod.metadata.name}',namespace='${
-            pod.metadata.namespace
-          }'}`}
+          query={`pod:container_cpu_usage:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
         />
       </div>
       <div className="col-md-12 col-lg-4">
@@ -263,9 +317,25 @@ const PodGraphs = requirePrometheus(({ pod }) => (
           humanize={humanizeBinaryBytes}
           byteDataType={ByteDataTypes.BinaryBytes}
           namespace={pod.metadata.namespace}
-          query={`pod:container_fs_usage_bytes:sum{pod='${pod.metadata.name}',namespace='${
-            pod.metadata.namespace
-          }'}`}
+          query={`pod:container_fs_usage_bytes:sum{pod='${pod.metadata.name}',namespace='${pod.metadata.namespace}'}`}
+        />
+      </div>
+    </div>
+    <div className="row">
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Network In"
+          humanize={humanizeDecimalBytesPerSec}
+          namespace={pod.metadata.namespace}
+          query={`sum(irate(container_network_receive_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace)`}
+        />
+      </div>
+      <div className="col-md-12 col-lg-4">
+        <Area
+          title="Network Out"
+          humanize={humanizeDecimalBytesPerSec}
+          namespace={pod.metadata.namespace}
+          query={`sum(irate(container_network_transmit_bytes_total{pod='${pod.metadata.name}', namespace='${pod.metadata.namespace}'}[5m])) by (pod, namespace)`}
         />
       </div>
     </div>
@@ -287,7 +357,7 @@ export const PodDetailsList: React.FC<PodDetailsListProps> = ({ pod }) => {
         {getRestartPolicyLabel(pod)}
       </DetailsItem>
       <DetailsItem label="Active Deadline Seconds" obj={pod} path="spec.activeDeadlineSeconds">
-        {pod.spec.progressDeadlineSeconds
+        {pod.spec.activeDeadlineSeconds
           ? pluralize(pod.spec.activeDeadlineSeconds, 'second')
           : 'Not Configured'}
       </DetailsItem>
@@ -300,7 +370,12 @@ export const PodDetailsList: React.FC<PodDetailsListProps> = ({ pod }) => {
 };
 
 export const PodResourceSummary: React.FC<PodResourceSummaryProps> = ({ pod }) => (
-  <ResourceSummary resource={pod} showNodeSelector showTolerations />
+  <ResourceSummary
+    resource={pod}
+    showNodeSelector
+    nodeSelector="spec.nodeSelector"
+    showTolerations
+  />
 );
 
 const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
@@ -332,7 +407,7 @@ const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
     <>
       <ScrollToTopOnMount />
       <div className="co-m-pane__body">
-        <SectionHeading text="Pod Overview" />
+        <SectionHeading text="Pod Details" />
         <PodGraphs pod={pod} />
         <div className="row">
           <div className="col-sm-6">
@@ -364,6 +439,10 @@ const Details: React.FC<PodDetailsProps> = ({ obj: pod }) => {
       <div className="co-m-pane__body">
         <VolumesTable resource={pod} heading="Volumes" />
       </div>
+      <div className="co-m-pane__body">
+        <SectionHeading text="Conditions" />
+        <Conditions conditions={pod.status.conditions} />
+      </div>
     </>
   );
 };
@@ -413,8 +492,9 @@ export const PodsDetailsPage: React.FC<PodDetailsPageProps> = (props) => (
 );
 PodsDetailsPage.displayName = 'PodsDetailsPage';
 
+const Row = (rowProps: PodTableRowProps) => <PodTableRow {...rowProps} />;
 export const PodList: React.FC = (props) => (
-  <Table {...props} aria-label="Pods" Header={PodTableHeader} Row={PodTableRow} virtualize />
+  <Table {...props} aria-label="Pods" Header={PodTableHeader} Row={Row} virtualize />
 );
 PodList.displayName = 'PodList';
 
@@ -437,27 +517,46 @@ const filters = [
   },
 ];
 
-export class PodsPage extends React.Component<PodPageProps> {
-  shouldComponentUpdate(nextProps: PodPageProps) {
-    return !_.isEqual(nextProps, this.props);
-  }
-  render() {
-    const { canCreate = true } = this.props;
-    return (
-      <ListPage
-        {...this.props}
-        canCreate={canCreate}
-        kind="Pod"
-        ListComponent={PodList}
-        rowFilters={filters}
-      />
-    );
-  }
-}
+const dispatchToProps = (dispatch): PodPagePropsFromDispatch => ({
+  setPodMetrics: (metrics) => dispatch(UIActions.setPodMetrics(metrics)),
+});
 
-type ReadinessProps = {
-  pod: PodKind;
-};
+export const PodsPage = connect<{}, PodPagePropsFromDispatch, PodPageProps>(
+  null,
+  dispatchToProps,
+)((props: PodPageProps & PodPagePropsFromDispatch) => {
+  const { canCreate = true, namespace, setPodMetrics, ...listProps } = props;
+  /* eslint-disable react-hooks/exhaustive-deps */
+  React.useEffect(() => {
+    if (showMetrics) {
+      const updateMetrics = () =>
+        fetchPodMetrics(namespace)
+          .then(setPodMetrics)
+          .catch((e) => {
+            // Just log the error here. Showing a warning alert could be more annoying
+            // than helpful. It should be obvious there are no metrics in the list, and
+            // if monitoring is broken, it'll be really apparent since none of the
+            // graphs and dashboards will load in the UI.
+            // eslint-disable-next-line no-console
+            console.error('Unable to fetch pod metrics', e);
+          });
+      updateMetrics();
+      const id = setInterval(updateMetrics, 30 * 1000);
+      return () => clearInterval(id);
+    }
+  }, [namespace]);
+  /* eslint-enable react-hooks/exhaustive-deps */
+  return (
+    <ListPage
+      {...listProps}
+      canCreate={canCreate}
+      kind="Pod"
+      ListComponent={PodList}
+      rowFilters={filters}
+      namespace={namespace}
+    />
+  );
+});
 
 type ContainerLinkProps = {
   pod: PodKind;
@@ -495,6 +594,17 @@ type PodDetailsProps = {
   obj: PodKind;
 };
 
+type PodTableRowProps = {
+  obj: PodKind;
+  index: number;
+  key?: string;
+  style: object;
+};
+
+type PodTableRowPropsFromState = {
+  metrics: UIActions.PodMetrics;
+};
+
 type PodPageProps = {
   canCreate?: boolean;
   fieldSelector?: any;
@@ -503,6 +613,10 @@ type PodPageProps = {
   showTitle?: boolean;
 };
 
+type PodPagePropsFromDispatch = {
+  setPodMetrics: (metrics) => void;
+};
+
 type PodDetailsPageProps = {
   kind: K8sResourceKindReference;
   match: any;
