@@ -155,29 +155,22 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
   };
 
   const handleStorageClass = (updatedStorageClass) => {
+    const provisioner: string = updatedStorageClass?.provisioner || '';
     //if the provisioner is unknown or no storage class selected, user should be able to set any access mode
-    const modes =
-      updatedStorageClass &&
-      updatedStorageClass.provisioner &&
-      provisionerAccessModeMapping[updatedStorageClass.provisioner]
-        ? provisionerAccessModeMapping[updatedStorageClass.provisioner]
-        : getAccessModeForProvisioner(updatedStorageClass.provisioner);
+    const modes = provisionerAccessModeMapping[provisioner]
+      ? provisionerAccessModeMapping[provisioner]
+      : getAccessModeForProvisioner(provisioner);
     //setting message to display for various modes when a storage class of a know provisioner is selected
     const displayMessage =
-      updatedStorageClass &&
-      (provisionerAccessModeMapping[updatedStorageClass.provisioner] ||
-        isCephProvisioner(updatedStorageClass.provisioner))
+      provisionerAccessModeMapping[provisioner] || isCephProvisioner(provisioner)
         ? 'Access mode is set by storage class and cannot be changed.'
         : 'Permissions to the mounted drive.';
     setAccessMode('ReadWriteOnce');
     setAccessModeHelp(displayMessage);
     //setting accessMode to default with the change to Storage Class selection
     setAllowedAccessModes(modes);
-    setStorageClass(_.get(updatedStorageClass, 'metadata.name'));
-
-    if (updatedStorageClass) {
-      setStorageProvisioner(updatedStorageClass.provisioner);
-    }
+    setStorageClass(updatedStorageClass?.metadata?.name);
+    setStorageProvisioner(provisioner);
   };
 
   const handleRequestSizeInputChange = (obj) => {
@@ -226,7 +219,6 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
           aria-describedby="pvc-name-help"
           id="pvc-name"
           name="pvcName"
-          pattern="[a-z0-9](?:[-a-z0-9]*[a-z0-9])?"
           required
         />
         <p className="help-block" id="pvc-name-help">
@@ -268,7 +260,7 @@ export const CreatePVCForm: React.FC<CreatePVCFormProps> = (props) => {
       </label>
       <RequestSizeInput
         name="requestSize"
-        required={false}
+        required
         onChange={handleRequestSizeInputChange}
         defaultRequestSizeUnit={requestSizeUnit}
         defaultRequestSizeValue={requestSizeValue}
