@@ -1,11 +1,23 @@
-import { K8sResourceKindReference, Selector, K8sResourceKind } from '../../module/k8s';
+import {
+  K8sResourceKindReference,
+  Selector,
+  K8sResourceKind,
+  K8sResourceCommon,
+} from '../../module/k8s';
 
-export type FirehoseResult<R extends K8sResourceKind | K8sResourceKind[] = K8sResourceKind[]> = {
+export type FirehoseResult<
+  R extends K8sResourceCommon | K8sResourceCommon[] = K8sResourceKind[]
+> = {
   loaded: boolean;
   loadError: string;
+  optional?: boolean;
   data: R;
 };
 
+export type FirehoseResourcesResult = {
+  [key: string]: FirehoseResult<K8sResourceCommon | K8sResourceCommon[]>;
+};
+
 /*
   Add the enum for NameValueEditorPair here and not in its namesake file because the editor should always be
   loaded asynchronously in order not to bloat the vendor file. The enum reference into the editor
