@@ -28,9 +28,12 @@ export const getAvailableClusterUpdates = (cv: ClusterVersionKind): ClusterUpdat
 };
 
 export const getAvailableClusterChannels = () => ({
-  'stable-4.3': 'stable-4.3',
-  'fast-4.3': 'fast-4.3',
-  'candidate-4.3': 'candidate-4.3',
+  'stable-4.4': 'stable-4.4',
+  'fast-4.4': 'fast-4.4',
+  'candidate-4.4': 'candidate-4.4',
+  'stable-4.5': 'stable-4.5',
+  'fast-4.5': 'fast-4.5',
+  'candidate-4.5': 'candidate-4.5',
 });
 
 export const getDesiredClusterVersion = (cv: ClusterVersionKind): string => {
@@ -111,14 +114,14 @@ export const getClusterUpdateStatus = (cv: ClusterVersionKind): ClusterUpdateSta
     return ClusterUpdateStatus.Failing;
   }
 
-  if (failedToRetrieveUpdates(cv)) {
-    return ClusterUpdateStatus.ErrorRetrieving;
-  }
-
   if (isProgressing(cv)) {
     return ClusterUpdateStatus.Updating;
   }
 
+  if (failedToRetrieveUpdates(cv)) {
+    return ClusterUpdateStatus.ErrorRetrieving;
+  }
+
   return hasAvailableUpdates(cv)
     ? ClusterUpdateStatus.UpdatesAvailable
     : ClusterUpdateStatus.UpToDate;
@@ -154,7 +157,8 @@ export const getReportBugLink = (cv: ClusterVersionKind): { label: string; href:
   }
 
   // Show a Bugzilla link for prerelease versions and a support case link for supported versions.
-  const { major, minor, patch, prerelease } = parsed;
+  const { major, minor, prerelease } = parsed;
+  const bugzillaVersion = major === 4 && minor <= 3 ? `${major}.${minor}.0` : `${major}.${minor}`;
   const environment = encodeURIComponent(`Version: ${version}
 Cluster ID: ${cv.spec.clusterID}
 Browser: ${window.navigator.userAgent}
@@ -162,15 +166,11 @@ Browser: ${window.navigator.userAgent}
   return _.isEmpty(prerelease)
     ? {
         label: 'Open Support Case',
-        href: `https://access.redhat.com/support/cases/#/case/new?product=OpenShift%20Container%20Platform&version=${major}.${minor}&clusterId=${
-          cv.spec.clusterID
-        }`,
+        href: `https://access.redhat.com/support/cases/#/case/new?product=OpenShift%20Container%20Platform&version=${major}.${minor}&clusterId=${cv.spec.clusterID}`,
       }
     : {
         label: 'Report Bug',
-        href: `https://bugzilla.redhat.com/enter_bug.cgi?product=OpenShift%20Container%20Platform&version=${major}.${minor}.${
-          patch ? 'z' : '0'
-        }&cf_environment=${environment}`,
+        href: `https://bugzilla.redhat.com/enter_bug.cgi?product=OpenShift%20Container%20Platform&version=${bugzillaVersion}&cf_environment=${environment}`,
       };
 };
 
