@@ -14,10 +14,13 @@ set -e
 
 export GOBIN=${PWD}/bin:${GOBIN}
 
+# Use deps from vendor dir.
+export GOFLAGS="-mod=vendor"
+
 # Invoke ./cover for HTML output
 COVER=${COVER:-"-cover"}
 
-TESTABLE="pkg/auth pkg/proxy pkg/server"
+TESTABLE="pkg/auth pkg/proxy pkg/server pkg/helm/actions pkg/helm/handlers"
 FORMATTABLE="${TESTABLE} cmd/bridge pkg/version"
 
 # user has not provided PKG override
